@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg;
 
-/**
- * An enum representing possible operations in a changelog.
- */
+/** An enum representing possible operations in a changelog. */
 public enum ChangelogOperation {
-  INSERT, DELETE
+  INSERT,
+  DELETE,
+  UPDATE_BEFORE,
+  UPDATE_AFTER
 }
