@@ -106,6 +106,18 @@ public interface RewriteDataFiles
 
   boolean USE_STARTING_SEQUENCE_NUMBER_DEFAULT = true;
 
+  /**
+   * Remove dangling delete files from the current snapshot after compaction. A delete file is
+   * considered dangling if it does not apply to any live data files.
+   *
+   * <p>Both equality and position dangling delete files will be removed.
+   *
+   * <p>Defaults to false.
+   */
+  String REMOVE_DANGLING_DELETES = "remove-dangling-deletes";
+
+  boolean REMOVE_DANGLING_DELETES_DEFAULT = false;
+
   /**
    * Forces the rewrite job order based on the value.
    *
@@ -216,6 +228,10 @@ public interface RewriteDataFiles
     default int failedDataFilesCount() {
       return rewriteFailures().stream().mapToInt(FileGroupFailureResult::dataFilesCount).sum();
     }
+
+    default int removedDeleteFilesCount() {
+      return 0;
+    }
   }
 
   /**
