@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.catalog;
 
 import java.util.List;
@@ -27,12 +26,10 @@ import org.apache.iceberg.SortOrder;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.Transaction;
 import org.apache.iceberg.exceptions.AlreadyExistsException;
+import org.apache.iceberg.exceptions.NoSuchNamespaceException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
-import org.apache.iceberg.exceptions.NotFoundException;
 
-/**
- * A Catalog API for table create, drop, and load operations.
- */
+/** A Catalog API for table create, drop, and load operations. */
 public interface Catalog {
 
   /**
@@ -49,7 +46,7 @@ public interface Catalog {
    *
    * @param namespace a namespace
    * @return a list of identifiers for tables
-   * @throws  NotFoundException if the namespace is not found
+   * @throws NoSuchNamespaceException if the namespace is not found
    */
   List<TableIdentifier> listTables(Namespace namespace);
 
@@ -105,10 +102,7 @@ public interface Catalog {
    * @return a Table instance
    * @throws AlreadyExistsException if the table already exists
    */
-  default Table createTable(
-      TableIdentifier identifier,
-      Schema schema,
-      PartitionSpec spec) {
+  default Table createTable(TableIdentifier identifier, Schema schema, PartitionSpec spec) {
     return createTable(identifier, schema, spec, null, null);
   }
 
@@ -120,9 +114,7 @@ public interface Catalog {
    * @return a Table instance
    * @throws AlreadyExistsException if the table already exists
    */
-  default Table createTable(
-      TableIdentifier identifier,
-      Schema schema) {
+  default Table createTable(TableIdentifier identifier, Schema schema) {
     return createTable(identifier, schema, PartitionSpec.unpartitioned(), null, null);
   }
 
@@ -179,9 +171,7 @@ public interface Catalog {
    * @throws AlreadyExistsException if the table already exists
    */
   default Transaction newCreateTableTransaction(
-      TableIdentifier identifier,
-      Schema schema,
-      PartitionSpec spec) {
+      TableIdentifier identifier, Schema schema, PartitionSpec spec) {
     return newCreateTableTransaction(identifier, schema, spec, null, null);
   }
 
@@ -193,9 +183,7 @@ public interface Catalog {
    * @return a {@link Transaction} to create the table
    * @throws AlreadyExistsException if the table already exists
    */
-  default Transaction newCreateTableTransaction(
-      TableIdentifier identifier,
-      Schema schema) {
+  default Transaction newCreateTableTransaction(TableIdentifier identifier, Schema schema) {
     return newCreateTableTransaction(identifier, schema, PartitionSpec.unpartitioned(), null, null);
   }
 
@@ -219,10 +207,11 @@ public interface Catalog {
       Map<String, String> properties,
       boolean orCreate) {
 
-    TableBuilder tableBuilder = buildTable(identifier, schema)
-        .withPartitionSpec(spec)
-        .withLocation(location)
-        .withProperties(properties);
+    TableBuilder tableBuilder =
+        buildTable(identifier, schema)
+            .withPartitionSpec(spec)
+            .withLocation(location)
+            .withProperties(properties);
 
     if (orCreate) {
       return tableBuilder.createOrReplaceTransaction();
@@ -262,10 +251,7 @@ public interface Catalog {
    * @throws NoSuchTableException if the table doesn't exist and orCreate is false
    */
   default Transaction newReplaceTableTransaction(
-      TableIdentifier identifier,
-      Schema schema,
-      PartitionSpec spec,
-      boolean orCreate) {
+      TableIdentifier identifier, Schema schema, PartitionSpec spec, boolean orCreate) {
     return newReplaceTableTransaction(identifier, schema, spec, null, null, orCreate);
   }
 
@@ -279,10 +265,9 @@ public interface Catalog {
    * @throws NoSuchTableException if the table doesn't exist and orCreate is false
    */
   default Transaction newReplaceTableTransaction(
-      TableIdentifier identifier,
-      Schema schema,
-      boolean orCreate) {
-    return newReplaceTableTransaction(identifier, schema, PartitionSpec.unpartitioned(), null, null, orCreate);
+      TableIdentifier identifier, Schema schema, boolean orCreate) {
+    return newReplaceTableTransaction(
+        identifier, schema, PartitionSpec.unpartitioned(), null, null, orCreate);
   }
 
   /**
@@ -312,8 +297,8 @@ public interface Catalog {
 
   /**
    * Drop a table; optionally delete data and metadata files.
-   * <p>
-   * If purge is set to true the implementation should delete all data and metadata files.
+   *
+   * <p>If purge is set to true the implementation should delete all data and metadata files.
    *
    * @param identifier a table identifier
    * @param purge if true, delete all data and metadata files in the table
@@ -342,14 +327,13 @@ public interface Catalog {
 
   /**
    * Invalidate cached table metadata from current catalog.
-   * <p>
-   * If the table is already loaded or cached, drop cached data. If the table does not exist or is
-   * not cached, do nothing.
+   *
+   * <p>If the table is already loaded or cached, drop cached data. If the table does not exist or
+   * is not cached, do nothing.
    *
    * @param identifier a table identifier
    */
-  default void invalidateTable(TableIdentifier identifier) {
-  }
+  default void invalidateTable(TableIdentifier identifier) {}
 
   /**
    * Register a table with the catalog if it does not exist.
@@ -364,34 +348,34 @@ public interface Catalog {
   }
 
   /**
-  /**
-   * Instantiate a builder to either create a table or start a create/replace transaction.
+   * /** Instantiate a builder to either create a table or start a create/replace transaction.
    *
    * @param identifier a table identifier
    * @param schema a schema
    * @return the builder to create a table or start a create/replace transaction
    */
   default TableBuilder buildTable(TableIdentifier identifier, Schema schema) {
-    throw new UnsupportedOperationException(this.getClass().getName() + " does not implement buildTable");
+    throw new UnsupportedOperationException(
+        this.getClass().getName() + " does not implement buildTable");
   }
 
   /**
    * Initialize a catalog given a custom name and a map of catalog properties.
-   * <p>
-   * A custom Catalog implementation must have a no-arg constructor.
-   * A compute engine like Spark or Flink will first initialize the catalog without any arguments,
-   * and then call this method to complete catalog initialization with properties passed into the engine.
+   *
+   * <p>A custom Catalog implementation must have a no-arg constructor. A compute engine like Spark
+   * or Flink will first initialize the catalog without any arguments, and then call this method to
+   * complete catalog initialization with properties passed into the engine.
    *
    * @param name a custom name for the catalog
    * @param properties catalog properties
    */
-  default void initialize(String name, Map<String, String> properties) {
-  }
+  default void initialize(String name, Map<String, String> properties) {}
 
   /**
-   * A builder used to create valid {@link Table tables} or start create/replace {@link Transaction transactions}.
-   * <p>
-   * Call {@link #buildTable(TableIdentifier, Schema)} to create a new builder.
+   * A builder used to create valid {@link Table tables} or start create/replace {@link Transaction
+   * transactions}.
+   *
+   * <p>Call {@link #buildTable(TableIdentifier, Schema)} to create a new builder.
    */
   interface TableBuilder {
     /**
@@ -429,7 +413,7 @@ public interface Catalog {
     /**
      * Adds a key/value property to the table.
      *
-     * @param key   a key
+     * @param key a key
      * @param value a value
      * @return this for method chaining
      */
