@@ -23,6 +23,10 @@ import java.nio.ByteBuffer;
 import java.util.Map;
 
 /** A minimum client interface to connect to a key management service (KMS). */
+/**
+ * @deprecated the API will be removed in v2.0.0 (replaced with KeyManagementClient interface).
+ */
+@Deprecated
 public interface KmsClient extends Serializable {
 
   /**
