@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.expressions;
 
 import java.io.ObjectStreamException;
@@ -25,7 +24,6 @@ import java.math.RoundingMode;
 import java.nio.ByteBuffer;
 import java.time.Instant;
 import java.time.LocalDate;
-import java.time.LocalDateTime;
 import java.time.LocalTime;
 import java.time.OffsetDateTime;
 import java.time.ZoneOffset;
@@ -41,11 +39,11 @@ import org.apache.iceberg.types.Conversions;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.ByteBuffers;
+import org.apache.iceberg.util.DateTimeUtil;
 import org.apache.iceberg.util.NaNUtil;
 
 class Literals {
-  private Literals() {
-  }
+  private Literals() {}
 
   private static final OffsetDateTime EPOCH = Instant.ofEpochSecond(0).atOffset(ZoneOffset.UTC);
   private static final LocalDate EPOCH_DAY = EPOCH.toLocalDate();
@@ -84,8 +82,9 @@ class Literals {
       return (Literal<T>) new Literals.DecimalLiteral((BigDecimal) value);
     }
 
-    throw new IllegalArgumentException(String.format(
-        "Cannot create expression literal from %s: %s", value.getClass().getName(), value));
+    throw new IllegalArgumentException(
+        String.format(
+            "Cannot create expression literal from %s: %s", value.getClass().getName(), value));
   }
 
   @SuppressWarnings("unchecked")
@@ -149,7 +148,6 @@ class Literals {
     public int hashCode() {
       return Objects.hashCode(value);
     }
-
   }
 
   private abstract static class ComparableLiteral<C extends Comparable<C>> extends BaseLiteral<C> {
@@ -171,8 +169,7 @@ class Literals {
   static class AboveMax<T> implements Literal<T> {
     private static final AboveMax INSTANCE = new AboveMax();
 
-    private AboveMax() {
-    }
+    private AboveMax() {}
 
     @Override
     public T value() {
@@ -198,8 +195,7 @@ class Literals {
   static class BelowMin<T> implements Literal<T> {
     private static final BelowMin INSTANCE = new BelowMin();
 
-    private BelowMin() {
-    }
+    private BelowMin() {}
 
     @Override
     public T value() {
@@ -264,8 +260,8 @@ class Literals {
         case DECIMAL:
           int scale = ((Types.DecimalType) type).scale();
           // rounding mode isn't necessary, but pass one to avoid warnings
-          return (Literal<T>) new DecimalLiteral(
-              BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
+          return (Literal<T>)
+              new DecimalLiteral(BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
         default:
           return null;
       }
@@ -303,6 +299,9 @@ class Literals {
           return (Literal<T>) new TimeLiteral(value());
         case TIMESTAMP:
           return (Literal<T>) new TimestampLiteral(value());
+        case TIMESTAMP_NANO:
+          // assume micros and convert to nanos to match the behavior in the timestamp case above
+          return new TimestampLiteral(value()).to(type);
         case DATE:
           if ((long) Integer.MAX_VALUE < value()) {
             return aboveMax();
@@ -313,8 +312,8 @@ class Literals {
         case DECIMAL:
           int scale = ((Types.DecimalType) type).scale();
           // rounding mode isn't necessary, but pass one to avoid warnings
-          return (Literal<T>) new DecimalLiteral(
-              BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
+          return (Literal<T>)
+              new DecimalLiteral(BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
         default:
           return null;
       }
@@ -341,8 +340,8 @@ class Literals {
           return (Literal<T>) new DoubleLiteral(value().doubleValue());
         case DECIMAL:
           int scale = ((Types.DecimalType) type).scale();
-          return (Literal<T>) new DecimalLiteral(
-              BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
+          return (Literal<T>)
+              new DecimalLiteral(BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
         default:
           return null;
       }
@@ -376,8 +375,8 @@ class Literals {
           return (Literal<T>) this;
         case DECIMAL:
           int scale = ((Types.DecimalType) type).scale();
-          return (Literal<T>) new DecimalLiteral(
-              BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
+          return (Literal<T>)
+              new DecimalLiteral(BigDecimal.valueOf(value()).setScale(scale, RoundingMode.HALF_UP));
         default:
           return null;
       }
@@ -441,8 +440,9 @@ class Literals {
         case TIMESTAMP:
           return (Literal<T>) this;
         case DATE:
-          return (Literal<T>) new DateLiteral((int) ChronoUnit.DAYS.between(
-              EPOCH_DAY, EPOCH.plus(value(), ChronoUnit.MICROS).toLocalDate()));
+          return (Literal<T>) new DateLiteral(DateTimeUtil.microsToDays(value()));
+        case TIMESTAMP_NANO:
+          return (Literal<T>) new TimestampNanoLiteral(DateTimeUtil.microsToNanos(value()));
         default:
       }
       return null;
@@ -454,6 +454,32 @@ class Literals {
     }
   }
 
+  static class TimestampNanoLiteral extends ComparableLiteral<Long> {
+    TimestampNanoLiteral(Long value) {
+      super(value);
+    }
+
+    @Override
+    @SuppressWarnings("unchecked")
+    public <T> Literal<T> to(Type type) {
+      switch (type.typeId()) {
+        case DATE:
+          return (Literal<T>) new DateLiteral(DateTimeUtil.nanosToDays(value()));
+        case TIMESTAMP:
+          return (Literal<T>) new TimestampLiteral(DateTimeUtil.nanosToMicros(value()));
+        case TIMESTAMP_NANO:
+          return (Literal<T>) this;
+        default:
+      }
+      return null;
+    }
+
+    @Override
+    protected Type.TypeID typeId() {
+      return Type.TypeID.TIMESTAMP_NANO;
+    }
+  }
+
   static class DecimalLiteral extends ComparableLiteral<BigDecimal> {
     DecimalLiteral(BigDecimal value) {
       super(value);
@@ -490,27 +516,34 @@ class Literals {
     public <T> Literal<T> to(Type type) {
       switch (type.typeId()) {
         case DATE:
-          int date = (int) ChronoUnit.DAYS.between(EPOCH_DAY,
-              LocalDate.parse(value(), DateTimeFormatter.ISO_LOCAL_DATE));
+          int date =
+              (int)
+                  ChronoUnit.DAYS.between(
+                      EPOCH_DAY, LocalDate.parse(value(), DateTimeFormatter.ISO_LOCAL_DATE));
           return (Literal<T>) new DateLiteral(date);
 
         case TIME:
-          long timeMicros = LocalTime.parse(value(), DateTimeFormatter.ISO_LOCAL_TIME)
-              .toNanoOfDay() / 1000;
+          long timeMicros =
+              LocalTime.parse(value(), DateTimeFormatter.ISO_LOCAL_TIME).toNanoOfDay() / 1000;
           return (Literal<T>) new TimeLiteral(timeMicros);
 
         case TIMESTAMP:
           if (((Types.TimestampType) type).shouldAdjustToUTC()) {
-            long timestampMicros = ChronoUnit.MICROS.between(EPOCH,
-                OffsetDateTime.parse(value(), DateTimeFormatter.ISO_DATE_TIME));
+            long timestampMicros = DateTimeUtil.isoTimestamptzToMicros(value().toString());
             return (Literal<T>) new TimestampLiteral(timestampMicros);
           } else {
-            long timestampMicros = ChronoUnit.MICROS.between(EPOCH,
-                LocalDateTime.parse(value(), DateTimeFormatter.ISO_LOCAL_DATE_TIME)
-                    .atOffset(ZoneOffset.UTC));
+            long timestampMicros = DateTimeUtil.isoTimestampToMicros(value().toString());
             return (Literal<T>) new TimestampLiteral(timestampMicros);
           }
 
+        case TIMESTAMP_NANO:
+          if (((Types.TimestampNanoType) type).shouldAdjustToUTC()) {
+            return (Literal<T>)
+                new TimestampNanoLiteral(DateTimeUtil.isoTimestamptzToNanos(value()));
+          } else {
+            return (Literal<T>) new TimestampNanoLiteral(DateTimeUtil.isoTimestampToNanos(value()));
+          }
+
         case STRING:
           return (Literal<T>) this;
 
