@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.util;
 
 import java.util.List;
@@ -33,8 +32,8 @@ import org.apache.iceberg.types.Types.StructType;
 public class StructProjection implements StructLike {
   /**
    * Creates a projecting wrapper for {@link StructLike} rows.
-   * <p>
-   * This projection does not work with repeated types like lists and maps.
+   *
+   * <p>This projection does not work with repeated types like lists and maps.
    *
    * @param schema schema of rows wrapped by this projection
    * @param ids field ids from the row schema to project
@@ -47,8 +46,8 @@ public class StructProjection implements StructLike {
 
   /**
    * Creates a projecting wrapper for {@link StructLike} rows.
-   * <p>
-   * This projection does not work with repeated types like lists and maps.
+   *
+   * <p>This projection does not work with repeated types like lists and maps.
    *
    * @param dataSchema schema of rows wrapped by this projection
    * @param projectedSchema result schema of the projected rows
@@ -60,8 +59,8 @@ public class StructProjection implements StructLike {
 
   /**
    * Creates a projecting wrapper for {@link StructLike} rows.
-   * <p>
-   * This projection does not work with repeated types like lists and maps.
+   *
+   * <p>This projection does not work with repeated types like lists and maps.
    *
    * @param structType type of rows wrapped by this projection
    * @param projectedStructType result type of the projected rows
@@ -73,14 +72,16 @@ public class StructProjection implements StructLike {
 
   /**
    * Creates a projecting wrapper for {@link StructLike} rows.
-   * <p>
-   * This projection allows missing fields and does not work with repeated types like lists and maps.
+   *
+   * <p>This projection allows missing fields and does not work with repeated types like lists and
+   * maps.
    *
    * @param structType type of rows wrapped by this projection
    * @param projectedStructType result type of the projected rows
    * @return a wrapper to project rows
    */
-  public static StructProjection createAllowMissing(StructType structType, StructType projectedStructType) {
+  public static StructProjection createAllowMissing(
+      StructType structType, StructType projectedStructType) {
     return new StructProjection(structType, projectedStructType, true);
   }
 
@@ -89,6 +90,13 @@ public class StructProjection implements StructLike {
   private final StructProjection[] nestedProjections;
   private StructLike struct;
 
+  private StructProjection(
+      StructType type, int[] positionMap, StructProjection[] nestedProjections) {
+    this.type = type;
+    this.positionMap = positionMap;
+    this.nestedProjections = nestedProjections;
+  }
+
   private StructProjection(StructType structType, StructType projection) {
     this(structType, projection, false);
   }
@@ -112,20 +120,25 @@ public class StructProjection implements StructLike {
           positionMap[pos] = i;
           switch (projectedField.type().typeId()) {
             case STRUCT:
-              nestedProjections[pos] = new StructProjection(
-                  dataField.type().asStructType(), projectedField.type().asStructType());
+              nestedProjections[pos] =
+                  new StructProjection(
+                      dataField.type().asStructType(), projectedField.type().asStructType());
               break;
             case MAP:
               MapType projectedMap = projectedField.type().asMapType();
               MapType originalMap = dataField.type().asMapType();
 
-              boolean keyProjectable = !projectedMap.keyType().isNestedType() ||
-                  projectedMap.keyType().equals(originalMap.keyType());
-              boolean valueProjectable = !projectedMap.valueType().isNestedType() ||
-                  projectedMap.valueType().equals(originalMap.valueType());
-              Preconditions.checkArgument(keyProjectable && valueProjectable,
+              boolean keyProjectable =
+                  !projectedMap.keyType().isNestedType()
+                      || projectedMap.keyType().equals(originalMap.keyType());
+              boolean valueProjectable =
+                  !projectedMap.valueType().isNestedType()
+                      || projectedMap.valueType().equals(originalMap.valueType());
+              Preconditions.checkArgument(
+                  keyProjectable && valueProjectable,
                   "Cannot project a partial map key or value struct. Trying to project %s out of %s",
-                  projectedField, dataField);
+                  projectedField,
+                  dataField);
 
               nestedProjections[pos] = null;
               break;
@@ -133,11 +146,14 @@ public class StructProjection implements StructLike {
               ListType projectedList = projectedField.type().asListType();
               ListType originalList = dataField.type().asListType();
 
-              boolean elementProjectable = !projectedList.elementType().isNestedType() ||
-                  projectedList.elementType().equals(originalList.elementType());
-              Preconditions.checkArgument(elementProjectable,
+              boolean elementProjectable =
+                  !projectedList.elementType().isNestedType()
+                      || projectedList.elementType().equals(originalList.elementType());
+              Preconditions.checkArgument(
+                  elementProjectable,
                   "Cannot project a partial list element struct. Trying to project %s out of %s",
-                  projectedField, dataField);
+                  projectedField,
+                  dataField);
 
               nestedProjections[pos] = null;
               break;
@@ -151,7 +167,8 @@ public class StructProjection implements StructLike {
         positionMap[pos] = -1;
         nestedProjections[pos] = null;
       } else if (!found) {
-        throw new IllegalArgumentException(String.format("Cannot find field %s in %s", projectedField, structType));
+        throw new IllegalArgumentException(
+            String.format("Cannot find field %s in %s", projectedField, structType));
       }
     }
   }
@@ -161,6 +178,10 @@ public class StructProjection implements StructLike {
     return this;
   }
 
+  public StructProjection copyFor(StructLike newStruct) {
+    return new StructProjection(type, positionMap, nestedProjections).wrap(newStruct);
+  }
+
   @Override
   public int size() {
     return type.fields().size();
@@ -168,16 +189,20 @@ public class StructProjection implements StructLike {
 
   @Override
   public <T> T get(int pos, Class<T> javaClass) {
+    // struct can be null if wrap is not called first before the get call
+    // or if a null struct is wrapped.
     if (struct == null) {
-      // Return a null struct when projecting a nested required field from an optional struct.
-      // See more details in issue #2738.
       return null;
     }
 
     int structPos = positionMap[pos];
-
     if (nestedProjections[pos] != null) {
-      return javaClass.cast(nestedProjections[pos].wrap(struct.get(structPos, StructLike.class)));
+      StructLike nestedStruct = struct.get(structPos, StructLike.class);
+      if (nestedStruct == null) {
+        return null;
+      }
+
+      return javaClass.cast(nestedProjections[pos].wrap(nestedStruct));
     }
 
     if (structPos != -1) {
