@@ -28,12 +28,14 @@ import org.apache.iceberg.LockManager;
 import org.apache.iceberg.TableMetadata;
 import org.apache.iceberg.aws.AwsProperties;
 import org.apache.iceberg.aws.s3.S3FileIO;
+import org.apache.iceberg.aws.util.RetryDetector;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.common.DynMethods;
 import org.apache.iceberg.exceptions.AlreadyExistsException;
 import org.apache.iceberg.exceptions.CommitFailedException;
 import org.apache.iceberg.exceptions.CommitStateUnknownException;
 import org.apache.iceberg.exceptions.ForbiddenException;
+import org.apache.iceberg.exceptions.NoSuchIcebergTableException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
 import org.apache.iceberg.exceptions.NotFoundException;
 import org.apache.iceberg.exceptions.ValidationException;
@@ -44,6 +46,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import software.amazon.awssdk.awscore.exception.AwsServiceException;
 import software.amazon.awssdk.services.glue.GlueClient;
+import software.amazon.awssdk.services.glue.model.AccessDeniedException;
 import software.amazon.awssdk.services.glue.model.ConcurrentModificationException;
 import software.amazon.awssdk.services.glue.model.CreateTableRequest;
 import software.amazon.awssdk.services.glue.model.DeleteTableRequest;
@@ -124,7 +127,7 @@ class GlueTableOperations extends BaseMetastoreTableOperations {
     String metadataLocation = null;
     Table table = getGlueTable();
     if (table != null) {
-      GlueToIcebergConverter.validateTable(table, tableName());
+      checkIfTableIsIceberg(table, tableName());
       metadataLocation = table.parameters().get(METADATA_LOCATION_PROP);
     } else {
       if (currentMetadataLocation() != null) {
@@ -141,58 +144,42 @@ class GlueTableOperations extends BaseMetastoreTableOperations {
   @Override
   protected void doCommit(TableMetadata base, TableMetadata metadata) {
     CommitStatus commitStatus = CommitStatus.FAILURE;
+    RetryDetector retryDetector = new RetryDetector();
 
     String newMetadataLocation = null;
     boolean glueTempTableCreated = false;
     try {
       glueTempTableCreated = createGlueTempTableIfNecessary(base, metadata.location());
 
-      newMetadataLocation = writeNewMetadata(metadata, currentVersion() + 1);
+      boolean newTable = base == null;
+      newMetadataLocation = writeNewMetadataIfRequired(newTable, metadata);
       lock(newMetadataLocation);
       Table glueTable = getGlueTable();
       checkMetadataLocation(glueTable, base);
       Map<String, String> properties = prepareProperties(glueTable, newMetadataLocation);
-      persistGlueTable(glueTable, properties, metadata);
+      persistGlueTable(glueTable, properties, metadata, retryDetector);
       commitStatus = CommitStatus.SUCCESS;
     } catch (CommitFailedException e) {
       throw e;
-    } catch (ConcurrentModificationException e) {
-      throw new CommitFailedException(
-          e, "Cannot commit %s because Glue detected concurrent update", tableName());
-    } catch (software.amazon.awssdk.services.glue.model.AlreadyExistsException e) {
-      throw new AlreadyExistsException(
-          e,
-          "Cannot commit %s because its Glue table already exists when trying to create one",
-          tableName());
-    } catch (EntityNotFoundException e) {
-      throw new NotFoundException(
-          e, "Cannot commit %s because Glue cannot find the requested entity", tableName());
-    } catch (software.amazon.awssdk.services.glue.model.AccessDeniedException e) {
-      throw new ForbiddenException(
-          e, "Cannot commit %s because Glue cannot access the requested resources", tableName());
-    } catch (software.amazon.awssdk.services.glue.model.ValidationException e) {
-      throw new ValidationException(
-          e,
-          "Cannot commit %s because Glue encountered a validation exception "
-              + "while accessing requested resources",
-          tableName());
     } catch (RuntimeException persistFailure) {
-      LOG.error(
-          "Confirming if commit to {} indeed failed to persist, attempting to reconnect and check.",
-          fullTableName,
-          persistFailure);
+      boolean isAwsServiceException = persistFailure instanceof AwsServiceException;
 
-      if (persistFailure instanceof AwsServiceException) {
-        int statusCode = ((AwsServiceException) persistFailure).statusCode();
-        if (statusCode >= 500 && statusCode < 600) {
-          commitStatus = CommitStatus.FAILURE;
-        } else {
-          throw persistFailure;
-        }
-      } else {
+      // If we got an exception we weren't expecting, or we got an AWS service exception
+      // but retries were performed, attempt to reconcile the actual commit status.
+      if (!isAwsServiceException || retryDetector.retried()) {
+        LOG.warn(
+            "Received unexpected failure when committing to {}, validating if commit ended up succeeding.",
+            fullTableName,
+            persistFailure);
         commitStatus = checkCommitStatus(newMetadataLocation, metadata);
       }
 
+      // If we got an AWS exception we would usually handle, but find we
+      // succeeded on a retry that threw an exception, skip the exception.
+      if (commitStatus != CommitStatus.SUCCESS && isAwsServiceException) {
+        handleAWSExceptions((AwsServiceException) persistFailure);
+      }
+
       switch (commitStatus) {
         case SUCCESS:
           break;
@@ -208,6 +195,24 @@ class GlueTableOperations extends BaseMetastoreTableOperations {
     }
   }
 
+  /**
+   * Validate the Glue table is Iceberg table by checking its parameters. If the table properties
+   * check does not pass, for Iceberg it is equivalent to not having a table in the catalog. We
+   * throw a {@link NoSuchIcebergTableException} in that case.
+   *
+   * @param table glue table
+   * @param fullName full table name for logging
+   * @throws NoSuchIcebergTableException if the table is not an Iceberg table
+   */
+  static void checkIfTableIsIceberg(Table table, String fullName) {
+    String tableType = table.parameters().get(TABLE_TYPE_PROP);
+    NoSuchIcebergTableException.check(
+        tableType != null && tableType.equalsIgnoreCase(ICEBERG_TABLE_TYPE_VALUE),
+        "Input Glue table is not an iceberg table: %s (type=%s)",
+        fullName,
+        tableType);
+  }
+
   protected static FileIO initializeFileIO(Map<String, String> properties, Object hadoopConf) {
     String fileIOImpl = properties.get(CatalogProperties.FILE_IO_IMPL);
     if (fileIOImpl == null) {
@@ -296,11 +301,16 @@ class GlueTableOperations extends BaseMetastoreTableOperations {
   }
 
   @VisibleForTesting
-  void persistGlueTable(Table glueTable, Map<String, String> parameters, TableMetadata metadata) {
+  void persistGlueTable(
+      Table glueTable,
+      Map<String, String> parameters,
+      TableMetadata metadata,
+      RetryDetector retryDetector) {
     if (glueTable != null) {
       LOG.debug("Committing existing Glue table: {}", tableName());
       UpdateTableRequest.Builder updateTableRequest =
           UpdateTableRequest.builder()
+              .overrideConfiguration(c -> c.addMetricPublisher(retryDetector))
               .catalogId(awsProperties.glueCatalogId())
               .databaseName(databaseName)
               .skipArchive(awsProperties.glueCatalogSkipArchive())
@@ -308,7 +318,8 @@ class GlueTableOperations extends BaseMetastoreTableOperations {
                   TableInput.builder()
                       .applyMutation(
                           builder ->
-                              IcebergToGlueConverter.setTableInputInformation(builder, metadata))
+                              IcebergToGlueConverter.setTableInputInformation(
+                                  builder, metadata, glueTable))
                       .name(tableName)
                       .tableType(GLUE_EXTERNAL_TABLE_TYPE)
                       .parameters(parameters)
@@ -323,6 +334,7 @@ class GlueTableOperations extends BaseMetastoreTableOperations {
       LOG.debug("Committing new Glue table: {}", tableName());
       glue.createTable(
           CreateTableRequest.builder()
+              .overrideConfiguration(c -> c.addMetricPublisher(retryDetector))
               .catalogId(awsProperties.glueCatalogId())
               .databaseName(databaseName)
               .tableInput(
@@ -338,6 +350,41 @@ class GlueTableOperations extends BaseMetastoreTableOperations {
     }
   }
 
+  private void handleAWSExceptions(AwsServiceException persistFailure) {
+    if (persistFailure instanceof ConcurrentModificationException) {
+      throw new CommitFailedException(
+          persistFailure, "Cannot commit %s because Glue detected concurrent update", tableName());
+    } else if (persistFailure
+        instanceof software.amazon.awssdk.services.glue.model.AlreadyExistsException) {
+      throw new AlreadyExistsException(
+          persistFailure,
+          "Cannot commit %s because its Glue table already exists when trying to create one",
+          tableName());
+    } else if (persistFailure instanceof EntityNotFoundException) {
+      throw new NotFoundException(
+          persistFailure,
+          "Cannot commit %s because Glue cannot find the requested entity",
+          tableName());
+    } else if (persistFailure instanceof AccessDeniedException) {
+      throw new ForbiddenException(
+          persistFailure,
+          "Cannot commit %s because Glue cannot access the requested resources",
+          tableName());
+    } else if (persistFailure
+        instanceof software.amazon.awssdk.services.glue.model.ValidationException) {
+      throw new ValidationException(
+          persistFailure,
+          "Cannot commit %s because Glue encountered a validation exception "
+              + "while accessing requested resources",
+          tableName());
+    } else {
+      int statusCode = persistFailure.statusCode();
+      if (statusCode < 500 || statusCode >= 600) {
+        throw persistFailure;
+      }
+    }
+  }
+
   @VisibleForTesting
   void cleanupMetadataAndUnlock(CommitStatus commitStatus, String metadataLocation) {
     try {
