@@ -48,8 +48,10 @@ import software.amazon.awssdk.core.retry.conditions.OrRetryCondition;
 import software.amazon.awssdk.core.retry.conditions.RetryCondition;
 import software.amazon.awssdk.core.retry.conditions.RetryOnExceptionsCondition;
 import software.amazon.awssdk.core.retry.conditions.TokenBucketRetryCondition;
+import software.amazon.awssdk.services.s3.S3AsyncClientBuilder;
 import software.amazon.awssdk.services.s3.S3ClientBuilder;
 import software.amazon.awssdk.services.s3.S3Configuration;
+import software.amazon.awssdk.services.s3.S3CrtAsyncClientBuilder;
 import software.amazon.awssdk.services.s3.model.ObjectCannedACL;
 import software.amazon.awssdk.services.s3.model.Tag;
 
@@ -72,6 +74,43 @@ public class S3FileIOProperties implements Serializable {
 
   public static final boolean S3_ACCESS_GRANTS_ENABLED_DEFAULT = false;
 
+  /**
+   * This property is used to enable using the S3 Analytics Accelerator library to accelerate data
+   * access from client applications to Amazon S3.
+   *
+   * <p>For more details, see: https://github.com/awslabs/analytics-accelerator-s3
+   */
+  public static final String S3_ANALYTICS_ACCELERATOR_ENABLED = "s3.analytics-accelerator.enabled";
+
+  public static final boolean S3_ANALYTICS_ACCELERATOR_ENABLED_DEFAULT = false;
+
+  /**
+   * This prefix allows users to configure the internal properties of the s3 analytics accelerator.
+   *
+   * <p>Example: s3.analytics-accelerator.logicalio.prefetching.mode=all
+   *
+   * <p>For more details, see:
+   * https://github.com/awslabs/analytics-accelerator-s3/blob/main/doc/CONFIGURATION.md
+   */
+  public static final String S3_ANALYTICS_ACCELERATOR_PROPERTIES_PREFIX =
+      "s3.analytics-accelerator.";
+
+  /** This property is used to specify if the S3 Async clients should be created using CRT. */
+  public static final String S3_CRT_ENABLED = "s3.crt.enabled";
+
+  public static final boolean S3_CRT_ENABLED_DEFAULT = true;
+
+  /** This property is used to specify the max concurrency for S3 CRT clients. */
+  public static final String S3_CRT_MAX_CONCURRENCY = "s3.crt.max-concurrency";
+
+  /**
+   * To fully benefit from the analytics-accelerator-s3 library where this S3 CRT client is used, it
+   * is recommended to initialize with higher concurrency.
+   *
+   * <p>For more details, see: https://github.com/awslabs/analytics-accelerator-s3
+   */
+  public static final int S3_CRT_MAX_CONCURRENCY_DEFAULT = 500;
+
   /**
    * The fallback-to-iam property allows users to customize whether or not they would like their
    * jobs fall back to the Job Execution IAM role in case they get an Access Denied from the S3
@@ -484,6 +523,10 @@ public class S3FileIOProperties implements Serializable {
   private final boolean isAccelerationEnabled;
   private final String endpoint;
   private final boolean isRemoteSigningEnabled;
+  private final boolean isS3AnalyticsAcceleratorEnabled;
+  private final Map<String, String> s3AnalyticsacceleratorProperties;
+  private final boolean isS3CRTEnabled;
+  private final int s3CrtMaxConcurrency;
   private String writeStorageClass;
   private int s3RetryNumRetries;
   private long s3RetryMinWaitMs;
@@ -528,6 +571,10 @@ public class S3FileIOProperties implements Serializable {
     this.s3RetryMaxWaitMs = S3_RETRY_MAX_WAIT_MS_DEFAULT;
     this.s3DirectoryBucketListPrefixAsDirectory =
         S3_DIRECTORY_BUCKET_LIST_PREFIX_AS_DIRECTORY_DEFAULT;
+    this.isS3AnalyticsAcceleratorEnabled = S3_ANALYTICS_ACCELERATOR_ENABLED_DEFAULT;
+    this.s3AnalyticsacceleratorProperties = Maps.newHashMap();
+    this.isS3CRTEnabled = S3_CRT_ENABLED_DEFAULT;
+    this.s3CrtMaxConcurrency = S3_CRT_MAX_CONCURRENCY_DEFAULT;
     this.allProperties = Maps.newHashMap();
 
     ValidationException.check(
@@ -640,6 +687,16 @@ public class S3FileIOProperties implements Serializable {
             properties,
             S3_DIRECTORY_BUCKET_LIST_PREFIX_AS_DIRECTORY,
             S3_DIRECTORY_BUCKET_LIST_PREFIX_AS_DIRECTORY_DEFAULT);
+    this.isS3AnalyticsAcceleratorEnabled =
+        PropertyUtil.propertyAsBoolean(
+            properties, S3_ANALYTICS_ACCELERATOR_ENABLED, S3_ANALYTICS_ACCELERATOR_ENABLED_DEFAULT);
+    this.s3AnalyticsacceleratorProperties =
+        PropertyUtil.propertiesWithPrefix(properties, S3_ANALYTICS_ACCELERATOR_PROPERTIES_PREFIX);
+    this.isS3CRTEnabled =
+        PropertyUtil.propertyAsBoolean(properties, S3_CRT_ENABLED, S3_CRT_ENABLED_DEFAULT);
+    this.s3CrtMaxConcurrency =
+        PropertyUtil.propertyAsInt(
+            properties, S3_CRT_MAX_CONCURRENCY, S3_CRT_MAX_CONCURRENCY_DEFAULT);
 
     ValidationException.check(
         keyIdAccessKeyBothConfigured(),
@@ -754,6 +811,22 @@ public class S3FileIOProperties implements Serializable {
     return this.isRemoteSigningEnabled;
   }
 
+  public boolean isS3AnalyticsAcceleratorEnabled() {
+    return isS3AnalyticsAcceleratorEnabled;
+  }
+
+  public Map<String, String> s3AnalyticsacceleratorProperties() {
+    return s3AnalyticsacceleratorProperties;
+  }
+
+  public boolean isS3CRTEnabled() {
+    return isS3CRTEnabled;
+  }
+
+  public int s3CrtMaxConcurrency() {
+    return s3CrtMaxConcurrency;
+  }
+
   public String endpoint() {
     return this.endpoint;
   }
@@ -953,6 +1026,36 @@ public class S3FileIOProperties implements Serializable {
     }
   }
 
+  /**
+   * Override the endpoint for an S3 async client
+   *
+   * <p>Sample usage:
+   *
+   * <pre>
+   *     S3AsyncClient.builder().applyMutation(s3FileIOProperties::applyEndpointConfigurations)
+   * </pre>
+   */
+  public <T extends S3AsyncClientBuilder> void applyEndpointConfigurations(T builder) {
+    if (endpoint != null) {
+      builder.endpointOverride(URI.create(endpoint));
+    }
+  }
+
+  /**
+   * Override the endpoint for an S3 CRT client
+   *
+   * <p>Sample usage:
+   *
+   * <pre>
+   *     S3AsyncClient.crtBuilder().applyMutation(s3FileIOProperties::applyEndpointConfigurations)
+   * </pre>
+   */
+  public <T extends S3CrtAsyncClientBuilder> void applyEndpointConfigurations(T builder) {
+    if (endpoint != null) {
+      builder.endpointOverride(URI.create(endpoint));
+    }
+  }
+
   /**
    * Override the retry configurations for an S3 client.
    *
@@ -1047,6 +1150,10 @@ public class S3FileIOProperties implements Serializable {
             .build());
   }
 
+  public S3CrtAsyncClientBuilder applyS3CrtConfigurations(S3CrtAsyncClientBuilder builder) {
+    return builder.maxConcurrency(s3CrtMaxConcurrency());
+  }
+
   /**
    * Dynamically load the http client builder to avoid runtime deps requirements of any optional SDK
    * Plugins
