@@ -22,10 +22,9 @@ import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.ByteArrayInputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.OutputStream;
 import java.io.SequenceInputStream;
 import java.io.UncheckedIOException;
 import java.nio.file.Files;
@@ -77,7 +76,7 @@ import software.amazon.awssdk.utils.BinaryUtils;
 
 class S3OutputStream extends PositionOutputStream {
   private static final Logger LOG = LoggerFactory.getLogger(S3OutputStream.class);
-  private static final String digestAlgorithm = "MD5";
+  private static final String DIGEST_ALGORITHM = "MD5";
 
   private static volatile ExecutorService executorService;
 
@@ -139,7 +138,7 @@ class S3OutputStream extends PositionOutputStream {
     this.isChecksumEnabled = s3FileIOProperties.isChecksumEnabled();
     try {
       this.completeMessageDigest =
-          isChecksumEnabled ? MessageDigest.getInstance(digestAlgorithm) : null;
+          isChecksumEnabled ? MessageDigest.getInstance(DIGEST_ALGORITHM) : null;
     } catch (NoSuchAlgorithmException e) {
       throw new RuntimeException(
           "Failed to create message digest needed for s3 checksum checks", e);
@@ -221,13 +220,14 @@ class S3OutputStream extends PositionOutputStream {
     currentStagingFile.deleteOnExit();
     try {
       currentPartMessageDigest =
-          isChecksumEnabled ? MessageDigest.getInstance(digestAlgorithm) : null;
+          isChecksumEnabled ? MessageDigest.getInstance(DIGEST_ALGORITHM) : null;
     } catch (NoSuchAlgorithmException e) {
       throw new RuntimeException(
           "Failed to create message digest needed for s3 checksum checks.", e);
     }
 
     stagingFiles.add(new FileAndDigest(currentStagingFile, currentPartMessageDigest));
+    OutputStream outputStream = Files.newOutputStream(currentStagingFile.toPath());
 
     if (isChecksumEnabled) {
       DigestOutputStream digestOutputStream;
@@ -236,27 +236,27 @@ class S3OutputStream extends PositionOutputStream {
       if (multipartUploadId != null) {
         digestOutputStream =
             new DigestOutputStream(
-                new BufferedOutputStream(new FileOutputStream(currentStagingFile)),
-                currentPartMessageDigest);
+                new BufferedOutputStream(outputStream), currentPartMessageDigest);
       } else {
         digestOutputStream =
             new DigestOutputStream(
                 new DigestOutputStream(
-                    new BufferedOutputStream(new FileOutputStream(currentStagingFile)),
-                    currentPartMessageDigest),
+                    new BufferedOutputStream(outputStream), currentPartMessageDigest),
                 completeMessageDigest);
       }
 
       stream = new CountingOutputStream(digestOutputStream);
     } else {
-      stream =
-          new CountingOutputStream(
-              new BufferedOutputStream(new FileOutputStream(currentStagingFile)));
+      stream = new CountingOutputStream(new BufferedOutputStream(outputStream));
     }
   }
 
   @Override
   public void close() throws IOException {
+    close(true);
+  }
+
+  private void close(boolean completeUploads) throws IOException {
     if (closed) {
       return;
     }
@@ -266,7 +266,9 @@ class S3OutputStream extends PositionOutputStream {
 
     try {
       stream.close();
-      completeUploads();
+      if (completeUploads) {
+        completeUploads();
+      }
     } finally {
       cleanUpStagingFiles();
     }
@@ -278,6 +280,9 @@ class S3OutputStream extends PositionOutputStream {
     if (writeTags != null && !writeTags.isEmpty()) {
       requestBuilder.tagging(Tagging.builder().tagSet(writeTags).build());
     }
+    if (s3FileIOProperties.writeStorageClass() != null) {
+      requestBuilder.storageClass(s3FileIOProperties.writeStorageClass());
+    }
 
     S3RequestUtil.configureEncryption(s3FileIOProperties, requestBuilder);
     S3RequestUtil.configurePermission(s3FileIOProperties, requestBuilder);
@@ -425,6 +430,10 @@ class S3OutputStream extends PositionOutputStream {
         requestBuilder.tagging(Tagging.builder().tagSet(writeTags).build());
       }
 
+      if (s3FileIOProperties.writeStorageClass() != null) {
+        requestBuilder.storageClass(s3FileIOProperties.writeStorageClass());
+      }
+
       if (isChecksumEnabled) {
         requestBuilder.contentMD5(BinaryUtils.toBase64(completeMessageDigest.digest()));
       }
@@ -444,7 +453,7 @@ class S3OutputStream extends PositionOutputStream {
 
   private static InputStream uncheckedInputStream(File file) {
     try {
-      return new FileInputStream(file);
+      return Files.newInputStream(file.toPath());
     } catch (IOException e) {
       throw new UncheckedIOException(e);
     }
@@ -472,12 +481,12 @@ class S3OutputStream extends PositionOutputStream {
     }
   }
 
-  @SuppressWarnings("checkstyle:NoFinalizer")
+  @SuppressWarnings({"checkstyle:NoFinalizer", "Finalize"})
   @Override
   protected void finalize() throws Throwable {
     super.finalize();
     if (!closed) {
-      close(); // releasing resources is more important than printing the warning
+      close(false); // releasing resources is more important than printing the warning
       String trace = Joiner.on("\n\t").join(Arrays.copyOfRange(createStack, 1, createStack.length));
       LOG.warn("Unclosed output stream created by:\n\t{}", trace);
     }
