@@ -122,6 +122,8 @@ public class AwsClientPropertiesTest {
     AwsClientProperties awsClientProperties =
         new AwsClientProperties(
             ImmutableMap.of(
+                CatalogProperties.URI,
+                "http://localhost:1234/v1",
                 AwsClientProperties.REFRESH_CREDENTIALS_ENDPOINT,
                 "http://localhost:1234/v1/credentials"));
 
@@ -150,6 +152,8 @@ public class AwsClientPropertiesTest {
             ImmutableMap.of(
                 AwsClientProperties.REFRESH_CREDENTIALS_ENDPOINT,
                 "http://localhost:1234/v1/credentials",
+                CatalogProperties.URI,
+                "http://localhost:1234/v1/catalog",
                 OAuth2Properties.TOKEN,
                 "oauth-token"));
 
@@ -161,36 +165,41 @@ public class AwsClientPropertiesTest {
         .extracting("properties")
         .isEqualTo(
             ImmutableMap.of(
+                AwsClientProperties.REFRESH_CREDENTIALS_ENDPOINT,
+                "http://localhost:1234/v1/credentials",
                 "credentials.uri",
                 "http://localhost:1234/v1/credentials",
+                CatalogProperties.URI,
+                "http://localhost:1234/v1/catalog",
                 OAuth2Properties.TOKEN,
                 "oauth-token"));
   }
 
   @Test
   public void refreshCredentialsEndpointWithOverridingOAuthToken() {
-    AwsClientProperties awsClientProperties =
-        new AwsClientProperties(
-            ImmutableMap.of(
-                AwsClientProperties.REFRESH_CREDENTIALS_ENDPOINT,
-                "http://localhost:1234/v1/credentials",
-                OAuth2Properties.TOKEN,
-                "oauth-token",
-                "client.credentials-provider.token",
-                "specific-token"));
+    Map<String, String> properties =
+        ImmutableMap.of(
+            CatalogProperties.URI,
+            "http://localhost:1234/v1",
+            AwsClientProperties.REFRESH_CREDENTIALS_ENDPOINT,
+            "http://localhost:1234/v1/credentials",
+            OAuth2Properties.TOKEN,
+            "oauth-token",
+            "client.credentials-provider.token",
+            "specific-token");
+    AwsClientProperties awsClientProperties = new AwsClientProperties(properties);
+
+    Map<String, String> expectedProperties =
+        ImmutableMap.<String, String>builder()
+            .putAll(properties)
+            .put("credentials.uri", "http://localhost:1234/v1/credentials")
+            .build();
 
     AwsCredentialsProvider provider =
         awsClientProperties.credentialsProvider("key", "secret", "token");
     assertThat(provider).isInstanceOf(VendedCredentialsProvider.class);
     VendedCredentialsProvider vendedCredentialsProvider = (VendedCredentialsProvider) provider;
-    assertThat(vendedCredentialsProvider)
-        .extracting("properties")
-        .isEqualTo(
-            ImmutableMap.of(
-                "credentials.uri",
-                "http://localhost:1234/v1/credentials",
-                OAuth2Properties.TOKEN,
-                "specific-token"));
+    assertThat(vendedCredentialsProvider).extracting("properties").isEqualTo(expectedProperties);
   }
 
   @Test
@@ -213,8 +222,12 @@ public class AwsClientPropertiesTest {
         .extracting("properties")
         .isEqualTo(
             ImmutableMap.of(
+                CatalogProperties.URI,
+                "http://localhost:1234/v1",
                 "credentials.uri",
                 "http://localhost:1234/v1/relative/credentials/endpoint",
+                AwsClientProperties.REFRESH_CREDENTIALS_ENDPOINT,
+                "/relative/credentials/endpoint",
                 OAuth2Properties.TOKEN,
                 "oauth-token"));
   }
