@@ -18,13 +18,15 @@
  */
 package org.apache.iceberg.aws.glue;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.util.Map;
 import org.apache.iceberg.BaseMetastoreTableOperations;
 import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.exceptions.NoSuchIcebergTableException;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
 import software.amazon.awssdk.services.glue.model.Database;
 import software.amazon.awssdk.services.glue.model.Table;
@@ -35,21 +37,21 @@ public class TestGlueToIcebergConverter {
   public void testToNamespace() {
     Database database = Database.builder().name("db").build();
     Namespace namespace = Namespace.of("db");
-    Assertions.assertThat(GlueToIcebergConverter.toNamespace(database)).isEqualTo(namespace);
+    assertThat(GlueToIcebergConverter.toNamespace(database)).isEqualTo(namespace);
   }
 
   @Test
   public void testToTableId() {
     Table table = Table.builder().databaseName("db").name("name").build();
     TableIdentifier icebergId = TableIdentifier.of("db", "name");
-    Assertions.assertThat(GlueToIcebergConverter.toTableId(table)).isEqualTo(icebergId);
+    assertThat(GlueToIcebergConverter.toTableId(table)).isEqualTo(icebergId);
   }
 
   @Test
   public void testValidateTableIcebergPropertyNotFound() {
     Table table = Table.builder().parameters(ImmutableMap.of()).build();
 
-    Assertions.assertThatThrownBy(() -> GlueTableOperations.checkIfTableIsIceberg(table, "name"))
+    assertThatThrownBy(() -> GlueTableOperations.checkIfTableIsIceberg(table, "name"))
         .isInstanceOf(NoSuchIcebergTableException.class)
         .hasMessage("Input Glue table is not an iceberg table: name (type=null)");
   }
@@ -60,7 +62,7 @@ public class TestGlueToIcebergConverter {
         ImmutableMap.of(BaseMetastoreTableOperations.TABLE_TYPE_PROP, "other");
     Table table = Table.builder().parameters(properties).build();
 
-    Assertions.assertThatThrownBy(() -> GlueTableOperations.checkIfTableIsIceberg(table, "name"))
+    assertThatThrownBy(() -> GlueTableOperations.checkIfTableIsIceberg(table, "name"))
         .isInstanceOf(NoSuchIcebergTableException.class)
         .hasMessage("Input Glue table is not an iceberg table: name (type=other)");
   }
