@@ -20,6 +20,8 @@ package org.apache.iceberg.azure;
 
 import static org.apache.iceberg.azure.AzureProperties.ADLS_CONNECTION_STRING_PREFIX;
 import static org.apache.iceberg.azure.AzureProperties.ADLS_READ_BLOCK_SIZE;
+import static org.apache.iceberg.azure.AzureProperties.ADLS_REFRESH_CREDENTIALS_ENABLED;
+import static org.apache.iceberg.azure.AzureProperties.ADLS_REFRESH_CREDENTIALS_ENDPOINT;
 import static org.apache.iceberg.azure.AzureProperties.ADLS_SAS_TOKEN_PREFIX;
 import static org.apache.iceberg.azure.AzureProperties.ADLS_SHARED_KEY_ACCOUNT_KEY;
 import static org.apache.iceberg.azure.AzureProperties.ADLS_SHARED_KEY_ACCOUNT_NAME;
@@ -32,10 +34,15 @@ import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 
+import com.azure.core.credential.AzureSasCredential;
 import com.azure.core.credential.TokenCredential;
+import com.azure.identity.DefaultAzureCredential;
 import com.azure.storage.common.StorageSharedKeyCredential;
 import com.azure.storage.file.datalake.DataLakeFileSystemClientBuilder;
+import java.util.Optional;
+import org.apache.iceberg.CatalogProperties;
 import org.apache.iceberg.TestHelpers;
+import org.apache.iceberg.azure.adlsv2.VendedAdlsCredentialProvider;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.junit.jupiter.api.Test;
 
@@ -71,6 +78,45 @@ public class AzurePropertiesTest {
     verify(clientBuilder, never()).credential(any(StorageSharedKeyCredential.class));
   }
 
+  @Test
+  public void testWithRefreshCredentialsEndpoint() {
+    AzureProperties props =
+        new AzureProperties(
+            ImmutableMap.of(
+                ADLS_REFRESH_CREDENTIALS_ENDPOINT,
+                "endpoint",
+                CatalogProperties.URI,
+                "catalog-endpoint"));
+
+    DataLakeFileSystemClientBuilder clientBuilder = mock(DataLakeFileSystemClientBuilder.class);
+    props.applyClientConfiguration("account1", clientBuilder);
+    Optional<VendedAdlsCredentialProvider> vendedAdlsCredentialProvider =
+        props.vendedAdlsCredentialProvider();
+
+    verify(clientBuilder, never()).credential(any(AzureSasCredential.class));
+    verify(clientBuilder, never()).sasToken(any());
+    verify(clientBuilder, never()).credential(any(StorageSharedKeyCredential.class));
+    assertThat(vendedAdlsCredentialProvider).isPresent();
+  }
+
+  @Test
+  public void testWithRefreshCredentialsEndpointDisabled() {
+    AzureProperties props =
+        new AzureProperties(
+            ImmutableMap.of(
+                ADLS_REFRESH_CREDENTIALS_ENDPOINT,
+                "endpoint",
+                ADLS_REFRESH_CREDENTIALS_ENABLED,
+                "false"));
+
+    DataLakeFileSystemClientBuilder clientBuilder = mock(DataLakeFileSystemClientBuilder.class);
+    props.applyClientConfiguration("account1", clientBuilder);
+    Optional<VendedAdlsCredentialProvider> vendedAdlsCredentialProvider =
+        props.vendedAdlsCredentialProvider();
+    verify(clientBuilder).credential(any(DefaultAzureCredential.class));
+    assertThat(vendedAdlsCredentialProvider).isEmpty();
+  }
+
   @Test
   public void testNoMatchingSasToken() {
     AzureProperties props =
