@@ -34,6 +34,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Conversions;
 import org.apache.iceberg.types.Type;
+import org.apache.iceberg.types.TypeUtil;
 import org.apache.iceberg.types.Types;
 
 public class MetricsUtil {
@@ -101,13 +102,27 @@ public class MetricsUtil {
       return Maps.newHashMap();
     }
 
+    Map<Integer, Integer> parents = TypeUtil.indexParents(inputSchema.asStruct());
+
     return fieldMetrics
+        .filter(metrics -> !inMapOrList(inputSchema, parents, metrics.id()))
         .filter(
             metrics ->
                 metricsMode(inputSchema, metricsConfig, metrics.id()) != MetricsModes.None.get())
         .collect(Collectors.toMap(FieldMetrics::id, FieldMetrics::nanValueCount));
   }
 
+  private static boolean inMapOrList(Schema schema, Map<Integer, Integer> parents, int id) {
+    Integer current = id;
+    while ((current = parents.get(current)) != null) {
+      if (schema.findField(current).type().typeId() != Type.TypeID.STRUCT) {
+        return true;
+      }
+    }
+
+    return false;
+  }
+
   /** Extract MetricsMode for the given field id from metrics config. */
   public static MetricsModes.MetricsMode metricsMode(
       Schema inputSchema, MetricsConfig metricsConfig, int fieldId) {
@@ -346,18 +361,21 @@ public class MetricsUtil {
         String colName = idToName.get(id);
 
         fields.add(
-            Types.NestedField.of(
-                nextId.incrementAndGet(),
-                true,
-                colName,
-                Types.StructType.of(
-                    READABLE_METRIC_COLS.stream()
-                        .map(
-                            m ->
-                                optional(
-                                    nextId.incrementAndGet(), m.name(), m.colType(field), m.doc()))
-                        .collect(Collectors.toList())),
-                String.format("Metrics for column %s", colName)));
+            Types.NestedField.optional(colName)
+                .withId(nextId.incrementAndGet())
+                .ofType(
+                    Types.StructType.of(
+                        READABLE_METRIC_COLS.stream()
+                            .map(
+                                m ->
+                                    optional(
+                                        nextId.incrementAndGet(),
+                                        m.name(),
+                                        m.colType(field),
+                                        m.doc()))
+                            .collect(Collectors.toList())))
+                .withDoc(String.format("Metrics for column %s", colName))
+                .build());
       }
     }
 
