@@ -131,9 +131,8 @@ public class RewriteTablePathUtil {
         updatePathInStatisticsFiles(metadata.statisticsFiles(), sourcePrefix, targetPrefix),
         // TODO: update partition statistics file paths
         metadata.partitionStatisticsFiles(),
-        metadata.changes(),
-        metadata.rowLineageEnabled(),
-        metadata.nextRowId());
+        metadata.nextRowId(),
+        metadata.changes());
   }
 
   private static Map<String, String> updateProperties(
@@ -253,7 +252,8 @@ public class RewriteTablePathUtil {
             outputFile,
             snapshot.snapshotId(),
             snapshot.parentId(),
-            snapshot.sequenceNumber())) {
+            snapshot.sequenceNumber(),
+            snapshot.firstRowId())) {
 
       for (ManifestFile file : manifestFiles) {
         ManifestFile newFile = file.copy();
