@@ -107,6 +107,8 @@ public class UpdateRequirements {
         update((MetadataUpdate.SetDefaultSortOrder) update);
       } else if (update instanceof MetadataUpdate.RemovePartitionSpecs) {
         update((MetadataUpdate.RemovePartitionSpecs) update);
+      } else if (update instanceof MetadataUpdate.RemoveSchemas) {
+        update((MetadataUpdate.RemoveSchemas) update);
       }
 
       return this;
@@ -136,13 +138,7 @@ public class UpdateRequirements {
     }
 
     private void update(MetadataUpdate.SetCurrentSchema unused) {
-      if (!setSchemaId) {
-        if (base != null && !isReplace) {
-          // require that the current schema has not changed
-          require(new UpdateRequirement.AssertCurrentSchemaID(base.currentSchemaId()));
-        }
-        this.setSchemaId = true;
-      }
+      requireCurrentSchemaNotChanged();
     }
 
     private void update(MetadataUpdate.AddPartitionSpec unused) {
@@ -156,13 +152,7 @@ public class UpdateRequirements {
     }
 
     private void update(MetadataUpdate.SetDefaultPartitionSpec unused) {
-      if (!setSpecId) {
-        if (base != null && !isReplace) {
-          // require that the default spec has not changed
-          require(new UpdateRequirement.AssertDefaultSpecID(base.defaultSpecId()));
-        }
-        this.setSpecId = true;
-      }
+      requireDefaultPartitionSpecNotChanged();
     }
 
     private void update(MetadataUpdate.SetDefaultSortOrder unused) {
@@ -176,15 +166,38 @@ public class UpdateRequirements {
     }
 
     private void update(MetadataUpdate.RemovePartitionSpecs unused) {
-      // require that the default partition spec has not changed
+      requireDefaultPartitionSpecNotChanged();
+
+      // require that no branches have changed, so that old specs won't be written.
+      requireNoBranchesChanged();
+    }
+
+    private void update(MetadataUpdate.RemoveSchemas unused) {
+      requireCurrentSchemaNotChanged();
+
+      // require that no branches have changed, so that old schemas won't be written.
+      requireNoBranchesChanged();
+    }
+
+    private void requireDefaultPartitionSpecNotChanged() {
       if (!setSpecId) {
         if (base != null && !isReplace) {
           require(new UpdateRequirement.AssertDefaultSpecID(base.defaultSpecId()));
         }
         this.setSpecId = true;
       }
+    }
 
-      // require that no branches have changed, so that old specs won't be written.
+    private void requireCurrentSchemaNotChanged() {
+      if (!setSchemaId) {
+        if (base != null && !isReplace) {
+          require(new UpdateRequirement.AssertCurrentSchemaID(base.currentSchemaId()));
+        }
+        this.setSchemaId = true;
+      }
+    }
+
+    private void requireNoBranchesChanged() {
       if (base != null && !isReplace) {
         base.refs()
             .forEach(
