@@ -34,23 +34,35 @@ import org.apache.iceberg.util.DataFileSet;
  * Container class representing a set of files to be rewritten by a RewriteAction and the new files
  * which have been written by the action.
  */
-public class RewriteFileGroup {
-  private final FileGroupInfo info;
-  private final List<FileScanTask> fileScanTasks;
-
+public class RewriteFileGroup extends RewriteGroupBase<FileGroupInfo, FileScanTask, DataFile> {
+  private final int outputSpecId;
   private DataFileSet addedFiles = DataFileSet.create();
 
+  /**
+   * @deprecated since 1.9.0, will be removed in 1.10.0
+   */
+  @Deprecated
   public RewriteFileGroup(FileGroupInfo info, List<FileScanTask> fileScanTasks) {
-    this.info = info;
-    this.fileScanTasks = fileScanTasks;
+    this(info, fileScanTasks, 0, 0L, 0L, 0);
   }
 
-  public FileGroupInfo info() {
-    return info;
+  public RewriteFileGroup(
+      FileGroupInfo info,
+      List<FileScanTask> fileScanTasks,
+      int outputSpecId,
+      long writeMaxFileSize,
+      long inputSplitSize,
+      int expectedOutputFiles) {
+    super(info, fileScanTasks, writeMaxFileSize, inputSplitSize, expectedOutputFiles);
+    this.outputSpecId = outputSpecId;
   }
 
+  /**
+   * @deprecated since 1.9.0, will be removed in 1.10.0; use {@link #fileScanTasks()}
+   */
+  @Deprecated
   public List<FileScanTask> fileScans() {
-    return fileScanTasks;
+    return fileScanTasks();
   }
 
   public void setOutputFiles(Set<DataFile> files) {
@@ -58,7 +70,7 @@ public class RewriteFileGroup {
   }
 
   public Set<DataFile> rewrittenFiles() {
-    return fileScans().stream()
+    return fileScanTasks().stream()
         .map(FileScanTask::file)
         .collect(Collectors.toCollection(DataFileSet::create));
   }
@@ -70,43 +82,60 @@ public class RewriteFileGroup {
   public RewriteDataFiles.FileGroupRewriteResult asResult() {
     Preconditions.checkState(addedFiles != null, "Cannot get result, Group was never rewritten");
     return ImmutableRewriteDataFiles.FileGroupRewriteResult.builder()
-        .info(info)
+        .info(info())
         .addedDataFilesCount(addedFiles.size())
-        .rewrittenDataFilesCount(fileScanTasks.size())
-        .rewrittenBytesCount(sizeInBytes())
+        .rewrittenDataFilesCount(fileScanTasks().size())
+        .rewrittenBytesCount(inputFilesSizeInBytes())
         .build();
   }
 
   @Override
   public String toString() {
     return MoreObjects.toStringHelper(this)
-        .add("info", info)
-        .add("numRewrittenFiles", fileScanTasks.size())
+        .add("info", info())
+        .add("numRewrittenFiles", fileScanTasks().size())
         .add(
             "numAddedFiles",
             addedFiles == null ? "Rewrite Incomplete" : Integer.toString(addedFiles.size()))
-        .add("numRewrittenBytes", sizeInBytes())
+        .add("numRewrittenBytes", inputFilesSizeInBytes())
+        .add("maxOutputFileSize", maxOutputFileSize())
+        .add("inputSplitSize", inputSplitSize())
+        .add("expectedOutputFiles", expectedOutputFiles())
+        .add("outputSpecId", outputSpecId)
         .toString();
   }
 
+  /**
+   * @deprecated since 1.9.0, will be removed in 1.10.0; use {@link #inputFilesSizeInBytes()}
+   */
+  @Deprecated
   public long sizeInBytes() {
-    return fileScanTasks.stream().mapToLong(FileScanTask::length).sum();
+    return inputFilesSizeInBytes();
   }
 
+  /**
+   * @deprecated since 1.9.0, will be removed in 1.10.0; use {@link #inputFileNum()}
+   */
+  @Deprecated
   public int numFiles() {
-    return fileScanTasks.size();
+    return inputFileNum();
+  }
+
+  public int outputSpecId() {
+    return outputSpecId;
   }
 
   public static Comparator<RewriteFileGroup> comparator(RewriteJobOrder rewriteJobOrder) {
     switch (rewriteJobOrder) {
       case BYTES_ASC:
-        return Comparator.comparing(RewriteFileGroup::sizeInBytes);
+        return Comparator.comparing(RewriteFileGroup::inputFilesSizeInBytes);
       case BYTES_DESC:
-        return Comparator.comparing(RewriteFileGroup::sizeInBytes, Comparator.reverseOrder());
+        return Comparator.comparing(
+            RewriteFileGroup::inputFilesSizeInBytes, Comparator.reverseOrder());
       case FILES_ASC:
-        return Comparator.comparing(RewriteFileGroup::numFiles);
+        return Comparator.comparing(RewriteFileGroup::inputFileNum);
       case FILES_DESC:
-        return Comparator.comparing(RewriteFileGroup::numFiles, Comparator.reverseOrder());
+        return Comparator.comparing(RewriteFileGroup::inputFileNum, Comparator.reverseOrder());
       default:
         return (unused, unused2) -> 0;
     }
