@@ -66,6 +66,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.util.LocationUtil;
 import org.apache.iceberg.util.PropertyUtil;
 import org.apache.iceberg.view.BaseMetastoreViewCatalog;
+import org.apache.iceberg.view.ViewMetadata;
 import org.apache.iceberg.view.ViewOperations;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -151,6 +152,7 @@ public class JdbcCatalog extends BaseMetastoreViewCatalog
     this.closeableGroup = new CloseableGroup();
     closeableGroup.addCloseable(metricsReporter());
     closeableGroup.addCloseable(connections);
+    closeableGroup.addCloseable(io);
     closeableGroup.setSuppressCloseFailure(true);
   }
 
@@ -612,6 +614,14 @@ public class JdbcCatalog extends BaseMetastoreViewCatalog
       throw new UnsupportedOperationException(VIEW_WARNING_LOG_MESSAGE);
     }
 
+    JdbcViewOperations ops = (JdbcViewOperations) newViewOps(identifier);
+    ViewMetadata lastViewMetadata = null;
+    try {
+      lastViewMetadata = ops.current();
+    } catch (NotFoundException e) {
+      LOG.warn("Failed to load view metadata for view: {}", identifier, e);
+    }
+
     int deletedRecords =
         execute(
             JdbcUtil.DROP_VIEW_SQL,
@@ -624,6 +634,10 @@ public class JdbcCatalog extends BaseMetastoreViewCatalog
       return false;
     }
 
+    if (lastViewMetadata != null) {
+      CatalogUtil.dropViewMetadata(ops.io(), lastViewMetadata);
+    }
+
     LOG.info("Dropped view: {}", identifier);
     return true;
   }
