@@ -16,11 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.rest;
 
-/**
- * Interface to mark a REST response
- */
-public interface RESTResponse extends RESTMessage {
-}
+/** Interface to mark a REST response */
+public interface RESTResponse extends RESTMessage {}
