@@ -21,12 +21,16 @@ package org.apache.iceberg;
 import static org.apache.iceberg.types.Types.NestedField.required;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
-import java.io.File;
 import java.io.IOException;
 import java.nio.file.Path;
 import java.util.List;
-import org.apache.iceberg.inmemory.InMemoryOutputFile;
+import org.apache.iceberg.encryption.EncryptedOutputFile;
+import org.apache.iceberg.encryption.EncryptingFileIO;
+import org.apache.iceberg.encryption.EncryptionManager;
+import org.apache.iceberg.encryption.PlaintextEncryptionManager;
+import org.apache.iceberg.inmemory.InMemoryFileIO;
 import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.io.FileAppender;
 import org.apache.iceberg.io.FileIO;
@@ -34,14 +38,17 @@ import org.apache.iceberg.io.InputFile;
 import org.apache.iceberg.io.OutputFile;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
+import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.Conversions;
 import org.apache.iceberg.types.Types;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.FieldSource;
 
 public class TestManifestWriterVersions {
-  private static final FileIO FILE_IO = new TestTables.LocalFileIO();
+  private final FileIO io = EncryptingFileIO.combine(new InMemoryFileIO(), encryptionManager());
 
   private static final Schema SCHEMA =
       new Schema(
@@ -76,10 +83,11 @@ public class TestManifestWriterVersions {
           ImmutableMap.of(1, Conversions.toByteBuffer(Types.IntegerType.get(), 1))); // upper bounds
   private static final List<Long> OFFSETS = ImmutableList.of(4L);
   private static final Integer SORT_ORDER_ID = 2;
+  private static final long FIRST_ROW_ID = 100L;
 
   private static final DataFile DATA_FILE =
       new GenericDataFile(
-          0, PATH, FORMAT, PARTITION, 150972L, METRICS, null, OFFSETS, SORT_ORDER_ID);
+          0, PATH, FORMAT, PARTITION, 150972L, METRICS, null, OFFSETS, SORT_ORDER_ID, FIRST_ROW_ID);
 
   private static final List<Integer> EQUALITY_IDS = ImmutableList.of(1);
   private static final int[] EQUALITY_ID_ARR = new int[] {1};
@@ -152,9 +160,12 @@ public class TestManifestWriterVersions {
     checkEntry(readManifest(manifest), SEQUENCE_NUMBER, SEQUENCE_NUMBER, FileContent.DATA);
   }
 
-  @Test
-  public void testV2WriteDelete() throws IOException {
-    ManifestFile manifest = writeDeleteManifest(2);
+  @ParameterizedTest
+  @FieldSource("org.apache.iceberg.TestHelpers#ALL_VERSIONS")
+  public void testV2PlusWriteDelete(int formatVersion) throws IOException {
+    assumeThat(formatVersion).isNotEqualTo(1);
+
+    ManifestFile manifest = writeDeleteManifest(formatVersion);
     checkManifest(manifest, ManifestWriter.UNASSIGNED_SEQ);
     assertThat(manifest.content()).isEqualTo(ManifestContent.DELETES);
     checkEntry(
@@ -164,9 +175,13 @@ public class TestManifestWriterVersions {
         FileContent.EQUALITY_DELETES);
   }
 
-  @Test
-  public void testV2WriteDeleteWithInheritance() throws IOException {
-    ManifestFile manifest = writeAndReadManifestList(writeDeleteManifest(2), 2);
+  @ParameterizedTest
+  @FieldSource("org.apache.iceberg.TestHelpers#ALL_VERSIONS")
+  public void testV2WriteDeleteWithInheritance(int formatVersion) throws IOException {
+    assumeThat(formatVersion).isNotEqualTo(1);
+
+    ManifestFile manifest =
+        writeAndReadManifestList(writeDeleteManifest(formatVersion), formatVersion);
     checkManifest(manifest, SEQUENCE_NUMBER);
     assertThat(manifest.content()).isEqualTo(ManifestContent.DELETES);
 
@@ -213,27 +228,125 @@ public class TestManifestWriterVersions {
     checkRewrittenEntry(readManifest(manifest2), 0L, FileContent.DATA);
   }
 
+  @Test
+  public void testV3Write() throws IOException {
+    ManifestFile manifest = writeManifest(3);
+    checkEntry(
+        readManifest(manifest),
+        ManifestWriter.UNASSIGNED_SEQ,
+        ManifestWriter.UNASSIGNED_SEQ,
+        FileContent.DATA,
+        FIRST_ROW_ID);
+  }
+
+  @Test
+  public void testV3WriteWithInheritance() throws IOException {
+    DataFile withoutFirstRowId =
+        DataFiles.builder(SPEC).copy(DATA_FILE).withFirstRowId(null).build();
+
+    ManifestFile manifest = writeAndReadManifestList(writeManifest(3, withoutFirstRowId), 3);
+    checkManifest(manifest, SEQUENCE_NUMBER);
+    assertThat(manifest.content()).isEqualTo(ManifestContent.DATA);
+
+    // v2+ should use the correct sequence number by inheriting it
+    // v3 should use the correct first-row-id by inheriting it
+    checkEntry(
+        readManifest(manifest), SEQUENCE_NUMBER, SEQUENCE_NUMBER, FileContent.DATA, FIRST_ROW_ID);
+  }
+
+  @Test
+  public void testV3WriteFirstRowIdAssignment() throws IOException {
+    long rowsPerFile = METRICS.recordCount();
+    DataFile withoutFirstRowId =
+        DataFiles.builder(SPEC).copy(DATA_FILE).withFirstRowId(null).build();
+
+    ManifestFile manifest =
+        writeAndReadManifestList(writeManifest(3, withoutFirstRowId, withoutFirstRowId), 3);
+    assertThat(manifest.content()).isEqualTo(ManifestContent.DATA);
+
+    // v2+ should use the correct sequence number by inheriting it
+    // v3 should use the correct first-row-id by inheriting it
+    List<ManifestEntry<DataFile>> entries = readManifestAsList(manifest);
+    long expectedFirstRowId = FIRST_ROW_ID;
+    for (ManifestEntry<DataFile> entry : entries) {
+      checkEntry(entry, SEQUENCE_NUMBER, SEQUENCE_NUMBER, FileContent.DATA, expectedFirstRowId);
+      expectedFirstRowId += rowsPerFile;
+    }
+  }
+
+  @Test
+  public void testV3ManifestListRewriteWithInheritance() throws IOException {
+    // write with v1
+    ManifestFile manifest = writeAndReadManifestList(writeManifest(1), 1);
+    checkManifest(manifest, 0L);
+
+    // rewrite existing metadata with a manifest list
+    ManifestFile manifest3 = writeAndReadManifestList(manifest, 3);
+    // the ManifestFile did not change and should still have its original sequence number, 0
+    checkManifest(manifest3, 0L);
+
+    // should not inherit the sequence number because it was a rewrite
+    checkEntry(readManifest(manifest3), 0L, 0L, FileContent.DATA, FIRST_ROW_ID);
+  }
+
+  @Test
+  public void testV3ManifestRewriteWithInheritance() throws IOException {
+    // write with v1
+    ManifestFile manifest = writeAndReadManifestList(writeManifest(1), 1);
+    checkManifest(manifest, 0L);
+
+    // rewrite the manifest file using a v3 manifest
+    ManifestFile rewritten = rewriteManifest(manifest, 3);
+    checkRewrittenManifest(rewritten, ManifestWriter.UNASSIGNED_SEQ, 0L);
+
+    // add the v3 manifest to a v3 manifest list, with a sequence number
+    ManifestFile manifest3 = writeAndReadManifestList(rewritten, 3);
+    // the ManifestFile is new so it has a sequence number, but the min sequence number 0 is from
+    // the entry
+    checkRewrittenManifest(manifest3, SEQUENCE_NUMBER, 0L);
+
+    // should not inherit the v3 sequence number because it was written into the v3 manifest
+    checkRewrittenEntry(readManifest(manifest3), 0L, FileContent.DATA, FIRST_ROW_ID);
+  }
+
   void checkEntry(
       ManifestEntry<?> entry,
       Long expectedDataSequenceNumber,
       Long expectedFileSequenceNumber,
       FileContent content) {
+    checkEntry(entry, expectedDataSequenceNumber, expectedFileSequenceNumber, content, null);
+  }
+
+  void checkEntry(
+      ManifestEntry<?> entry,
+      Long expectedDataSequenceNumber,
+      Long expectedFileSequenceNumber,
+      FileContent content,
+      Long expectedRowId) {
     assertThat(entry.status()).isEqualTo(ManifestEntry.Status.ADDED);
     assertThat(entry.snapshotId()).isEqualTo(SNAPSHOT_ID);
     assertThat(entry.dataSequenceNumber()).isEqualTo(expectedDataSequenceNumber);
     assertThat(entry.fileSequenceNumber()).isEqualTo(expectedFileSequenceNumber);
-    checkDataFile(entry.file(), content);
+    checkDataFile(entry.file(), content, expectedRowId);
   }
 
   void checkRewrittenEntry(
       ManifestEntry<DataFile> entry, Long expectedSequenceNumber, FileContent content) {
+    checkRewrittenEntry(entry, expectedSequenceNumber, content, null);
+  }
+
+  void checkRewrittenEntry(
+      ManifestEntry<DataFile> entry,
+      Long expectedSequenceNumber,
+      FileContent content,
+      Long expectedRowId) {
     assertThat(entry.status()).isEqualTo(ManifestEntry.Status.EXISTING);
     assertThat(entry.snapshotId()).isEqualTo(SNAPSHOT_ID);
     assertThat(entry.dataSequenceNumber()).isEqualTo(expectedSequenceNumber);
-    checkDataFile(entry.file(), content);
+    checkDataFile(entry.file(), content, expectedRowId);
   }
 
-  void checkDataFile(ContentFile<?> dataFile, FileContent content) {
+  void checkDataFile(ContentFile<?> dataFile, FileContent content, Long expectedRowId) {
     // DataFile is the superclass of DeleteFile, so this method can check both
     assertThat(dataFile.content()).isEqualTo(content);
     assertThat(dataFile.location()).isEqualTo(PATH);
@@ -247,10 +360,19 @@ public class TestManifestWriterVersions {
     assertThat(dataFile.lowerBounds()).isEqualTo(METRICS.lowerBounds());
     assertThat(dataFile.upperBounds()).isEqualTo(METRICS.upperBounds());
     assertThat(dataFile.sortOrderId()).isEqualTo(SORT_ORDER_ID);
-    if (dataFile.content() == FileContent.EQUALITY_DELETES) {
-      assertThat(dataFile.equalityFieldIds()).isEqualTo(EQUALITY_IDS);
-    } else {
-      assertThat(dataFile.equalityFieldIds()).isNull();
+    switch (dataFile.content()) {
+      case DATA:
+        assertThat(dataFile.firstRowId()).isEqualTo(expectedRowId);
+        assertThat(dataFile.equalityFieldIds()).isNull();
+        break;
+      case EQUALITY_DELETES:
+        assertThat(dataFile.firstRowId()).isNull();
+        assertThat(dataFile.equalityFieldIds()).isEqualTo(EQUALITY_IDS);
+        break;
+      case POSITION_DELETES:
+        assertThat(dataFile.firstRowId()).isNull();
+        assertThat(dataFile.equalityFieldIds()).isNull();
+        break;
     }
   }
 
@@ -279,17 +401,23 @@ public class TestManifestWriterVersions {
     assertThat(manifest.deletedRowsCount()).isEqualTo(0);
   }
 
+  protected EncryptionManager encryptionManager() {
+    return PlaintextEncryptionManager.instance();
+  }
+
   private InputFile writeManifestList(ManifestFile manifest, int formatVersion) throws IOException {
-    OutputFile manifestList = new InMemoryOutputFile();
+    OutputFile manifestList = io.newOutputFile("manifest-list");
     try (FileAppender<ManifestFile> writer =
         ManifestLists.write(
             formatVersion,
             manifestList,
             SNAPSHOT_ID,
             SNAPSHOT_ID - 1,
-            formatVersion > 1 ? SEQUENCE_NUMBER : 0)) {
+            formatVersion > 1 ? SEQUENCE_NUMBER : 0,
+            FIRST_ROW_ID)) {
       writer.add(manifest);
     }
+
     return manifestList.toInputFile();
   }
 
@@ -302,10 +430,8 @@ public class TestManifestWriterVersions {
 
   private ManifestFile rewriteManifest(ManifestFile manifest, int formatVersion)
       throws IOException {
-    OutputFile manifestFile =
-        Files.localOutput(
-            FileFormat.AVRO.addExtension(
-                File.createTempFile("manifest", null, temp.toFile()).toString()));
+    String filename = FileFormat.AVRO.addExtension("rewrite-manifest");
+    EncryptedOutputFile manifestFile = encryptionManager().encrypt(io.newOutputFile(filename));
     ManifestWriter<DataFile> writer =
         ManifestFiles.write(formatVersion, SPEC, manifestFile, SNAPSHOT_ID);
     try {
@@ -317,38 +443,41 @@ public class TestManifestWriterVersions {
   }
 
   private ManifestFile writeManifest(int formatVersion) throws IOException {
-    return writeManifest(DATA_FILE, formatVersion);
+    return writeManifest(formatVersion, DATA_FILE);
   }
 
-  private ManifestFile writeManifest(DataFile file, int formatVersion) throws IOException {
-    OutputFile manifestFile =
-        Files.localOutput(
-            FileFormat.AVRO.addExtension(
-                File.createTempFile("manifest", null, temp.toFile()).toString()));
+  private ManifestFile writeManifest(int formatVersion, DataFile... files) throws IOException {
+    String filename = FileFormat.AVRO.addExtension("manifest");
+    EncryptedOutputFile manifestFile = encryptionManager().encrypt(io.newOutputFile(filename));
     ManifestWriter<DataFile> writer =
-        ManifestFiles.write(formatVersion, SPEC, manifestFile, SNAPSHOT_ID);
+        ManifestFiles.newWriter(formatVersion, SPEC, manifestFile, SNAPSHOT_ID, FIRST_ROW_ID);
     try {
-      writer.add(file);
+      for (DataFile file : files) {
+        writer.add(file);
+      }
     } finally {
       writer.close();
     }
     return writer.toManifestFile();
   }
 
-  private ManifestEntry<DataFile> readManifest(ManifestFile manifest) throws IOException {
+  private List<ManifestEntry<DataFile>> readManifestAsList(ManifestFile manifest)
+      throws IOException {
     try (CloseableIterable<ManifestEntry<DataFile>> reader =
-        ManifestFiles.read(manifest, FILE_IO).entries()) {
-      List<ManifestEntry<DataFile>> files = Lists.newArrayList(reader);
-      assertThat(files).hasSize(1);
-      return files.get(0);
+        ManifestFiles.read(manifest, io).entries()) {
+      return Lists.newArrayList(Iterables.transform(reader, ManifestEntry::copy));
     }
   }
 
+  private ManifestEntry<DataFile> readManifest(ManifestFile manifest) throws IOException {
+    List<ManifestEntry<DataFile>> files = readManifestAsList(manifest);
+    assertThat(files).hasSize(1);
+    return files.get(0);
+  }
+
   private ManifestFile writeDeleteManifest(int formatVersion) throws IOException {
-    OutputFile manifestFile =
-        Files.localOutput(
-            FileFormat.AVRO.addExtension(
-                File.createTempFile("manifest", null, temp.toFile()).toString()));
+    String filename = FileFormat.AVRO.addExtension("manifest");
+    EncryptedOutputFile manifestFile = encryptionManager().encrypt(io.newOutputFile(filename));
     ManifestWriter<DeleteFile> writer =
         ManifestFiles.writeDeleteManifest(formatVersion, SPEC, manifestFile, SNAPSHOT_ID);
     try {
@@ -361,7 +490,7 @@ public class TestManifestWriterVersions {
 
   private ManifestEntry<DeleteFile> readDeleteManifest(ManifestFile manifest) throws IOException {
     try (CloseableIterable<ManifestEntry<DeleteFile>> reader =
-        ManifestFiles.readDeleteManifest(manifest, FILE_IO, null).entries()) {
+        ManifestFiles.readDeleteManifest(manifest, io, null).entries()) {
       List<ManifestEntry<DeleteFile>> entries = Lists.newArrayList(reader);
       assertThat(entries).hasSize(1);
       return entries.get(0);
