@@ -375,7 +375,6 @@ public class TestMergeAppend extends TestBase {
     V2Assert.assertEquals(
         "Last sequence number should be 1", 1, table.ops().current().lastSequenceNumber());
 
-    TableMetadata base = readMetadata();
     long baseId = commitBefore.snapshotId();
     validateSnapshot(null, commitBefore, 1, FILE_A, FILE_B);
 
@@ -709,7 +708,6 @@ public class TestMergeAppend extends TestBase {
 
     validateSnapshot(null, snap, 1, FILE_A, FILE_B);
 
-    TableMetadata base = readMetadata();
     long baseId = snap.snapshotId();
     assertThat(snap.allManifests(table.io())).hasSize(1);
     ManifestFile initialManifest = snap.allManifests(table.io()).get(0);
@@ -730,7 +728,6 @@ public class TestMergeAppend extends TestBase {
     V1Assert.assertEquals(
         "Table should end with last-sequence-number 0", 0, readMetadata().lastSequenceNumber());
 
-    TableMetadata delete = readMetadata();
     long deleteId = latestSnapshot(table, branch).snapshotId();
     assertThat(latestSnapshot(table, branch).allManifests(table.io())).hasSize(1);
     ManifestFile deleteManifest = deleteSnapshot.allManifests(table.io()).get(0);
@@ -789,7 +786,6 @@ public class TestMergeAppend extends TestBase {
     long idFileC = snap3.snapshotId();
     validateSnapshot(snap2, snap3, 3, FILE_C);
 
-    TableMetadata base = readMetadata();
     assertThat(latestSnapshot(table, branch).allManifests(table.io())).hasSize(3);
     Set<ManifestFile> unmerged =
         Sets.newHashSet(latestSnapshot(table, branch).allManifests(table.io()));
@@ -829,7 +825,6 @@ public class TestMergeAppend extends TestBase {
 
     validateSnapshot(null, snap, 1, FILE_A, FILE_B);
 
-    TableMetadata base = readMetadata();
     long baseId = snap.snapshotId();
     assertThat(snap.allManifests(table.io())).hasSize(1);
     ManifestFile initialManifest = snap.allManifests(table.io()).get(0);
@@ -1099,7 +1094,6 @@ public class TestMergeAppend extends TestBase {
 
     Snapshot current = commit(table, table.newAppend().appendFile(FILE_A), branch);
 
-    TableMetadata base = readMetadata();
     long baseId = current.snapshotId();
     V2Assert.assertEquals(
         "Last sequence number should be 1", 1, readMetadata().lastSequenceNumber());
@@ -1143,7 +1137,6 @@ public class TestMergeAppend extends TestBase {
     V1Assert.assertEquals(
         "Table should end with last-sequence-number 0", 0, readMetadata().lastSequenceNumber());
 
-    TableMetadata metadata = readMetadata();
     assertThat(new File(newManifest.path())).exists();
     assertThat(snapshot.allManifests(table.io())).containsExactly(newManifest);
 
