@@ -35,6 +35,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.relocated.com.google.common.collect.Streams;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.Pair;
@@ -415,9 +416,9 @@ public class TestMetadataUpdateParser {
     assertEquals(action, expected, MetadataUpdateParser.fromJson(json));
   }
 
-  /** RemoveSnapshots * */
+  /** RemoveSnapshot * */
   @Test
-  public void testRemoveSnapshotsFromJson() {
+  public void testRemoveSnapshotFromJson() {
     String action = MetadataUpdateParser.REMOVE_SNAPSHOTS;
     long snapshotId = 2L;
     String json = String.format("{\"action\":\"%s\",\"snapshot-ids\":[2]}", action);
@@ -426,7 +427,7 @@ public class TestMetadataUpdateParser {
   }
 
   @Test
-  public void testRemoveSnapshotsToJson() {
+  public void testRemoveSnapshotToJson() {
     String action = MetadataUpdateParser.REMOVE_SNAPSHOTS;
     long snapshotId = 2L;
     String expected = String.format("{\"action\":\"%s\",\"snapshot-ids\":[2]}", action);
@@ -437,6 +438,28 @@ public class TestMetadataUpdateParser {
         .isEqualTo(expected);
   }
 
+  /** RemoveSnapshots * */
+  @Test
+  public void testRemoveSnapshotsFromJson() {
+    String action = MetadataUpdateParser.REMOVE_SNAPSHOTS;
+    Set<Long> snapshotIds = Sets.newHashSet(2L, 3L);
+    String json = String.format("{\"action\":\"%s\",\"snapshot-ids\":[2,3]}", action);
+    MetadataUpdate expected = new MetadataUpdate.RemoveSnapshots(snapshotIds);
+    assertEquals(action, expected, MetadataUpdateParser.fromJson(json));
+  }
+
+  @Test
+  public void testRemoveSnapshotsToJson() {
+    String action = MetadataUpdateParser.REMOVE_SNAPSHOTS;
+    Set<Long> snapshotIds = Sets.newHashSet(2L, 3L);
+    String expected = String.format("{\"action\":\"%s\",\"snapshot-ids\":[2,3]}", action);
+    MetadataUpdate update = new MetadataUpdate.RemoveSnapshots(snapshotIds);
+    String actual = MetadataUpdateParser.toJson(update);
+    assertThat(actual)
+        .as("Remove snapshots should serialize to the correct JSON value")
+        .isEqualTo(expected);
+  }
+
   /** RemoveSnapshotRef * */
   @Test
   public void testRemoveSnapshotRefFromJson() {
@@ -931,13 +954,13 @@ public class TestMetadataUpdateParser {
   }
 
   @Test
-  public void testEnableRowLineage() {
-    String action = MetadataUpdateParser.ENABLE_ROW_LINEAGE;
-    String json = "{\"action\":\"enable-row-lineage\"}";
-    MetadataUpdate expected = new MetadataUpdate.EnableRowLineage();
+  public void testRemoveSchemas() {
+    String action = MetadataUpdateParser.REMOVE_SCHEMAS;
+    String json = "{\"action\":\"remove-schemas\",\"schema-ids\":[1,2,3]}";
+    MetadataUpdate expected = new MetadataUpdate.RemoveSchemas(ImmutableSet.of(1, 2, 3));
     assertEquals(action, expected, MetadataUpdateParser.fromJson(json));
     assertThat(MetadataUpdateParser.toJson(expected))
-        .as("Enable row lineage should convert to the correct JSON value")
+        .as("Remove schemas should convert to the correct JSON value")
         .isEqualTo(json);
   }
 
@@ -1007,9 +1030,15 @@ public class TestMetadataUpdateParser {
             (MetadataUpdate.AddSnapshot) expectedUpdate, (MetadataUpdate.AddSnapshot) actualUpdate);
         break;
       case MetadataUpdateParser.REMOVE_SNAPSHOTS:
-        assertEqualsRemoveSnapshots(
-            (MetadataUpdate.RemoveSnapshot) expectedUpdate,
-            (MetadataUpdate.RemoveSnapshot) actualUpdate);
+        if (actualUpdate instanceof MetadataUpdate.RemoveSnapshot) {
+          assertEqualsRemoveSnapshot(
+              (MetadataUpdate.RemoveSnapshot) expectedUpdate,
+              (MetadataUpdate.RemoveSnapshot) actualUpdate);
+        } else {
+          assertEqualsRemoveSnapshots(
+              (MetadataUpdate.RemoveSnapshots) expectedUpdate,
+              (MetadataUpdate.RemoveSnapshots) actualUpdate);
+        }
         break;
       case MetadataUpdateParser.REMOVE_SNAPSHOT_REF:
         assertEqualsRemoveSnapshotRef(
@@ -1050,8 +1079,10 @@ public class TestMetadataUpdateParser {
             (MetadataUpdate.RemovePartitionSpecs) expectedUpdate,
             (MetadataUpdate.RemovePartitionSpecs) actualUpdate);
         break;
-      case MetadataUpdateParser.ENABLE_ROW_LINEAGE:
-        assertThat(actualUpdate).isInstanceOf(MetadataUpdate.EnableRowLineage.class);
+      case MetadataUpdateParser.REMOVE_SCHEMAS:
+        assertEqualsRemoveSchemas(
+            (MetadataUpdate.RemoveSchemas) expectedUpdate,
+            (MetadataUpdate.RemoveSchemas) actualUpdate);
         break;
       default:
         fail("Unrecognized metadata update action: " + action);
@@ -1208,13 +1239,20 @@ public class TestMetadataUpdateParser {
     assertThat(actual.snapshot().schemaId()).isEqualTo(expected.snapshot().schemaId());
   }
 
-  private static void assertEqualsRemoveSnapshots(
+  private static void assertEqualsRemoveSnapshot(
       MetadataUpdate.RemoveSnapshot expected, MetadataUpdate.RemoveSnapshot actual) {
     assertThat(actual.snapshotId())
-        .as("Snapshots to remove should be the same")
+        .as("Snapshot to remove should be the same")
         .isEqualTo(expected.snapshotId());
   }
 
+  private static void assertEqualsRemoveSnapshots(
+      MetadataUpdate.RemoveSnapshots expected, MetadataUpdate.RemoveSnapshots actual) {
+    assertThat(actual.snapshotIds())
+        .as("Snapshots to remove should be the same")
+        .isEqualTo(expected.snapshotIds());
+  }
+
   private static void assertEqualsSetSnapshotRef(
       MetadataUpdate.SetSnapshotRef expected, MetadataUpdate.SetSnapshotRef actual) {
     // Non-null fields
@@ -1279,6 +1317,11 @@ public class TestMetadataUpdateParser {
     assertThat(actual.specIds()).containsExactlyInAnyOrderElementsOf(expected.specIds());
   }
 
+  private static void assertEqualsRemoveSchemas(
+      MetadataUpdate.RemoveSchemas expected, MetadataUpdate.RemoveSchemas actual) {
+    assertThat(actual.schemaIds()).containsExactlyInAnyOrderElementsOf(expected.schemaIds());
+  }
+
   private String createManifestListWithManifestFiles(long snapshotId, Long parentSnapshotId)
       throws IOException {
     File manifestList = File.createTempFile("manifests", null, temp.toFile());
@@ -1290,7 +1333,8 @@ public class TestMetadataUpdateParser {
             new GenericManifestFile(localInput("file:/tmp/manifest2.avro"), 0, snapshotId));
 
     try (ManifestListWriter writer =
-        ManifestLists.write(1, Files.localOutput(manifestList), snapshotId, parentSnapshotId, 0)) {
+        ManifestLists.write(
+            1, Files.localOutput(manifestList), snapshotId, parentSnapshotId, 0, 0L)) {
       writer.addAll(manifests);
     }
 
