@@ -18,8 +18,11 @@
  */
 package org.apache.iceberg.avro;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Path;
 import java.util.List;
 import org.apache.avro.SchemaBuilder;
 import org.apache.avro.file.DataFileWriter;
@@ -30,14 +33,12 @@ import org.apache.iceberg.Files;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 public class TestAvroEnums {
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir Path temp;
 
   @Test
   public void writeAndValidateEnums() throws IOException {
@@ -60,8 +61,8 @@ public class TestAvroEnums {
     Record enumRecord3 = new GenericData.Record(avroSchema); // null enum
     List<Record> expected = ImmutableList.of(enumRecord1, enumRecord2, enumRecord3);
 
-    File testFile = temp.newFile();
-    Assert.assertTrue("Delete should succeed", testFile.delete());
+    File testFile = temp.toFile();
+    assertThat(testFile.delete()).as("Delete should succeed").isTrue();
 
     try (DataFileWriter<Record> writer = new DataFileWriter<>(new GenericDatumWriter<>())) {
       writer.create(avroSchema, testFile);
@@ -82,7 +83,7 @@ public class TestAvroEnums {
     for (int i = 0; i < expected.size(); i += 1) {
       String expectedEnumString =
           expected.get(i).get("enumCol") == null ? null : expected.get(i).get("enumCol").toString();
-      Assert.assertEquals(expectedEnumString, rows.get(i).get("enumCol"));
+      assertThat(rows.get(i).get("enumCol")).isEqualTo(expectedEnumString);
     }
   }
 }
