@@ -42,7 +42,7 @@ import org.apache.flink.configuration.ReadableConfig;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.datastream.DataStreamSink;
 import org.apache.flink.streaming.api.datastream.SingleOutputStreamOperator;
-import org.apache.flink.streaming.api.functions.sink.v2.DiscardingSink;
+import org.apache.flink.streaming.api.functions.sink.DiscardingSink;
 import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.table.data.util.DataFormatConverters;
@@ -136,7 +136,7 @@ public class FlinkSink {
     return new Builder().forRowData(input);
   }
 
-  public static class Builder implements IcebergSinkBuilder<Builder> {
+  public static class Builder {
     private Function<String, DataStream<RowData>> inputCreator = null;
     private TableLoader tableLoader;
     private Table table;
@@ -181,7 +181,6 @@ public class FlinkSink {
      * @param newTable the loaded iceberg table instance.
      * @return {@link Builder} to connect the iceberg table.
      */
-    @Override
     public Builder table(Table newTable) {
       this.table = newTable;
       return this;
@@ -195,7 +194,6 @@ public class FlinkSink {
      * @param newTableLoader to load iceberg table inside tasks.
      * @return {@link Builder} to connect the iceberg table.
      */
-    @Override
     public Builder tableLoader(TableLoader newTableLoader) {
       this.tableLoader = newTableLoader;
       return this;
@@ -214,25 +212,21 @@ public class FlinkSink {
      * Set the write properties for Flink sink. View the supported properties in {@link
      * FlinkWriteOptions}
      */
-    @Override
     public Builder setAll(Map<String, String> properties) {
       writeOptions.putAll(properties);
       return this;
     }
 
-    @Override
     public Builder tableSchema(TableSchema newTableSchema) {
       this.tableSchema = newTableSchema;
       return this;
     }
 
-    @Override
     public Builder overwrite(boolean newOverwrite) {
       writeOptions.put(FlinkWriteOptions.OVERWRITE_MODE.key(), Boolean.toString(newOverwrite));
       return this;
     }
 
-    @Override
     public Builder flinkConf(ReadableConfig config) {
       this.readableConfig = config;
       return this;
@@ -245,7 +239,6 @@ public class FlinkSink {
      * @param mode to specify the write distribution mode.
      * @return {@link Builder} to connect the iceberg table.
      */
-    @Override
     public Builder distributionMode(DistributionMode mode) {
       if (mode != null) {
         writeOptions.put(FlinkWriteOptions.DISTRIBUTION_MODE.key(), mode.modeName());
@@ -315,7 +308,6 @@ public class FlinkSink {
      * @param newWriteParallelism the number of parallel iceberg stream writer.
      * @return {@link Builder} to connect the iceberg table.
      */
-    @Override
     public Builder writeParallelism(int newWriteParallelism) {
       writeOptions.put(
           FlinkWriteOptions.WRITE_PARALLELISM.key(), Integer.toString(newWriteParallelism));
@@ -331,7 +323,6 @@ public class FlinkSink {
      * @param enabled indicate whether it should transform all INSERT/UPDATE_AFTER events to UPSERT.
      * @return {@link Builder} to connect the iceberg table.
      */
-    @Override
     public Builder upsert(boolean enabled) {
       writeOptions.put(FlinkWriteOptions.WRITE_UPSERT_ENABLED.key(), Boolean.toString(enabled));
       return this;
@@ -343,7 +334,6 @@ public class FlinkSink {
      * @param columns defines the iceberg table's key.
      * @return {@link Builder} to connect the iceberg table.
      */
-    @Override
     public Builder equalityFieldColumns(List<String> columns) {
       this.equalityFieldColumns = columns;
       return this;
@@ -388,13 +378,12 @@ public class FlinkSink {
       return this;
     }
 
-    @Override
     public Builder toBranch(String branch) {
       writeOptions.put(FlinkWriteOptions.BRANCH.key(), branch);
       return this;
     }
 
-    private DataStreamSink<Void> chainIcebergOperators() {
+    private <T> DataStreamSink<T> chainIcebergOperators() {
       Preconditions.checkArgument(
           inputCreator != null,
           "Please use forRowData() or forMapperOutputType() to initialize the input DataStream.");
@@ -418,8 +407,7 @@ public class FlinkSink {
       flinkWriteConf = new FlinkWriteConf(table, writeOptions, readableConfig);
 
       // Find out the equality field id list based on the user-provided equality field column names.
-      List<Integer> equalityFieldIds =
-          SinkUtil.checkAndGetEqualityFieldIds(table, equalityFieldColumns);
+      List<Integer> equalityFieldIds = checkAndGetEqualityFieldIds();
 
       RowType flinkRowType = toFlinkRowType(table.schema(), tableSchema);
       int writerParallelism =
@@ -449,7 +437,6 @@ public class FlinkSink {
      *
      * @return {@link DataStreamSink} for sink.
      */
-    @Override
     public DataStreamSink<Void> append() {
       return chainIcebergOperators();
     }
@@ -486,10 +473,12 @@ public class FlinkSink {
       return equalityFieldIds;
     }
 
-    private DataStreamSink<Void> appendDummySink(SingleOutputStreamOperator<Void> committerStream) {
-      DataStreamSink<Void> resultStream =
+    @SuppressWarnings("unchecked")
+    private <T> DataStreamSink<T> appendDummySink(
+        SingleOutputStreamOperator<Void> committerStream) {
+      DataStreamSink<T> resultStream =
           committerStream
-              .sinkTo(new DiscardingSink<>())
+              .addSink(new DiscardingSink())
               .name(operatorName(String.format("IcebergSink %s", this.table.name())))
               .setParallelism(1);
       if (uidPrefix != null) {
