@@ -64,7 +64,7 @@ public class ContinuousSplitPlannerImpl implements ContinuousSplitPlanner {
     this.workerPool =
         isSharedPool
             ? ThreadPools.getWorkerPool()
-            : ThreadPools.newFixedThreadPool(
+            : ThreadPools.newWorkerPool(
                 "iceberg-plan-worker-pool-" + threadName, scanContext.planParallelism());
   }
 
