@@ -104,7 +104,7 @@ public class TestFlinkUpsert extends CatalogTestBase {
   @Override
   @AfterEach
   public void clean() {
-    dropDatabase(flinkDatabase, true);
+    sql("DROP DATABASE IF EXISTS %s", flinkDatabase);
     super.clean();
   }
 
