@@ -21,9 +21,11 @@ package org.apache.iceberg.flink.source;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
+import java.nio.file.Path;
 import java.time.Duration;
 import java.util.Collection;
 import java.util.List;
+import java.util.Optional;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.stream.Collectors;
 import org.apache.flink.api.common.JobID;
@@ -31,11 +33,14 @@ import org.apache.flink.api.common.JobStatus;
 import org.apache.flink.api.common.eventtime.WatermarkStrategy;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.client.program.ClusterClient;
+import org.apache.flink.metrics.MetricGroup;
 import org.apache.flink.runtime.client.JobStatusMessage;
+import org.apache.flink.runtime.testutils.InMemoryReporter;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.data.RowData;
-import org.apache.flink.test.util.MiniClusterWithClientResource;
+import org.apache.flink.test.junit5.InjectClusterClient;
+import org.apache.flink.test.junit5.MiniClusterExtension;
 import org.apache.flink.types.Row;
 import org.apache.flink.util.CloseableIterator;
 import org.apache.iceberg.FileFormat;
@@ -43,43 +48,43 @@ import org.apache.iceberg.data.GenericAppenderHelper;
 import org.apache.iceberg.data.RandomGenericData;
 import org.apache.iceberg.data.Record;
 import org.apache.iceberg.flink.FlinkSchemaUtil;
-import org.apache.iceberg.flink.HadoopTableResource;
-import org.apache.iceberg.flink.MiniClusterResource;
+import org.apache.iceberg.flink.HadoopTableExtension;
+import org.apache.iceberg.flink.MiniFlinkClusterExtension;
 import org.apache.iceberg.flink.TestFixtures;
 import org.apache.iceberg.flink.TestHelpers;
 import org.apache.iceberg.flink.data.RowDataToRowMapper;
 import org.apache.iceberg.flink.source.assigner.SimpleSplitAssignerFactory;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.awaitility.Awaitility;
-import org.junit.Assert;
-import org.junit.ClassRule;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
+import org.junit.jupiter.api.io.TempDir;
 
 public class TestIcebergSourceContinuous {
 
-  @ClassRule
-  public static final MiniClusterWithClientResource MINI_CLUSTER_RESOURCE =
-      MiniClusterResource.createWithClassloaderCheckDisabled();
+  public static final InMemoryReporter METRIC_REPORTER = InMemoryReporter.create();
 
-  @ClassRule public static final TemporaryFolder TEMPORARY_FOLDER = new TemporaryFolder();
+  @TempDir protected Path temporaryFolder;
 
-  @Rule
-  public final HadoopTableResource tableResource =
-      new HadoopTableResource(
-          TEMPORARY_FOLDER, TestFixtures.DATABASE, TestFixtures.TABLE, TestFixtures.SCHEMA);
+  @RegisterExtension
+  public static final MiniClusterExtension MINI_CLUSTER_EXTENSION =
+      MiniFlinkClusterExtension.createWithClassloaderCheckDisabled(METRIC_REPORTER);
+
+  @RegisterExtension
+  private static final HadoopTableExtension TABLE_EXTENSION =
+      new HadoopTableExtension(TestFixtures.DATABASE, TestFixtures.TABLE, TestFixtures.SCHEMA);
 
   private final AtomicLong randomSeed = new AtomicLong(0L);
 
   @Test
   public void testTableScanThenIncremental() throws Exception {
     GenericAppenderHelper dataAppender =
-        new GenericAppenderHelper(tableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER);
+        new GenericAppenderHelper(TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder);
 
     // snapshot1
     List<Record> batch1 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch1);
 
     ScanContext scanContext =
@@ -92,49 +97,53 @@ public class TestIcebergSourceContinuous {
     try (CloseableIterator<Row> iter =
         createStream(scanContext).executeAndCollect(getClass().getSimpleName())) {
       List<Row> result1 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result1, batch1, tableResource.table().schema());
+      TestHelpers.assertRecords(result1, batch1, TABLE_EXTENSION.table().schema());
 
       // snapshot2
       List<Record> batch2 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch2);
-      tableResource.table().currentSnapshot().snapshotId();
+      TABLE_EXTENSION.table().currentSnapshot().snapshotId();
 
       List<Row> result2 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result2, batch2, tableResource.table().schema());
+      TestHelpers.assertRecords(result2, batch2, TABLE_EXTENSION.table().schema());
 
       // snapshot3
       List<Record> batch3 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch3);
-      tableResource.table().currentSnapshot().snapshotId();
+      TABLE_EXTENSION.table().currentSnapshot().snapshotId();
 
       List<Row> result3 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result3, batch3, tableResource.table().schema());
+      TestHelpers.assertRecords(result3, batch3, TABLE_EXTENSION.table().schema());
+
+      assertThatIcebergEnumeratorMetricsExist();
     }
   }
 
   @Test
   public void testTableScanThenIncrementalAfterExpiration() throws Exception {
     GenericAppenderHelper dataAppender =
-        new GenericAppenderHelper(tableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER);
+        new GenericAppenderHelper(TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder);
 
     // snapshot1
     List<Record> batch1 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch1);
-    long snapshotId = tableResource.table().currentSnapshot().snapshotId();
+    long snapshotId = TABLE_EXTENSION.table().currentSnapshot().snapshotId();
 
     // snapshot2
     List<Record> batch2 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch2);
 
-    tableResource.table().expireSnapshots().expireSnapshotId(snapshotId).commit();
+    TABLE_EXTENSION.table().expireSnapshots().expireSnapshotId(snapshotId).commit();
 
-    Assert.assertEquals(1, tableResource.table().history().size());
+    assertThat(TABLE_EXTENSION.table().history()).hasSize(1);
 
     ScanContext scanContext =
         ScanContext.builder()
@@ -143,8 +152,8 @@ public class TestIcebergSourceContinuous {
             .startingStrategy(StreamingStartingStrategy.TABLE_SCAN_THEN_INCREMENTAL)
             .build();
 
-    Assert.assertEquals(
-        FlinkSplitPlanner.ScanMode.BATCH, FlinkSplitPlanner.checkScanMode(scanContext));
+    assertThat(FlinkSplitPlanner.checkScanMode(scanContext))
+        .isEqualTo(FlinkSplitPlanner.ScanMode.BATCH);
 
     try (CloseableIterator<Row> iter =
         createStream(scanContext).executeAndCollect(getClass().getSimpleName())) {
@@ -152,33 +161,37 @@ public class TestIcebergSourceContinuous {
       List<Record> initialRecords = Lists.newArrayList();
       initialRecords.addAll(batch1);
       initialRecords.addAll(batch2);
-      TestHelpers.assertRecords(result1, initialRecords, tableResource.table().schema());
+      TestHelpers.assertRecords(result1, initialRecords, TABLE_EXTENSION.table().schema());
 
       // snapshot3
       List<Record> batch3 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch3);
-      tableResource.table().currentSnapshot().snapshotId();
+      TABLE_EXTENSION.table().currentSnapshot().snapshotId();
 
       List<Row> result3 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result3, batch3, tableResource.table().schema());
+      TestHelpers.assertRecords(result3, batch3, TABLE_EXTENSION.table().schema());
+
+      assertThatIcebergEnumeratorMetricsExist();
     }
   }
 
   @Test
   public void testEarliestSnapshot() throws Exception {
     GenericAppenderHelper dataAppender =
-        new GenericAppenderHelper(tableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER);
+        new GenericAppenderHelper(TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder);
 
     // snapshot0
     List<Record> batch0 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch0);
 
     // snapshot1
     List<Record> batch1 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch1);
 
     ScanContext scanContext =
@@ -193,41 +206,46 @@ public class TestIcebergSourceContinuous {
       List<Row> result1 = waitForResult(iter, 4);
       List<Record> combinedBatch0AndBatch1 = Lists.newArrayList(batch0);
       combinedBatch0AndBatch1.addAll(batch1);
-      TestHelpers.assertRecords(result1, combinedBatch0AndBatch1, tableResource.table().schema());
+      TestHelpers.assertRecords(result1, combinedBatch0AndBatch1, TABLE_EXTENSION.table().schema());
 
       // snapshot2
       List<Record> batch2 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch2);
 
       List<Row> result2 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result2, batch2, tableResource.table().schema());
+      TestHelpers.assertRecords(result2, batch2, TABLE_EXTENSION.table().schema());
 
       // snapshot3
       List<Record> batch3 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch3);
 
       List<Row> result3 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result3, batch3, tableResource.table().schema());
+      TestHelpers.assertRecords(result3, batch3, TABLE_EXTENSION.table().schema());
+
+      assertThatIcebergEnumeratorMetricsExist();
     }
   }
 
   @Test
-  public void testLatestSnapshot() throws Exception {
+  public void testLatestSnapshot(@InjectClusterClient ClusterClient<?> clusterClient)
+      throws Exception {
     GenericAppenderHelper dataAppender =
-        new GenericAppenderHelper(tableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER);
+        new GenericAppenderHelper(TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder);
 
     // snapshot0
     List<Record> batch0 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch0);
 
     // snapshot1
     List<Record> batch1 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch1);
 
     ScanContext scanContext =
@@ -241,48 +259,52 @@ public class TestIcebergSourceContinuous {
         createStream(scanContext).executeAndCollect(getClass().getSimpleName())) {
       // we want to make sure job is running first so that enumerator can
       // start from the latest snapshot before inserting the next batch2 below.
-      waitUntilJobIsRunning(MINI_CLUSTER_RESOURCE.getClusterClient());
+      waitUntilJobIsRunning(clusterClient);
 
       // inclusive behavior for starting snapshot
       List<Row> result1 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result1, batch1, tableResource.table().schema());
+      TestHelpers.assertRecords(result1, batch1, TABLE_EXTENSION.table().schema());
 
       // snapshot2
       List<Record> batch2 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch2);
 
       List<Row> result2 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result2, batch2, tableResource.table().schema());
+      TestHelpers.assertRecords(result2, batch2, TABLE_EXTENSION.table().schema());
 
       // snapshot3
       List<Record> batch3 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch3);
 
       List<Row> result3 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result3, batch3, tableResource.table().schema());
+      TestHelpers.assertRecords(result3, batch3, TABLE_EXTENSION.table().schema());
+
+      assertThatIcebergEnumeratorMetricsExist();
     }
   }
 
   @Test
   public void testSpecificSnapshotId() throws Exception {
     GenericAppenderHelper dataAppender =
-        new GenericAppenderHelper(tableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER);
+        new GenericAppenderHelper(TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder);
 
     // snapshot0
     List<Record> batch0 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch0);
-    long snapshot0 = tableResource.table().currentSnapshot().snapshotId();
+    long snapshot0 = TABLE_EXTENSION.table().currentSnapshot().snapshotId();
 
     // snapshot1
     List<Record> batch1 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch1);
-    long snapshot1 = tableResource.table().currentSnapshot().snapshotId();
+    long snapshot1 = TABLE_EXTENSION.table().currentSnapshot().snapshotId();
 
     ScanContext scanContext =
         ScanContext.builder()
@@ -295,47 +317,51 @@ public class TestIcebergSourceContinuous {
     try (CloseableIterator<Row> iter =
         createStream(scanContext).executeAndCollect(getClass().getSimpleName())) {
       List<Row> result1 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result1, batch1, tableResource.table().schema());
+      TestHelpers.assertRecords(result1, batch1, TABLE_EXTENSION.table().schema());
 
       // snapshot2
       List<Record> batch2 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch2);
 
       List<Row> result2 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result2, batch2, tableResource.table().schema());
+      TestHelpers.assertRecords(result2, batch2, TABLE_EXTENSION.table().schema());
 
       // snapshot3
       List<Record> batch3 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch3);
 
       List<Row> result3 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result3, batch3, tableResource.table().schema());
+      TestHelpers.assertRecords(result3, batch3, TABLE_EXTENSION.table().schema());
+
+      assertThatIcebergEnumeratorMetricsExist();
     }
   }
 
   @Test
   public void testSpecificSnapshotTimestamp() throws Exception {
     GenericAppenderHelper dataAppender =
-        new GenericAppenderHelper(tableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER);
+        new GenericAppenderHelper(TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder);
 
     // snapshot0
     List<Record> batch0 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch0);
-    long snapshot0Timestamp = tableResource.table().currentSnapshot().timestampMillis();
+    long snapshot0Timestamp = TABLE_EXTENSION.table().currentSnapshot().timestampMillis();
 
     // sleep for 2 ms to make sure snapshot1 has a higher timestamp value
     Thread.sleep(2);
 
     // snapshot1
     List<Record> batch1 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batch1);
-    long snapshot1Timestamp = tableResource.table().currentSnapshot().timestampMillis();
+    long snapshot1Timestamp = TABLE_EXTENSION.table().currentSnapshot().timestampMillis();
 
     ScanContext scanContext =
         ScanContext.builder()
@@ -349,25 +375,27 @@ public class TestIcebergSourceContinuous {
         createStream(scanContext).executeAndCollect(getClass().getSimpleName())) {
       // consume data from snapshot1
       List<Row> result1 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result1, batch1, tableResource.table().schema());
+      TestHelpers.assertRecords(result1, batch1, TABLE_EXTENSION.table().schema());
 
       // snapshot2
       List<Record> batch2 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch2);
 
       List<Row> result2 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result2, batch2, tableResource.table().schema());
+      TestHelpers.assertRecords(result2, batch2, TABLE_EXTENSION.table().schema());
 
       // snapshot3
       List<Record> batch3 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batch3);
 
       List<Row> result3 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result3, batch3, tableResource.table().schema());
+      TestHelpers.assertRecords(result3, batch3, TABLE_EXTENSION.table().schema());
+
+      assertThatIcebergEnumeratorMetricsExist();
     }
   }
 
@@ -375,27 +403,30 @@ public class TestIcebergSourceContinuous {
   public void testReadingFromBranch() throws Exception {
     String branch = "b1";
     GenericAppenderHelper dataAppender =
-        new GenericAppenderHelper(tableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER);
+        new GenericAppenderHelper(TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder);
 
     List<Record> batchBase =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(batchBase);
 
     // create branch
-    tableResource
+    TABLE_EXTENSION
         .table()
         .manageSnapshots()
-        .createBranch(branch, tableResource.table().currentSnapshot().snapshotId())
+        .createBranch(branch, TABLE_EXTENSION.table().currentSnapshot().snapshotId())
         .commit();
 
     // snapshot1 to branch
     List<Record> batch1 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(branch, batch1);
 
     // snapshot2 to branch
     List<Record> batch2 =
-        RandomGenericData.generate(tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+        RandomGenericData.generate(
+            TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
     dataAppender.appendToTable(branch, batch2);
 
     List<Record> branchExpectedRecords = Lists.newArrayList();
@@ -415,25 +446,26 @@ public class TestIcebergSourceContinuous {
     try (CloseableIterator<Row> iter =
         createStream(scanContext).executeAndCollect(getClass().getSimpleName())) {
       List<Row> resultMain = waitForResult(iter, 6);
-      TestHelpers.assertRecords(resultMain, branchExpectedRecords, tableResource.table().schema());
+      TestHelpers.assertRecords(
+          resultMain, branchExpectedRecords, TABLE_EXTENSION.table().schema());
 
       // snapshot3 to branch
       List<Record> batch3 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(branch, batch3);
 
       List<Row> result3 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result3, batch3, tableResource.table().schema());
+      TestHelpers.assertRecords(result3, batch3, TABLE_EXTENSION.table().schema());
 
       // snapshot4 to branch
       List<Record> batch4 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(branch, batch4);
 
       List<Row> result4 = waitForResult(iter, 2);
-      TestHelpers.assertRecords(result4, batch4, tableResource.table().schema());
+      TestHelpers.assertRecords(result4, batch4, TABLE_EXTENSION.table().schema());
     }
 
     // read only from main branch. Should contain only the first snapshot
@@ -446,14 +478,14 @@ public class TestIcebergSourceContinuous {
     try (CloseableIterator<Row> iter =
         createStream(scanContext).executeAndCollect(getClass().getSimpleName())) {
       List<Row> resultMain = waitForResult(iter, 2);
-      TestHelpers.assertRecords(resultMain, batchBase, tableResource.table().schema());
+      TestHelpers.assertRecords(resultMain, batchBase, TABLE_EXTENSION.table().schema());
 
       List<Record> batchMain2 =
           RandomGenericData.generate(
-              tableResource.table().schema(), 2, randomSeed.incrementAndGet());
+              TABLE_EXTENSION.table().schema(), 2, randomSeed.incrementAndGet());
       dataAppender.appendToTable(batchMain2);
       resultMain = waitForResult(iter, 2);
-      TestHelpers.assertRecords(resultMain, batchMain2, tableResource.table().schema());
+      TestHelpers.assertRecords(resultMain, batchMain2, TABLE_EXTENSION.table().schema());
     }
   }
 
@@ -462,7 +494,7 @@ public class TestIcebergSourceContinuous {
     assertThatThrownBy(
             () ->
                 IcebergSource.forRowData()
-                    .tableLoader(tableResource.tableLoader())
+                    .tableLoader(TABLE_EXTENSION.tableLoader())
                     .assignerFactory(new SimpleSplitAssignerFactory())
                     .streaming(true)
                     .endTag("tag")
@@ -478,7 +510,7 @@ public class TestIcebergSourceContinuous {
     DataStream<Row> stream =
         env.fromSource(
                 IcebergSource.forRowData()
-                    .tableLoader(tableResource.tableLoader())
+                    .tableLoader(TABLE_EXTENSION.tableLoader())
                     .assignerFactory(new SimpleSplitAssignerFactory())
                     .streaming(scanContext.isStreaming())
                     .streamingStartingStrategy(scanContext.streamingStartingStrategy())
@@ -490,7 +522,7 @@ public class TestIcebergSourceContinuous {
                 WatermarkStrategy.noWatermarks(),
                 "icebergSource",
                 TypeInformation.of(RowData.class))
-            .map(new RowDataToRowMapper(FlinkSchemaUtil.convert(tableResource.table().schema())));
+            .map(new RowDataToRowMapper(FlinkSchemaUtil.convert(TABLE_EXTENSION.table().schema())));
     return stream;
   }
 
@@ -520,4 +552,22 @@ public class TestIcebergSourceContinuous {
         .map(JobStatusMessage::getJobId)
         .collect(Collectors.toList());
   }
+
+  private static void assertThatIcebergEnumeratorMetricsExist() {
+    assertThatIcebergSourceMetricExists(
+        "enumerator", "coordinator.enumerator.elapsedSecondsSinceLastSplitDiscovery");
+    assertThatIcebergSourceMetricExists("enumerator", "coordinator.enumerator.unassignedSplits");
+    assertThatIcebergSourceMetricExists("enumerator", "coordinator.enumerator.pendingRecords");
+  }
+
+  private static void assertThatIcebergSourceMetricExists(
+      String metricGroupPattern, String metricName) {
+    Optional<MetricGroup> groups = METRIC_REPORTER.findGroup(metricGroupPattern);
+    assertThat(groups).isPresent();
+    assertThat(
+            METRIC_REPORTER.getMetricsByGroup(groups.get()).keySet().stream()
+                .map(name -> groups.get().getMetricIdentifier(name)))
+        .satisfiesOnlyOnce(
+            fullMetricName -> assertThat(fullMetricName).containsSubsequence(metricName));
+  }
 }
