@@ -18,9 +18,10 @@
  */
 package org.apache.iceberg.flink.source;
 
-import static org.apache.iceberg.flink.MiniClusterResource.DISABLE_CLASSLOADER_CHECK_CONFIG;
+import static org.apache.iceberg.flink.MiniFlinkClusterExtension.DISABLE_CLASSLOADER_CHECK_CONFIG;
 
 import java.io.Serializable;
+import java.nio.file.Path;
 import java.time.Duration;
 import java.time.Instant;
 import java.time.LocalDateTime;
@@ -37,6 +38,7 @@ import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.core.execution.JobClient;
 import org.apache.flink.metrics.Gauge;
 import org.apache.flink.runtime.metrics.MetricNames;
+import org.apache.flink.runtime.minicluster.MiniCluster;
 import org.apache.flink.runtime.minicluster.RpcServiceSharing;
 import org.apache.flink.runtime.testutils.CommonTestUtils;
 import org.apache.flink.runtime.testutils.InMemoryReporter;
@@ -49,24 +51,24 @@ import org.apache.flink.streaming.api.windowing.time.Time;
 import org.apache.flink.streaming.api.windowing.windows.TimeWindow;
 import org.apache.flink.table.data.GenericRowData;
 import org.apache.flink.table.data.RowData;
-import org.apache.flink.test.util.MiniClusterWithClientResource;
+import org.apache.flink.test.junit5.InjectMiniCluster;
+import org.apache.flink.test.junit5.MiniClusterExtension;
 import org.apache.flink.util.CloseableIterator;
 import org.apache.flink.util.Collector;
 import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.data.GenericAppenderHelper;
 import org.apache.iceberg.data.GenericRecord;
 import org.apache.iceberg.data.Record;
-import org.apache.iceberg.flink.HadoopTableResource;
+import org.apache.iceberg.flink.HadoopTableExtension;
 import org.apache.iceberg.flink.TestFixtures;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.awaitility.Awaitility;
-import org.junit.ClassRule;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
+import org.junit.jupiter.api.io.TempDir;
 
 public class TestIcebergSourceWithWatermarkExtractor implements Serializable {
   private static final int PARALLELISM = 4;
@@ -74,25 +76,24 @@ public class TestIcebergSourceWithWatermarkExtractor implements Serializable {
   private static final int RECORD_NUM_FOR_2_SPLITS = 200;
   private static final ConcurrentMap<Long, Integer> WINDOWS = Maps.newConcurrentMap();
 
-  @ClassRule public static final TemporaryFolder TEMPORARY_FOLDER = new TemporaryFolder();
+  @TempDir protected Path temporaryFolder;
 
-  private final InMemoryReporter reporter = InMemoryReporter.createWithRetainedMetrics();
+  private static final InMemoryReporter REPORTER = InMemoryReporter.createWithRetainedMetrics();
 
-  @Rule
-  public final MiniClusterWithClientResource miniClusterResource =
-      new MiniClusterWithClientResource(
+  @RegisterExtension
+  public static final MiniClusterExtension MINI_CLUSTER_EXTENSION =
+      new MiniClusterExtension(
           new MiniClusterResourceConfiguration.Builder()
               .setNumberTaskManagers(1)
               .setNumberSlotsPerTaskManager(PARALLELISM)
               .setRpcServiceSharing(RpcServiceSharing.DEDICATED)
-              .setConfiguration(reporter.addToConfiguration(DISABLE_CLASSLOADER_CHECK_CONFIG))
+              .setConfiguration(REPORTER.addToConfiguration(DISABLE_CLASSLOADER_CHECK_CONFIG))
               .withHaLeadershipControl()
               .build());
 
-  @Rule
-  public final HadoopTableResource sourceTableResource =
-      new HadoopTableResource(
-          TEMPORARY_FOLDER, TestFixtures.DATABASE, TestFixtures.TABLE, TestFixtures.TS_SCHEMA);
+  @RegisterExtension
+  private static final HadoopTableExtension TABLE_EXTENSION =
+      new HadoopTableExtension(TestFixtures.DATABASE, TestFixtures.TABLE, TestFixtures.TS_SCHEMA);
 
   /**
    * This is an integration test for watermark handling and windowing. Integration testing the
@@ -259,7 +260,7 @@ public class TestIcebergSourceWithWatermarkExtractor implements Serializable {
    * the readers continue reading.
    */
   @Test
-  public void testThrottling() throws Exception {
+  public void testThrottling(@InjectMiniCluster MiniCluster miniCluster) throws Exception {
     GenericAppenderHelper dataAppender = appender();
 
     // Generate records in advance
@@ -310,8 +311,7 @@ public class TestIcebergSourceWithWatermarkExtractor implements Serializable {
 
     try (CloseableIterator<RowData> resultIterator = stream.collectAsync()) {
       JobClient jobClient = env.executeAsync("Iceberg Source Throttling Test");
-      CommonTestUtils.waitForAllTaskRunning(
-          miniClusterResource.getMiniCluster(), jobClient.getJobID(), false);
+      CommonTestUtils.waitForAllTaskRunning(miniCluster, jobClient.getJobID(), false);
 
       // Insert the first data into the table
       dataAppender.appendToTable(dataAppender.writeFile(batch1), dataAppender.writeFile(batch2));
@@ -353,7 +353,7 @@ public class TestIcebergSourceWithWatermarkExtractor implements Serializable {
 
   protected IcebergSource<RowData> source() {
     return IcebergSource.<RowData>builder()
-        .tableLoader(sourceTableResource.tableLoader())
+        .tableLoader(TABLE_EXTENSION.tableLoader())
         .watermarkColumn("ts")
         .project(TestFixtures.TS_SCHEMA)
         .splitSize(100L)
@@ -377,7 +377,7 @@ public class TestIcebergSourceWithWatermarkExtractor implements Serializable {
 
   private Optional<Gauge<Long>> findAlignmentDriftMetric(JobID jobID, long withValue) {
     String metricsName = SOURCE_NAME + ".*" + MetricNames.WATERMARK_ALIGNMENT_DRIFT;
-    return reporter.findMetrics(jobID, metricsName).values().stream()
+    return REPORTER.findMetrics(jobID, metricsName).values().stream()
         .map(m -> (Gauge<Long>) m)
         .filter(m -> m.getValue() == withValue)
         .findFirst();
@@ -389,7 +389,7 @@ public class TestIcebergSourceWithWatermarkExtractor implements Serializable {
     hadoopConf.set("write.parquet.page-size-bytes", "64");
     hadoopConf.set("write.parquet.row-group-size-bytes", "64");
     return new GenericAppenderHelper(
-        sourceTableResource.table(), FileFormat.PARQUET, TEMPORARY_FOLDER, hadoopConf);
+        TABLE_EXTENSION.table(), FileFormat.PARQUET, temporaryFolder, hadoopConf);
   }
 
   private static RowData row(long time, long count) {
