@@ -44,7 +44,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.Queues;
 import org.jetbrains.annotations.Nullable;
 
 /** Testing source implementation for Flink sources which can be triggered manually. */
-class ManualSource<T>
+public class ManualSource<T>
     implements Source<T, ManualSource.DummySplit, ManualSource.DummyCheckpoint>,
         ResultTypeQueryable<T> {
 
@@ -65,7 +65,7 @@ class ManualSource<T>
    * @param env to register the source
    * @param type of the events returned by the source
    */
-  ManualSource(StreamExecutionEnvironment env, TypeInformation<T> type) {
+  public ManualSource(StreamExecutionEnvironment env, TypeInformation<T> type) {
     this.type = type;
     this.env = env;
     this.index = numSources++;
@@ -78,7 +78,7 @@ class ManualSource<T>
    *
    * @param event to emit
    */
-  void sendRecord(T event) {
+  public void sendRecord(T event) {
     this.sendInternal(Tuple2.of(event, null));
   }
 
@@ -88,7 +88,7 @@ class ManualSource<T>
    * @param event to emit
    * @param eventTime of the event
    */
-  void sendRecord(T event, long eventTime) {
+  public void sendRecord(T event, long eventTime) {
     this.sendInternal(Tuple2.of(event, eventTime));
   }
 
@@ -97,7 +97,7 @@ class ManualSource<T>
    *
    * @param timeStamp of the watermark
    */
-  void sendWatermark(long timeStamp) {
+  public void sendWatermark(long timeStamp) {
     this.sendInternal(Tuple2.of(null, timeStamp));
   }
 
@@ -112,7 +112,7 @@ class ManualSource<T>
    *
    * @return the stream emitted by this source
    */
-  DataStream<T> dataStream() {
+  public DataStream<T> dataStream() {
     if (this.stream == null) {
       this.stream =
           this.env
