@@ -76,12 +76,6 @@ public class InputFormatConfig {
 
   public static final String CATALOG_CONFIG_PREFIX = "iceberg.catalog.";
 
-  public enum InMemoryDataModel {
-    PIG,
-    HIVE,
-    GENERIC // Default data model is of Iceberg Generics
-  }
-
   public static class ConfigBuilder {
     private final Configuration conf;
 
@@ -164,16 +158,6 @@ public class InputFormatConfig {
       return this;
     }
 
-    public ConfigBuilder useHiveRows() {
-      conf.set(IN_MEMORY_DATA_MODEL, InMemoryDataModel.HIVE.name());
-      return this;
-    }
-
-    public ConfigBuilder usePigTuples() {
-      conf.set(IN_MEMORY_DATA_MODEL, InMemoryDataModel.PIG.name());
-      return this;
-    }
-
     /**
      * Compute platforms pass down filters to data sources. If the data source cannot apply some
      * filters, or only partially applies the filter, it will return the residual filter back. If
