@@ -124,10 +124,15 @@ public class OrcMetrics {
       final Stream<FieldMetrics<?>> fieldMetricsStream,
       final MetricsConfig metricsConfig,
       final NameMapping mapping) {
-    final TypeDescription orcSchemaWithIds =
-        (!ORCSchemaUtil.hasIds(orcSchema) && mapping != null)
-            ? ORCSchemaUtil.applyNameMapping(orcSchema, mapping)
-            : orcSchema;
+    TypeDescription orcSchemaWithIds;
+    if (ORCSchemaUtil.hasIds(orcSchema)) {
+      orcSchemaWithIds = orcSchema;
+    } else if (mapping != null) {
+      orcSchemaWithIds = ORCSchemaUtil.applyNameMapping(orcSchema, mapping);
+    } else {
+      return new Metrics(numOfRows);
+    }
+
     final Set<Integer> statsColumns = statsColumns(orcSchemaWithIds);
     final MetricsConfig effectiveMetricsConfig =
         Optional.ofNullable(metricsConfig).orElseGet(MetricsConfig::getDefault);
@@ -135,10 +140,6 @@ public class OrcMetrics {
     Map<Integer, Long> valueCounts = Maps.newHashMapWithExpectedSize(colStats.length);
     Map<Integer, Long> nullCounts = Maps.newHashMapWithExpectedSize(colStats.length);
 
-    if (!ORCSchemaUtil.hasIds(orcSchemaWithIds)) {
-      return new Metrics(numOfRows, columnSizes, valueCounts, nullCounts, null, null, null);
-    }
-
     final Schema schema = ORCSchemaUtil.convert(orcSchemaWithIds);
     Map<Integer, ByteBuffer> lowerBounds = Maps.newHashMap();
     Map<Integer, ByteBuffer> upperBounds = Maps.newHashMap();
@@ -161,7 +162,7 @@ public class OrcMetrics {
         final MetricsMode metricsMode =
             MetricsUtil.metricsMode(schema, effectiveMetricsConfig, icebergCol.fieldId());
 
-        if (metricsMode == MetricsModes.None.get()) {
+        if (metricsMode == MetricsModes.None.get() || inMapOrList(orcCol)) {
           continue;
         }
 
@@ -170,7 +171,7 @@ public class OrcMetrics {
         if (statsColumns.contains(fieldId)) {
           // Since ORC does not track null values nor repeated ones, the value count for columns in
           // containers (maps, list) may be larger than what it actually is, however these are not
-          // used in experssions right now. For such cases, we use the value number of values
+          // used in expressions right now. For such cases, we use the value number of values
           // directly stored in ORC.
           if (colStat.hasNull()) {
             nullCounts.put(fieldId, numOfRows - colStat.getNumberOfValues());
@@ -208,6 +209,17 @@ public class OrcMetrics {
         upperBounds);
   }
 
+  private static boolean inMapOrList(TypeDescription orcCol) {
+    TypeDescription current = orcCol;
+    while ((current = current.getParent()) != null) {
+      if (current.getCategory() != TypeDescription.Category.STRUCT) {
+        return true;
+      }
+    }
+
+    return false;
+  }
+
   private static Optional<ByteBuffer> fromOrcMin(
       Type type,
       ColumnStatistics columnStats,
