@@ -30,6 +30,7 @@ import java.util.Map;
 import java.util.UUID;
 import java.util.function.Function;
 import java.util.stream.Collectors;
+import java.util.stream.IntStream;
 import java.util.stream.Stream;
 import org.apache.avro.util.Utf8;
 import org.apache.iceberg.DoubleFieldMetrics;
@@ -40,6 +41,7 @@ import org.apache.iceberg.deletes.PositionDelete;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.types.TypeUtil;
+import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.DecimalUtil;
 import org.apache.iceberg.util.UUIDUtil;
 import org.apache.parquet.column.ColumnDescriptor;
@@ -71,6 +73,10 @@ public class ParquetValueWriters {
     return new ShortWriter(desc);
   }
 
+  public static <T> ParquetValueWriter<T> unboxed(ColumnDescriptor desc) {
+    return new UnboxedWriter<>(desc);
+  }
+
   public static UnboxedWriter<Integer> ints(ColumnDescriptor desc) {
     return new UnboxedWriter<>(desc);
   }
@@ -127,9 +133,21 @@ public class ParquetValueWriters {
     return new MapWriter<>(dl, rl, keyWriter, valueWriter);
   }
 
+  /**
+   * Create a struct writer that produces a StructLike record.
+   *
+   * @deprecated will be removed in 1.10.0; use {@link #recordWriter(Types.StructType, List)}
+   *     instead.
+   */
+  @Deprecated
   public static <T extends StructLike> StructWriter<T> recordWriter(
       List<ParquetValueWriter<?>> writers) {
-    return new RecordWriter<>(writers);
+    return recordWriter(null, writers);
+  }
+
+  public static <T extends StructLike> StructWriter<T> recordWriter(
+      Types.StructType struct, List<ParquetValueWriter<?>> writers) {
+    return new RecordWriter<>(struct, writers);
   }
 
   public abstract static class PrimitiveWriter<T> implements ParquetValueWriter<T> {
@@ -387,8 +405,8 @@ public class ParquetValueWriters {
   }
 
   private static class RecordWriter<T extends StructLike> extends StructWriter<T> {
-    private RecordWriter(List<ParquetValueWriter<?>> writers) {
-      super(writers);
+    private RecordWriter(Types.StructType struct, List<ParquetValueWriter<?>> writers) {
+      super(struct, writers);
     }
 
     @Override
@@ -622,11 +640,21 @@ public class ParquetValueWriters {
   }
 
   public abstract static class StructWriter<S> implements ParquetValueWriter<S> {
+    private final int[] fieldIndexes;
     private final ParquetValueWriter<Object>[] writers;
     private final List<TripleWriter<?>> children;
 
-    @SuppressWarnings("unchecked")
     protected StructWriter(List<ParquetValueWriter<?>> writers) {
+      this((Types.StructType) null, writers);
+    }
+
+    protected StructWriter(Types.StructType struct, List<ParquetValueWriter<?>> writers) {
+      this(writerToFieldIndex(struct, writers.size()), writers);
+    }
+
+    @SuppressWarnings("unchecked")
+    protected StructWriter(int[] fieldIndexes, List<ParquetValueWriter<?>> writers) {
+      this.fieldIndexes = fieldIndexes;
       this.writers =
           (ParquetValueWriter<Object>[])
               Array.newInstance(ParquetValueWriter.class, writers.size());
@@ -644,7 +672,7 @@ public class ParquetValueWriters {
     @Override
     public void write(int repetitionLevel, S value) {
       for (int i = 0; i < writers.length; i += 1) {
-        Object fieldValue = get(value, i);
+        Object fieldValue = get(value, fieldIndexes[i]);
         writers[i].write(repetitionLevel, fieldValue);
       }
     }
@@ -691,4 +719,25 @@ public class ParquetValueWriters {
       throw new IllegalArgumentException("Cannot get value for invalid index: " + index);
     }
   }
+
+  /** Returns a mapping from writer index to field index, skipping Unknown columns. */
+  static int[] writerToFieldIndex(Types.StructType struct, int numWriters) {
+    if (null == struct) {
+      return IntStream.rangeClosed(0, numWriters).toArray();
+    }
+
+    List<Types.NestedField> recordFields = struct.fields();
+
+    // value writer index to record field index
+    int[] indexes = new int[numWriters];
+    int writerIndex = 0;
+    for (int pos = 0; pos < recordFields.size(); pos += 1) {
+      if (recordFields.get(pos).type().typeId() != org.apache.iceberg.types.Type.TypeID.UNKNOWN) {
+        indexes[writerIndex] = pos;
+        writerIndex += 1;
+      }
+    }
+
+    return indexes;
+  }
 }
