@@ -21,6 +21,8 @@ package org.apache.iceberg.snowflake;
 import static org.apache.iceberg.snowflake.JdbcSnowflakeClient.DATABASE_NOT_FOUND_ERROR_CODES;
 import static org.apache.iceberg.snowflake.JdbcSnowflakeClient.SCHEMA_NOT_FOUND_ERROR_CODES;
 import static org.apache.iceberg.snowflake.JdbcSnowflakeClient.TABLE_NOT_FOUND_ERROR_CODES;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doAnswer;
@@ -37,7 +39,6 @@ import org.apache.iceberg.exceptions.NoSuchTableException;
 import org.apache.iceberg.jdbc.JdbcClientPool;
 import org.apache.iceberg.jdbc.UncheckedInterruptedException;
 import org.apache.iceberg.jdbc.UncheckedSQLException;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
@@ -79,7 +80,7 @@ public class JdbcSnowflakeClientTest {
 
   @Test
   public void testNullClientPoolInConstructor() {
-    Assertions.assertThatExceptionOfType(IllegalArgumentException.class)
+    assertThatExceptionOfType(IllegalArgumentException.class)
         .isThrownBy(() -> new JdbcSnowflakeClient(null))
         .withMessageContaining("JdbcClientPool must be non-null");
   }
@@ -91,8 +92,7 @@ public class JdbcSnowflakeClientTest {
     when(mockResultSet.getString("database_name")).thenReturn("DB_1");
     when(mockResultSet.getString("name")).thenReturn("SCHEMA_1");
 
-    Assertions.assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1")))
-        .isTrue();
+    assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1"))).isTrue();
 
     verify(mockQueryHarness)
         .query(
@@ -113,16 +113,13 @@ public class JdbcSnowflakeClientTest {
             new SQLException("Database does not exist or not authorized", "2000", 2001, null));
 
     // Error code 2003
-    Assertions.assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1")))
-        .isFalse();
+    assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1"))).isFalse();
 
     // Error code 2043
-    Assertions.assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1")))
-        .isFalse();
+    assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1"))).isFalse();
 
     // Error code 2001
-    Assertions.assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1")))
-        .isFalse();
+    assertThat(snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1"))).isFalse();
   }
 
   @Test
@@ -130,7 +127,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new SQLException("Some other exception", "2000", 2, null);
     when(mockResultSet.next()).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(() -> snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1")))
         .withMessageContaining("Failed to check if database 'DATABASE: 'DB_1'' exists")
         .withCause(injectedException);
@@ -143,7 +140,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new InterruptedException("Fake interrupted exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedInterruptedException.class)
+    assertThatExceptionOfType(UncheckedInterruptedException.class)
         .isThrownBy(() -> snowflakeClient.databaseExists(SnowflakeIdentifier.ofDatabase("DB_1")))
         .withMessageContaining("Interrupted while checking if database 'DATABASE: 'DB_1'' exists")
         .withCause(injectedException);
@@ -161,8 +158,7 @@ public class JdbcSnowflakeClientTest {
     when(mockResultSet.getString("database_name")).thenReturn("DB1");
     when(mockResultSet.getString("schema_name")).thenReturn("SCHEMA1");
 
-    Assertions.assertThat(
-            snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB1", "SCHEMA1")))
+    assertThat(snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB1", "SCHEMA1")))
         .isTrue();
 
     verify(mockQueryHarness)
@@ -201,18 +197,15 @@ public class JdbcSnowflakeClientTest {
     when(mockResultSet.getString("database_name")).thenReturn("DB1");
 
     // Error code 2003
-    Assertions.assertThat(
-            snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
+    assertThat(snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
         .isFalse();
 
     // Error code 2043
-    Assertions.assertThat(
-            snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
+    assertThat(snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
         .isFalse();
 
     // Error code 2001
-    Assertions.assertThat(
-            snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
+    assertThat(snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
         .isFalse();
   }
 
@@ -228,7 +221,7 @@ public class JdbcSnowflakeClientTest {
     when(mockResultSet.getString("name")).thenReturn("DB1").thenReturn("SCHEMA1");
     when(mockResultSet.getString("database_name")).thenReturn("DB1");
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(
             () -> snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
         .withMessageContaining("Failed to check if schema 'SCHEMA: 'DB_1.SCHEMA_2'' exists")
@@ -242,7 +235,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new InterruptedException("Fake Interrupted exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedInterruptedException.class)
+    assertThatExceptionOfType(UncheckedInterruptedException.class)
         .isThrownBy(
             () -> snowflakeClient.schemaExists(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
         .withMessageContaining("Interrupted while checking if database 'DATABASE: 'DB_1'' exists")
@@ -263,7 +256,7 @@ public class JdbcSnowflakeClientTest {
             eq("SHOW DATABASES IN ACCOUNT"),
             any(JdbcSnowflakeClient.ResultSetParser.class));
 
-    Assertions.assertThat(actualList)
+    assertThat(actualList)
         .containsExactly(
             SnowflakeIdentifier.ofDatabase("DB_1"),
             SnowflakeIdentifier.ofDatabase("DB_2"),
@@ -281,7 +274,7 @@ public class JdbcSnowflakeClientTest {
         new SQLException(String.format("SQL exception with Error Code %d", 0), "2000", 0, null);
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(() -> snowflakeClient.listDatabases())
         .withMessageContaining("Failed to list databases")
         .withCause(injectedException);
@@ -298,7 +291,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new SQLException("Fake SQL exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(() -> snowflakeClient.listDatabases())
         .withMessageContaining("Failed to list databases")
         .withCause(injectedException);
@@ -314,7 +307,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new InterruptedException("Fake interrupted exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedInterruptedException.class)
+    assertThatExceptionOfType(UncheckedInterruptedException.class)
         .isThrownBy(() -> snowflakeClient.listDatabases())
         .withMessageContaining("Interrupted while listing databases")
         .withCause(injectedException);
@@ -347,7 +340,7 @@ public class JdbcSnowflakeClientTest {
             any(JdbcSnowflakeClient.ResultSetParser.class),
             eq(null));
 
-    Assertions.assertThat(actualList)
+    assertThat(actualList)
         .containsExactly(
             SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_1"),
             SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2"),
@@ -375,7 +368,7 @@ public class JdbcSnowflakeClientTest {
             any(JdbcSnowflakeClient.ResultSetParser.class),
             eq("DB_1"));
 
-    Assertions.assertThat(actualList)
+    assertThat(actualList)
         .containsExactly(
             SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_1"),
             SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2"));
@@ -392,7 +385,7 @@ public class JdbcSnowflakeClientTest {
         new SQLException(String.format("SQL exception with Error Code %d", 0), "2000", 0, null);
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(() -> snowflakeClient.listSchemas(SnowflakeIdentifier.ofRoot()))
         .withMessageContaining("Failed to list schemas for scope 'ROOT: '''")
         .withCause(injectedException);
@@ -415,7 +408,7 @@ public class JdbcSnowflakeClientTest {
               null);
       when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-      Assertions.assertThatExceptionOfType(NoSuchNamespaceException.class)
+      assertThatExceptionOfType(NoSuchNamespaceException.class)
           .isThrownBy(() -> snowflakeClient.listSchemas(SnowflakeIdentifier.ofDatabase("DB_1")))
           .withMessageContaining(
               String.format(
@@ -428,7 +421,7 @@ public class JdbcSnowflakeClientTest {
   /** List schemas is not supported at Schema level */
   @Test
   public void testListSchemasAtSchemaLevel() {
-    Assertions.assertThatExceptionOfType(IllegalArgumentException.class)
+    assertThatExceptionOfType(IllegalArgumentException.class)
         .isThrownBy(
             () -> snowflakeClient.listSchemas(SnowflakeIdentifier.ofSchema("DB_1", "SCHEMA_2")))
         .withMessageContaining("Unsupported scope type for listSchemas: SCHEMA: 'DB_1.SCHEMA_2'");
@@ -445,7 +438,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new SQLException("Fake SQL exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(() -> snowflakeClient.listSchemas(SnowflakeIdentifier.ofDatabase("DB_1")))
         .withMessageContaining("Failed to list schemas for scope 'DATABASE: 'DB_1''")
         .withCause(injectedException);
@@ -461,7 +454,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new InterruptedException("Fake interrupted exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedInterruptedException.class)
+    assertThatExceptionOfType(UncheckedInterruptedException.class)
         .isThrownBy(() -> snowflakeClient.listSchemas(SnowflakeIdentifier.ofDatabase("DB_1")))
         .withMessageContaining("Interrupted while listing schemas for scope 'DATABASE: 'DB_1''")
         .withCause(injectedException);
@@ -506,7 +499,7 @@ public class JdbcSnowflakeClientTest {
             any(JdbcSnowflakeClient.ResultSetParser.class),
             eq(null));
 
-    Assertions.assertThat(actualList)
+    assertThat(actualList)
         .containsExactly(
             SnowflakeIdentifier.ofTable("DB_1", "SCHEMA_1", "TABLE_1"),
             SnowflakeIdentifier.ofTable("DB_1", "SCHEMA_1", "TABLE_2"),
@@ -545,7 +538,7 @@ public class JdbcSnowflakeClientTest {
             any(JdbcSnowflakeClient.ResultSetParser.class),
             eq("DB_1"));
 
-    Assertions.assertThat(actualList)
+    assertThat(actualList)
         .containsExactly(
             SnowflakeIdentifier.ofTable("DB_1", "SCHEMA_1", "TABLE_1"),
             SnowflakeIdentifier.ofTable("DB_1", "SCHEMA_1", "TABLE_2"),
@@ -574,7 +567,7 @@ public class JdbcSnowflakeClientTest {
             any(JdbcSnowflakeClient.ResultSetParser.class),
             eq("DB_1.SCHEMA_1"));
 
-    Assertions.assertThat(actualList)
+    assertThat(actualList)
         .containsExactly(
             SnowflakeIdentifier.ofTable("DB_1", "SCHEMA_1", "TABLE_1"),
             SnowflakeIdentifier.ofTable("DB_1", "SCHEMA_1", "TABLE_2"));
@@ -592,7 +585,7 @@ public class JdbcSnowflakeClientTest {
         new SQLException(String.format("SQL exception with Error Code %d", 0), "2000", 0, null);
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(() -> snowflakeClient.listIcebergTables(SnowflakeIdentifier.ofRoot()))
         .withMessageContaining("Failed to list tables for scope 'ROOT: '''")
         .withCause(injectedException);
@@ -615,7 +608,7 @@ public class JdbcSnowflakeClientTest {
               null);
       when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-      Assertions.assertThatExceptionOfType(NoSuchNamespaceException.class)
+      assertThatExceptionOfType(NoSuchNamespaceException.class)
           .isThrownBy(
               () -> snowflakeClient.listIcebergTables(SnowflakeIdentifier.ofDatabase("DB_1")))
           .withMessageContaining(
@@ -643,7 +636,7 @@ public class JdbcSnowflakeClientTest {
               null);
       when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-      Assertions.assertThatExceptionOfType(NoSuchNamespaceException.class)
+      assertThatExceptionOfType(NoSuchNamespaceException.class)
           .isThrownBy(
               () ->
                   snowflakeClient.listIcebergTables(
@@ -667,7 +660,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new SQLException("Fake SQL exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(() -> snowflakeClient.listIcebergTables(SnowflakeIdentifier.ofDatabase("DB_1")))
         .withMessageContaining("Failed to list tables for scope 'DATABASE: 'DB_1''")
         .withCause(injectedException);
@@ -684,7 +677,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new InterruptedException("Fake interrupted exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedInterruptedException.class)
+    assertThatExceptionOfType(UncheckedInterruptedException.class)
         .isThrownBy(() -> snowflakeClient.listIcebergTables(SnowflakeIdentifier.ofDatabase("DB_1")))
         .withMessageContaining("Interrupted while listing tables for scope 'DATABASE: 'DB_1''")
         .withCause(injectedException);
@@ -719,7 +712,7 @@ public class JdbcSnowflakeClientTest {
             "s3://tab1/metadata/v3.metadata.json",
             "success",
             null);
-    Assertions.assertThat(actualMetadata).isEqualTo(expectedMetadata);
+    assertThat(actualMetadata).isEqualTo(expectedMetadata);
   }
 
   /**
@@ -751,7 +744,7 @@ public class JdbcSnowflakeClientTest {
             "wasbs://mycontainer@myaccount.blob.core.windows.net/tab3/metadata/v334.metadata.json",
             "success",
             null);
-    Assertions.assertThat(actualMetadata).isEqualTo(expectedMetadata);
+    assertThat(actualMetadata).isEqualTo(expectedMetadata);
   }
 
   /**
@@ -783,7 +776,7 @@ public class JdbcSnowflakeClientTest {
             "gs://tab5/metadata/v793.metadata.json",
             "success",
             null);
-    Assertions.assertThat(actualMetadata).isEqualTo(expectedMetadata);
+    assertThat(actualMetadata).isEqualTo(expectedMetadata);
   }
 
   /** Malformed JSON from a ResultSet should propagate as an IllegalArgumentException. */
@@ -791,7 +784,7 @@ public class JdbcSnowflakeClientTest {
   public void testGetTableMetadataMalformedJson() throws SQLException {
     when(mockResultSet.next()).thenReturn(true);
     when(mockResultSet.getString("METADATA")).thenReturn("{\"malformed_no_closing_bracket");
-    Assertions.assertThatExceptionOfType(IllegalArgumentException.class)
+    assertThatExceptionOfType(IllegalArgumentException.class)
         .isThrownBy(
             () ->
                 snowflakeClient.loadTableMetadata(
@@ -815,7 +808,7 @@ public class JdbcSnowflakeClientTest {
               null);
       when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-      Assertions.assertThatExceptionOfType(NoSuchTableException.class)
+      assertThatExceptionOfType(NoSuchTableException.class)
           .isThrownBy(
               () ->
                   snowflakeClient.loadTableMetadata(
@@ -839,7 +832,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new SQLException("Fake SQL exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedSQLException.class)
+    assertThatExceptionOfType(UncheckedSQLException.class)
         .isThrownBy(
             () ->
                 snowflakeClient.loadTableMetadata(
@@ -858,7 +851,7 @@ public class JdbcSnowflakeClientTest {
     Exception injectedException = new InterruptedException("Fake interrupted exception");
     when(mockClientPool.run(any(ClientPool.Action.class))).thenThrow(injectedException);
 
-    Assertions.assertThatExceptionOfType(UncheckedInterruptedException.class)
+    assertThatExceptionOfType(UncheckedInterruptedException.class)
         .isThrownBy(
             () ->
                 snowflakeClient.loadTableMetadata(
