@@ -24,7 +24,7 @@ import org.apache.spark.sql.connector.expressions.Transform
 
 case class SetIdentifierFields(
     table: Seq[String],
-    fields: Seq[String]) extends Command {
+    fields: Seq[String]) extends LeafCommand {
   import org.apache.spark.sql.connector.catalog.CatalogV2Implicits._
 
   override lazy val output: Seq[Attribute] = Nil
