@@ -19,20 +19,22 @@
 
 package org.apache.spark.sql.execution.datasources.v2
 
-import org.apache.spark.sql.catalyst.InternalRow
-import org.apache.spark.sql.connector.write.BatchWrite
+import org.apache.spark.sql.catalyst.expressions.AttributeSet
+import org.apache.spark.sql.connector.write.Write
 import org.apache.spark.sql.execution.SparkPlan
 
+/**
+ * Physical plan node to replace data in existing tables.
+ */
 case class ReplaceDataExec(
-    batchWrite: BatchWrite,
+    query: SparkPlan,
     refreshCache: () => Unit,
-    query: SparkPlan) extends V2TableWriteExec {
+    write: Write) extends V2ExistingTableWriteExec {
 
-  override protected def run(): Seq[InternalRow] = {
-    // calling prepare() ensures we execute DynamicFileFilter if present
-    prepare()
-    val writtenRows = writeWithV2(batchWrite)
-    refreshCache()
-    writtenRows
+  override lazy val references: AttributeSet = query.outputSet
+  override lazy val stringArgs: Iterator[Any] = Iterator(query, write)
+
+  override protected def withNewChildInternal(newChild: SparkPlan): ReplaceDataExec = {
+    copy(query = newChild)
   }
 }
