@@ -241,6 +241,10 @@ public class TestMergeOnReadDelete extends TestDelete {
     createTableWithDeleteGranularity(
         "id INT, dep STRING", "PARTITIONED BY (dep)", deleteGranularity);
 
+    sql(
+        "ALTER TABLE %s SET TBLPROPERTIES ('%s' '%s')",
+        tableName, TableProperties.DELETE_GRANULARITY, deleteGranularity);
+
     append(tableName, new Employee(1, "hr"), new Employee(2, "hr"));
     append(tableName, new Employee(3, "hr"), new Employee(4, "hr"));
     append(tableName, new Employee(1, "hardware"), new Employee(2, "hardware"));
