@@ -148,6 +148,9 @@ public class TestReplaceBranch extends ExtensionsTestBase {
     long first = table.currentSnapshot().snapshotId();
     String branchName = "b1";
     table.manageSnapshots().createBranch(branchName, first).commit();
+    SnapshotRef b1 = table.refs().get(branchName);
+    Integer minSnapshotsToKeep = b1.minSnapshotsToKeep();
+    Long maxSnapshotAgeMs = b1.maxSnapshotAgeMs();
     df.writeTo(tableName).append();
     long second = table.currentSnapshot().snapshotId();
 
