@@ -38,6 +38,8 @@ import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DeleteFile;
 import org.apache.iceberg.FileScanTask;
 import org.apache.iceberg.Files;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.RowLevelOperationMode;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Table;
@@ -67,12 +69,13 @@ import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
 import org.apache.spark.storage.memory.MemoryStore;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runners.Parameterized.Parameters;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-public class TestSparkExecutorCache extends SparkExtensionsTestBase {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestSparkExecutorCache extends ExtensionsTestBase {
 
   @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}")
   public static Object[][] parameters() {
@@ -99,31 +102,26 @@ public class TestSparkExecutorCache extends SparkExtensionsTestBase {
   private String targetTableName;
   private TableIdentifier targetTableIdent;
 
-  public TestSparkExecutorCache(
-      String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
-  }
-
-  @Before
+  @BeforeEach
   public void configureTargetTableName() {
     String name = "target_exec_cache_" + JOB_COUNTER.incrementAndGet();
     this.targetTableName = tableName(name);
     this.targetTableIdent = TableIdentifier.of(Namespace.of("default"), name);
   }
 
-  @After
+  @AfterEach
   public void releaseResources() {
     sql("DROP TABLE IF EXISTS %s", targetTableName);
     sql("DROP TABLE IF EXISTS %s", UPDATES_VIEW_NAME);
     INPUT_FILES.clear();
   }
 
-  @Test
+  @TestTemplate
   public void testCopyOnWriteDelete() throws Exception {
     checkDelete(COPY_ON_WRITE);
   }
 
-  @Test
+  @TestTemplate
   public void testMergeOnReadDelete() throws Exception {
     checkDelete(MERGE_ON_READ);
   }
@@ -148,12 +146,12 @@ public class TestSparkExecutorCache extends SparkExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id ASC", targetTableName));
   }
 
-  @Test
+  @TestTemplate
   public void testCopyOnWriteUpdate() throws Exception {
     checkUpdate(COPY_ON_WRITE);
   }
 
-  @Test
+  @TestTemplate
   public void testMergeOnReadUpdate() throws Exception {
     checkUpdate(MERGE_ON_READ);
   }
@@ -181,12 +179,12 @@ public class TestSparkExecutorCache extends SparkExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id ASC", targetTableName));
   }
 
-  @Test
+  @TestTemplate
   public void testCopyOnWriteMerge() throws Exception {
     checkMerge(COPY_ON_WRITE);
   }
 
-  @Test
+  @TestTemplate
   public void testMergeOnReadMerge() throws Exception {
     checkMerge(MERGE_ON_READ);
   }
@@ -282,13 +280,13 @@ public class TestSparkExecutorCache extends SparkExtensionsTestBase {
       deletes.add(delete.copy(col, value));
     }
 
-    OutputFile out = Files.localOutput(temp.newFile("eq-deletes-" + UUID.randomUUID()));
+    OutputFile out = Files.localOutput(new File(temp.toFile(), "eq-deletes-" + UUID.randomUUID()));
     return FileHelpers.writeDeleteFile(table, out, null, deletes, deleteSchema);
   }
 
   private Pair<DeleteFile, CharSequenceSet> writePosDeletes(
       Table table, List<Pair<CharSequence, Long>> deletes) throws IOException {
-    OutputFile out = Files.localOutput(temp.newFile("pos-deletes-" + UUID.randomUUID()));
+    OutputFile out = Files.localOutput(new File(temp.toFile(), "pos-deletes-" + UUID.randomUUID()));
     return FileHelpers.writeDeleteFile(table, out, null, deletes);
   }
 
