@@ -456,9 +456,7 @@ public class SparkTableUtil {
    * @param sourceTableIdent an identifier of the source Spark table
    * @param targetTable an Iceberg table where to import the data
    * @param stagingDir a staging directory to store temporary manifest files
-   * @param service executor service to use for file reading. If null, file reading will be
-   *     performed on the current thread. * If non-null, the provided ExecutorService will be
-   *     shutdown within this method after file reading is complete.
+   * @param service executor service to use for file reading
    */
   public static void importSparkTable(
       SparkSession spark,
@@ -516,9 +514,7 @@ public class SparkTableUtil {
    * @param partitionFilter only import partitions whose values match those in the map, can be
    *     partially defined
    * @param checkDuplicateFiles if true, throw exception if import results in a duplicate data file
-   * @param service executor service to use for file reading. If null, file reading will be
-   *     performed on the current thread. If non-null, the provided ExecutorService will be shutdown
-   *     within this method after file reading is complete.
+   * @param service executor service to use for file reading
    */
   public static void importSparkTable(
       SparkSession spark,
@@ -738,9 +734,7 @@ public class SparkTableUtil {
    * @param spec a partition spec
    * @param stagingDir a staging directory to store temporary manifest files
    * @param checkDuplicateFiles if true, throw exception if import results in a duplicate data file
-   * @param service executor service to use for file reading. If null, file reading will be
-   *     performed on the current thread. If non-null, the provided ExecutorService will be shutdown
-   *     within this method after file reading is complete.
+   * @param service executor service to use for file reading
    */
   public static void importSparkPartitions(
       SparkSession spark,
@@ -756,7 +750,7 @@ public class SparkTableUtil {
         Math.min(
             partitions.size(), spark.sessionState().conf().parallelPartitionDiscoveryParallelism());
     int numShufflePartitions = spark.sessionState().conf().numShufflePartitions();
-    MetricsConfig metricsConfig = MetricsConfig.forTable(targetTable);
+    MetricsConfig metricsConfig = MetricsConfig.fromProperties(targetTable.properties());
     String nameMappingString = targetTable.properties().get(TableProperties.DEFAULT_NAME_MAPPING);
     NameMapping nameMapping =
         nameMappingString != null ? NameMappingParser.fromJson(nameMappingString) : null;
@@ -987,6 +981,96 @@ public class SparkTableUtil {
     }
   }
 
+  /**
+   * Returns the first partition spec in an IcebergTable that shares the same names and ordering as
+   * the partition columns provided. Throws an error if not found
+   */
+  public static PartitionSpec findCompatibleSpec(List<String> partitionNames, Table icebergTable) {
+    List<String> partitionNamesLower =
+        partitionNames.stream()
+            .map(name -> name.toLowerCase(Locale.ROOT))
+            .collect(Collectors.toList());
+    for (PartitionSpec icebergSpec : icebergTable.specs().values()) {
+      boolean allIdentity =
+          icebergSpec.fields().stream().allMatch(field -> field.transform().isIdentity());
+      if (allIdentity) {
+        List<String> icebergPartNames =
+            icebergSpec.fields().stream()
+                .map(PartitionField::name)
+                .map(name -> name.toLowerCase(Locale.ROOT))
+                .collect(Collectors.toList());
+        if (icebergPartNames.equals(partitionNamesLower)) {
+          return icebergSpec;
+        }
+      }
+    }
+
+    throw new IllegalArgumentException(
+        String.format(
+            "Cannot find a partition spec in Iceberg table %s that matches the partition"
+                + " columns (%s) in input table",
+            icebergTable, partitionNames));
+  }
+
+  /**
+   * Returns the first partition spec in an IcebergTable that shares the same names and ordering as
+   * the partition columns provided. Throws an error if not found
+   */
+  private static PartitionSpec findCompatibleSpec(
+      Table icebergTable, SparkSession spark, String sparkTable) throws AnalysisException {
+    List<String> parts = Lists.newArrayList(Splitter.on('.').limit(2).split(sparkTable));
+    String db = parts.size() == 1 ? "default" : parts.get(0);
+    String table = parts.get(parts.size() == 1 ? 0 : 1);
+
+    List<String> sparkPartNames =
+        spark.catalog().listColumns(db, table).collectAsList().stream()
+            .filter(org.apache.spark.sql.catalog.Column::isPartition)
+            .map(org.apache.spark.sql.catalog.Column::name)
+            .collect(Collectors.toList());
+    return findCompatibleSpec(sparkPartNames, icebergTable);
+  }
+
+  public static void validatePartitionFilter(
+      PartitionSpec spec, Map<String, String> partitionFilter, String tableName) {
+    List<PartitionField> partitionFields = spec.fields();
+    Set<String> partitionNames =
+        spec.fields().stream().map(PartitionField::name).collect(Collectors.toSet());
+
+    boolean tablePartitioned = !partitionFields.isEmpty();
+    boolean partitionFilterPassed = !partitionFilter.isEmpty();
+
+    if (tablePartitioned && partitionFilterPassed) {
+      // Check to see there are sufficient partition columns to satisfy the filter
+      Preconditions.checkArgument(
+          partitionFields.size() >= partitionFilter.size(),
+          "Cannot add data files to target table %s because that table is partitioned, "
+              + "but the number of columns in the provided partition filter (%s) "
+              + "is greater than the number of partitioned columns in table (%s)",
+          tableName,
+          partitionFilter.size(),
+          partitionFields.size());
+
+      // Check for any filters of non-existent columns
+      List<String> unMatchedFilters =
+          partitionFilter.keySet().stream()
+              .filter(filterName -> !partitionNames.contains(filterName))
+              .collect(Collectors.toList());
+      Preconditions.checkArgument(
+          unMatchedFilters.isEmpty(),
+          "Cannot add files to target table %s. %s is partitioned but the specified partition filter "
+              + "refers to columns that are not partitioned: %s . Valid partition columns: [%s]",
+          tableName,
+          tableName,
+          unMatchedFilters,
+          String.join(",", partitionNames));
+    } else {
+      Preconditions.checkArgument(
+          !partitionFilterPassed,
+          "Cannot use partition filter with an unpartitioned table %s",
+          tableName);
+    }
+  }
+
   @Nullable
   public static ExecutorService migrationService(int parallelism) {
     return parallelism == 1 ? null : new LazyExecutorService(parallelism);
@@ -1091,94 +1175,4 @@ public class SparkTableUtil {
       return service;
     }
   }
-
-  /**
-   * Returns the first partition spec in an IcebergTable that shares the same names and ordering as
-   * the partition columns provided. Throws an error if not found
-   */
-  public static PartitionSpec findCompatibleSpec(List<String> partitionNames, Table icebergTable) {
-    List<String> partitionNamesLower =
-        partitionNames.stream()
-            .map(name -> name.toLowerCase(Locale.ROOT))
-            .collect(Collectors.toList());
-    for (PartitionSpec icebergSpec : icebergTable.specs().values()) {
-      boolean allIdentity =
-          icebergSpec.fields().stream().allMatch(field -> field.transform().isIdentity());
-      if (allIdentity) {
-        List<String> icebergPartNames =
-            icebergSpec.fields().stream()
-                .map(PartitionField::name)
-                .map(name -> name.toLowerCase(Locale.ROOT))
-                .collect(Collectors.toList());
-        if (icebergPartNames.equals(partitionNamesLower)) {
-          return icebergSpec;
-        }
-      }
-    }
-
-    throw new IllegalArgumentException(
-        String.format(
-            "Cannot find a partition spec in Iceberg table %s that matches the partition"
-                + " columns (%s) in input table",
-            icebergTable, partitionNames));
-  }
-
-  /**
-   * Returns the first partition spec in an IcebergTable that shares the same names and ordering as
-   * the partition columns in a given Spark Table. Throws an error if not found
-   */
-  private static PartitionSpec findCompatibleSpec(
-      Table icebergTable, SparkSession spark, String sparkTable) throws AnalysisException {
-    List<String> parts = Lists.newArrayList(Splitter.on('.').limit(2).split(sparkTable));
-    String db = parts.size() == 1 ? "default" : parts.get(0);
-    String table = parts.get(parts.size() == 1 ? 0 : 1);
-
-    List<String> sparkPartNames =
-        spark.catalog().listColumns(db, table).collectAsList().stream()
-            .filter(org.apache.spark.sql.catalog.Column::isPartition)
-            .map(org.apache.spark.sql.catalog.Column::name)
-            .collect(Collectors.toList());
-    return findCompatibleSpec(sparkPartNames, icebergTable);
-  }
-
-  public static void validatePartitionFilter(
-      PartitionSpec spec, Map<String, String> partitionFilter, String tableName) {
-    List<PartitionField> partitionFields = spec.fields();
-    Set<String> partitionNames =
-        spec.fields().stream().map(PartitionField::name).collect(Collectors.toSet());
-
-    boolean tablePartitioned = !partitionFields.isEmpty();
-    boolean partitionFilterPassed = !partitionFilter.isEmpty();
-
-    if (tablePartitioned && partitionFilterPassed) {
-      // Check to see there are sufficient partition columns to satisfy the filter
-      Preconditions.checkArgument(
-          partitionFields.size() >= partitionFilter.size(),
-          "Cannot add data files to target table %s because that table is partitioned, "
-              + "but the number of columns in the provided partition filter (%s) "
-              + "is greater than the number of partitioned columns in table (%s)",
-          tableName,
-          partitionFilter.size(),
-          partitionFields.size());
-
-      // Check for any filters of non-existent columns
-      List<String> unMatchedFilters =
-          partitionFilter.keySet().stream()
-              .filter(filterName -> !partitionNames.contains(filterName))
-              .collect(Collectors.toList());
-      Preconditions.checkArgument(
-          unMatchedFilters.isEmpty(),
-          "Cannot add files to target table %s. %s is partitioned but the specified partition filter "
-              + "refers to columns that are not partitioned: %s . Valid partition columns: [%s]",
-          tableName,
-          tableName,
-          unMatchedFilters,
-          String.join(",", partitionNames));
-    } else {
-      Preconditions.checkArgument(
-          !partitionFilterPassed,
-          "Cannot use partition filter with an unpartitioned table %s",
-          tableName);
-    }
-  }
 }
