@@ -20,6 +20,9 @@ package org.apache.iceberg.spark.source;
 
 import java.util.Arrays;
 import java.util.Map;
+import java.util.Objects;
+import java.util.Optional;
+import java.util.stream.Stream;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.spark.PathIdentifier;
@@ -29,11 +32,13 @@ import org.apache.iceberg.spark.SparkCatalog;
 import org.apache.iceberg.spark.SparkReadOptions;
 import org.apache.iceberg.spark.SparkSessionCatalog;
 import org.apache.iceberg.spark.SparkTableCache;
+import org.apache.iceberg.util.PropertyUtil;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
 import org.apache.spark.sql.connector.catalog.CatalogManager;
 import org.apache.spark.sql.connector.catalog.CatalogPlugin;
 import org.apache.spark.sql.connector.catalog.Identifier;
+import org.apache.spark.sql.connector.catalog.SessionConfigSupport;
 import org.apache.spark.sql.connector.catalog.SupportsCatalogOptions;
 import org.apache.spark.sql.connector.catalog.Table;
 import org.apache.spark.sql.connector.catalog.TableCatalog;
@@ -45,9 +50,9 @@ import org.apache.spark.sql.util.CaseInsensitiveStringMap;
 /**
  * The IcebergSource loads/writes tables with format "iceberg". It can load paths and tables.
  *
- * <p>How paths/tables are loaded when using spark.read().format("iceberg").path(table)
+ * <p>How paths/tables are loaded when using spark.read().format("iceberg").load(table)
  *
- * <p>table = "file:/path/to/table" -&gt; loads a HadoopTable at given path table = "tablename"
+ * <p>table = "file:///path/to/table" -&gt; loads a HadoopTable at given path table = "tablename"
  * -&gt; loads currentCatalog.currentNamespace.tablename table = "catalog.tablename" -&gt; load
  * "tablename" from the specified catalog. table = "namespace.tablename" -&gt; load
  * "namespace.tablename" from current catalog table = "catalog.namespace.tablename" -&gt;
@@ -57,14 +62,17 @@ import org.apache.spark.sql.util.CaseInsensitiveStringMap;
  * <p>The above list is in order of priority. For example: a matching catalog will take priority
  * over any namespace resolution.
  */
-public class IcebergSource implements DataSourceRegister, SupportsCatalogOptions {
+public class IcebergSource
+    implements DataSourceRegister, SupportsCatalogOptions, SessionConfigSupport {
   private static final String DEFAULT_CATALOG_NAME = "default_iceberg";
   private static final String DEFAULT_CACHE_CATALOG_NAME = "default_cache_iceberg";
+  private static final String DEFAULT_CATALOG = "spark.sql.catalog." + DEFAULT_CATALOG_NAME;
   private static final String DEFAULT_CACHE_CATALOG =
       "spark.sql.catalog." + DEFAULT_CACHE_CATALOG_NAME;
-  private static final String DEFAULT_CATALOG = "spark.sql.catalog." + DEFAULT_CATALOG_NAME;
   private static final String AT_TIMESTAMP = "at_timestamp_";
   private static final String SNAPSHOT_ID = "snapshot_id_";
+  private static final String BRANCH_PREFIX = "branch_";
+  private static final String TAG_PREFIX = "tag_";
   private static final String[] EMPTY_NAMESPACE = new String[0];
 
   private static final SparkTableCache TABLE_CACHE = SparkTableCache.get();
@@ -74,6 +82,11 @@ public class IcebergSource implements DataSourceRegister, SupportsCatalogOptions
     return "iceberg";
   }
 
+  @Override
+  public String keyPrefix() {
+    return shortName();
+  }
+
   @Override
   public StructType inferSchema(CaseInsensitiveStringMap options) {
     return null;
@@ -114,18 +127,23 @@ public class IcebergSource implements DataSourceRegister, SupportsCatalogOptions
   }
 
   private Spark3Util.CatalogAndIdentifier catalogAndIdentifier(CaseInsensitiveStringMap options) {
-    Preconditions.checkArgument(options.containsKey("path"), "Cannot open table: path is not set");
+    Preconditions.checkArgument(
+        options.containsKey(SparkReadOptions.PATH), "Cannot open table: path is not set");
     SparkSession spark = SparkSession.active();
     setupDefaultSparkCatalogs(spark);
-    String path = options.get("path");
+    String path = options.get(SparkReadOptions.PATH);
 
     Long snapshotId = propertyAsLong(options, SparkReadOptions.SNAPSHOT_ID);
     Long asOfTimestamp = propertyAsLong(options, SparkReadOptions.AS_OF_TIMESTAMP);
+    String branch = options.get(SparkReadOptions.BRANCH);
+    String tag = options.get(SparkReadOptions.TAG);
     Preconditions.checkArgument(
-        asOfTimestamp == null || snapshotId == null,
-        "Cannot specify both snapshot-id (%s) and as-of-timestamp (%s)",
+        Stream.of(snapshotId, asOfTimestamp, branch, tag).filter(Objects::nonNull).count() <= 1,
+        "Can specify only one of snapshot-id (%s), as-of-timestamp (%s), branch (%s), tag (%s)",
         snapshotId,
-        asOfTimestamp);
+        asOfTimestamp,
+        branch,
+        tag);
 
     String selector = null;
 
@@ -137,6 +155,14 @@ public class IcebergSource implements DataSourceRegister, SupportsCatalogOptions
       selector = AT_TIMESTAMP + asOfTimestamp;
     }
 
+    if (branch != null) {
+      selector = BRANCH_PREFIX + branch;
+    }
+
+    if (tag != null) {
+      selector = TAG_PREFIX + tag;
+    }
+
     CatalogManager catalogManager = spark.sessionState().catalogManager();
 
     if (TABLE_CACHE.contains(path)) {
@@ -189,6 +215,18 @@ public class IcebergSource implements DataSourceRegister, SupportsCatalogOptions
     return catalogAndIdentifier(options).catalog().name();
   }
 
+  @Override
+  public Optional<String> extractTimeTravelVersion(CaseInsensitiveStringMap options) {
+    return Optional.ofNullable(
+        PropertyUtil.propertyAsString(options, SparkReadOptions.VERSION_AS_OF, null));
+  }
+
+  @Override
+  public Optional<String> extractTimeTravelTimestamp(CaseInsensitiveStringMap options) {
+    return Optional.ofNullable(
+        PropertyUtil.propertyAsString(options, SparkReadOptions.TIMESTAMP_AS_OF, null));
+  }
+
   private static Long propertyAsLong(CaseInsensitiveStringMap options, String property) {
     String value = options.get(property);
     if (value != null) {
