@@ -98,7 +98,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
   private final Schema writeSchema;
   private final StructType dsSchema;
   private final Map<String, String> extraSnapshotMetadata;
-  private final boolean useFanoutWriter;
+  private final boolean partitionedFanoutEnabled;
   private final SparkWriteRequirements writeRequirements;
   private final Map<String, String> writeProperties;
 
@@ -126,7 +126,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     this.writeSchema = writeSchema;
     this.dsSchema = dsSchema;
     this.extraSnapshotMetadata = writeConf.extraSnapshotMetadata();
-    this.useFanoutWriter = writeConf.useFanoutWriter(writeRequirements);
+    this.partitionedFanoutEnabled = writeConf.fanoutWriterEnabled();
     this.writeRequirements = writeRequirements;
     this.outputSpecId = writeConf.outputSpecId();
     this.writeProperties = writeConf.writeProperties();
@@ -134,9 +134,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
 
   @Override
   public Distribution requiredDistribution() {
-    Distribution distribution = writeRequirements.distribution();
-    LOG.info("Requesting {} as write distribution for table {}", distribution, table.name());
-    return distribution;
+    return writeRequirements.distribution();
   }
 
   @Override
@@ -146,16 +144,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
 
   @Override
   public SortOrder[] requiredOrdering() {
-    SortOrder[] ordering = writeRequirements.ordering();
-    LOG.info("Requesting {} as write ordering for table {}", ordering, table.name());
-    return ordering;
-  }
-
-  @Override
-  public long advisoryPartitionSizeInBytes() {
-    long size = writeRequirements.advisoryPartitionSize();
-    LOG.info("Requesting {} bytes advisory partition size for table {}", size, table.name());
-    return size;
+    return writeRequirements.ordering();
   }
 
   BatchWrite asBatchAppend() {
@@ -199,7 +188,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         targetFileSize,
         writeSchema,
         dsSchema,
-        useFanoutWriter,
+        partitionedFanoutEnabled,
         writeProperties);
   }
 
@@ -506,11 +495,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       return createWriterFactory();
     }
 
-    @Override
-    public boolean useCommitCoordinator() {
-      return false;
-    }
-
     @Override
     public final void commit(long epochId, WriterCommitMessage[] messages) {
       LOG.info("Committing epoch {} for query {} in {} mode", epochId, queryId, mode());
@@ -638,7 +622,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     private final long targetFileSize;
     private final Schema writeSchema;
     private final StructType dsSchema;
-    private final boolean useFanoutWriter;
+    private final boolean partitionedFanoutEnabled;
     private final String queryId;
     private final Map<String, String> writeProperties;
 
@@ -650,7 +634,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         long targetFileSize,
         Schema writeSchema,
         StructType dsSchema,
-        boolean useFanoutWriter,
+        boolean partitionedFanoutEnabled,
         Map<String, String> writeProperties) {
       this.tableBroadcast = tableBroadcast;
       this.format = format;
@@ -658,7 +642,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       this.targetFileSize = targetFileSize;
       this.writeSchema = writeSchema;
       this.dsSchema = dsSchema;
-      this.useFanoutWriter = useFanoutWriter;
+      this.partitionedFanoutEnabled = partitionedFanoutEnabled;
       this.queryId = queryId;
       this.writeProperties = writeProperties;
     }
@@ -699,7 +683,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
             writeSchema,
             dsSchema,
             targetFileSize,
-            useFanoutWriter);
+            partitionedFanoutEnabled);
       }
     }
   }
