@@ -32,7 +32,8 @@ public class NoSuchProcedureException extends AnalysisException {
         Option.empty(),
         Option.empty(),
         Option.empty(),
-        Map$.MODULE$.<String, String>empty(),
+        Option.empty(),
+        Map$.MODULE$.empty(),
         new QueryContext[0]);
   }
 }
