@@ -51,23 +51,21 @@ import java.time.Duration;
 import java.util.List;
 import java.util.Map;
 import org.apache.iceberg.DistributionMode;
-import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.UpdateProperties;
 import org.apache.iceberg.deletes.DeleteGranularity;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.apache.spark.sql.internal.SQLConf;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
 
-public class TestSparkWriteConf extends TestBaseWithCatalog {
+public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
 
-  @BeforeEach
+  @Before
   public void before() {
-    super.before();
     sql(
         "CREATE TABLE %s (id BIGINT, data STRING, date DATE, ts TIMESTAMP) "
             + "USING iceberg "
@@ -75,47 +73,12 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
         tableName);
   }
 
-  @AfterEach
+  @After
   public void after() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @TestTemplate
-  public void testOptionCaseInsensitive() {
-    Table table = validationCatalog.loadTable(tableIdent);
-    Map<String, String> options = ImmutableMap.of("option", "value");
-    SparkConfParser parser = new SparkConfParser(spark, table, options);
-    String parsedValue = parser.stringConf().option("oPtIoN").parseOptional();
-    assertThat(parsedValue).isEqualTo("value");
-  }
-
-  @TestTemplate
-  public void testCamelCaseSparkSessionConf() {
-    Table table = validationCatalog.loadTable(tableIdent);
-    String confName = "spark.sql.iceberg.some-int-conf";
-    String sparkConfName = "spark.sql.iceberg.someIntConf";
-
-    withSQLConf(
-        ImmutableMap.of(sparkConfName, "1"),
-        () -> {
-          SparkConfParser parser = new SparkConfParser(spark, table, ImmutableMap.of());
-          Integer value = parser.intConf().sessionConf(confName).parseOptional();
-          assertThat(value).isEqualTo(1);
-        });
-  }
-
-  @TestTemplate
-  public void testCamelCaseSparkOption() {
-    Table table = validationCatalog.loadTable(tableIdent);
-    String option = "some-int-option";
-    String sparkOption = "someIntOption";
-    Map<String, String> options = ImmutableMap.of(sparkOption, "1");
-    SparkConfParser parser = new SparkConfParser(spark, table, options);
-    Integer value = parser.intConf().option(option).parseOptional();
-    assertThat(value).isEqualTo(1);
-  }
-
-  @TestTemplate
+  @Test
   public void testDurationConf() {
     Table table = validationCatalog.loadTable(tableIdent);
     String confName = "spark.sql.iceberg.some-duration-conf";
@@ -137,31 +100,31 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
         });
   }
 
-  @TestTemplate
+  @Test
   public void testDeleteGranularityDefault() {
     Table table = validationCatalog.loadTable(tableIdent);
     SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
 
-    DeleteGranularity value = writeConf.deleteGranularity();
-    assertThat(value).isEqualTo(DeleteGranularity.FILE);
-  }
-
-  @TestTemplate
-  public void testDeleteGranularityTableProperty() {
-    Table table = validationCatalog.loadTable(tableIdent);
-
-    table
-        .updateProperties()
-        .set(TableProperties.DELETE_GRANULARITY, DeleteGranularity.PARTITION.toString())
-        .commit();
-
-    SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
-
     DeleteGranularity value = writeConf.deleteGranularity();
     assertThat(value).isEqualTo(DeleteGranularity.PARTITION);
   }
 
-  @TestTemplate
+  @Test
+  public void testDeleteGranularityTableProperty() {
+    Table table = validationCatalog.loadTable(tableIdent);
+
+    table
+        .updateProperties()
+        .set(TableProperties.DELETE_GRANULARITY, DeleteGranularity.FILE.toString())
+        .commit();
+
+    SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
+
+    DeleteGranularity value = writeConf.deleteGranularity();
+    assertThat(value).isEqualTo(DeleteGranularity.FILE);
+  }
+
+  @Test
   public void testDeleteGranularityWriteOption() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -179,7 +142,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
     assertThat(value).isEqualTo(DeleteGranularity.FILE);
   }
 
-  @TestTemplate
+  @Test
   public void testDeleteGranularityInvalidValue() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -192,25 +155,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
         .hasMessageContaining("Unknown delete granularity");
   }
 
-  @TestTemplate
-  public void testAdvisoryPartitionSize() {
-    Table table = validationCatalog.loadTable(tableIdent);
-
-    SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
-
-    long value1 = writeConf.writeRequirements().advisoryPartitionSize();
-    assertThat(value1).isGreaterThan(64L * 1024 * 1024).isLessThan(2L * 1024 * 1024 * 1024);
-
-    spark.conf().set(SQLConf.ADVISORY_PARTITION_SIZE_IN_BYTES().key(), "2GB");
-    long value2 = writeConf.writeRequirements().advisoryPartitionSize();
-    assertThat(value2).isEqualTo(2L * 1024 * 1024 * 1024);
-
-    spark.conf().set(SQLConf.ADVISORY_PARTITION_SIZE_IN_BYTES().key(), "10MB");
-    long value3 = writeConf.writeRequirements().advisoryPartitionSize();
-    assertThat(value3).isGreaterThan(10L * 1024 * 1024);
-  }
-
-  @TestTemplate
+  @Test
   public void testSparkWriteConfDistributionDefault() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -219,7 +164,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
     checkMode(DistributionMode.HASH, writeConf);
   }
 
-  @TestTemplate
+  @Test
   public void testSparkWriteConfDistributionModeWithWriteOption() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -230,7 +175,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
     checkMode(DistributionMode.NONE, writeConf);
   }
 
-  @TestTemplate
+  @Test
   public void testSparkWriteConfDistributionModeWithSessionConfig() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.NONE.modeName()),
@@ -241,7 +186,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
         });
   }
 
-  @TestTemplate
+  @Test
   public void testSparkWriteConfDistributionModeWithTableProperties() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -257,7 +202,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
     checkMode(DistributionMode.NONE, writeConf);
   }
 
-  @TestTemplate
+  @Test
   public void testSparkWriteConfDistributionModeWithTblPropAndSessionConfig() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.NONE.modeName()),
@@ -278,7 +223,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
         });
   }
 
-  @TestTemplate
+  @Test
   public void testSparkWriteConfDistributionModeWithWriteOptionAndSessionConfig() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.RANGE.modeName()),
@@ -295,7 +240,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
         });
   }
 
-  @TestTemplate
+  @Test
   public void testSparkWriteConfDistributionModeWithEverything() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.RANGE.modeName()),
@@ -320,7 +265,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
         });
   }
 
-  @TestTemplate
+  @Test
   public void testSparkConfOverride() {
     List<List<Map<String, String>>> propertiesSuites =
         Lists.newArrayList(
@@ -393,7 +338,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
     }
   }
 
-  @TestTemplate
+  @Test
   public void testDataPropsDefaultsAsDeleteProps() {
     List<List<Map<String, String>>> propertiesSuites =
         Lists.newArrayList(
@@ -462,7 +407,7 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
     }
   }
 
-  @TestTemplate
+  @Test
   public void testDeleteFileWriteConf() {
     List<List<Map<String, String>>> propertiesSuites =
         Lists.newArrayList(
@@ -541,14 +486,6 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
     }
   }
 
-  @TestTemplate
-  public void testDVWriteConf() {
-    Table table = validationCatalog.loadTable(tableIdent);
-    table.updateProperties().set(TableProperties.FORMAT_VERSION, "3").commit();
-    SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
-    assertThat(writeConf.deleteFileFormat()).isEqualTo(FileFormat.PUFFIN);
-  }
-
   private void testWriteProperties(List<Map<String, String>> propertiesSuite) {
     withSQLConf(
         propertiesSuite.get(0),
@@ -565,9 +502,9 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
           SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
           Map<String, String> writeProperties = writeConf.writeProperties();
           Map<String, String> expectedProperties = propertiesSuite.get(2);
-          assertThat(writeConf.writeProperties()).hasSameSizeAs(expectedProperties);
+          Assert.assertEquals(expectedProperties.size(), writeConf.writeProperties().size());
           for (Map.Entry<String, String> entry : writeProperties.entrySet()) {
-            assertThat(expectedProperties).containsEntry(entry.getKey(), entry.getValue());
+            Assert.assertEquals(entry.getValue(), expectedProperties.get(entry.getKey()));
           }
 
           table.refresh();
@@ -581,12 +518,12 @@ public class TestSparkWriteConf extends TestBaseWithCatalog {
   }
 
   private void checkMode(DistributionMode expectedMode, SparkWriteConf writeConf) {
-    assertThat(writeConf.distributionMode()).isEqualTo(expectedMode);
-    assertThat(writeConf.copyOnWriteDistributionMode(DELETE)).isEqualTo(expectedMode);
-    assertThat(writeConf.positionDeltaDistributionMode(DELETE)).isEqualTo(expectedMode);
-    assertThat(writeConf.copyOnWriteDistributionMode(UPDATE)).isEqualTo(expectedMode);
-    assertThat(writeConf.positionDeltaDistributionMode(UPDATE)).isEqualTo(expectedMode);
-    assertThat(writeConf.copyOnWriteDistributionMode(MERGE)).isEqualTo(expectedMode);
-    assertThat(writeConf.positionDeltaDistributionMode(MERGE)).isEqualTo(expectedMode);
+    Assert.assertEquals(expectedMode, writeConf.distributionMode());
+    Assert.assertEquals(expectedMode, writeConf.copyOnWriteDistributionMode(DELETE));
+    Assert.assertEquals(expectedMode, writeConf.positionDeltaDistributionMode(DELETE));
+    Assert.assertEquals(expectedMode, writeConf.copyOnWriteDistributionMode(UPDATE));
+    Assert.assertEquals(expectedMode, writeConf.positionDeltaDistributionMode(UPDATE));
+    Assert.assertEquals(expectedMode, writeConf.copyOnWriteDistributionMode(MERGE));
+    Assert.assertEquals(expectedMode, writeConf.positionDeltaDistributionMode(MERGE));
   }
 }
