@@ -64,6 +64,7 @@ import org.apache.iceberg.spark.TestBase;
 import org.apache.iceberg.spark.data.TestHelpers;
 import org.apache.iceberg.types.Types;
 import org.apache.spark.sql.Dataset;
+import org.junit.Assert;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.TestTemplate;
 import org.junit.jupiter.api.extension.ExtendWith;
@@ -254,12 +255,8 @@ public class TestExpireSnapshotsAction extends TestBase {
     // Verifies that the delete methods ran in the threads created by the provided ExecutorService
     // ThreadFactory
     assertThat(deleteThreads)
-        .isEqualTo(
-            Sets.newHashSet(
-                "remove-snapshot-0",
-                "remove-snapshot-1",
-                "remove-snapshot-2",
-                "remove-snapshot-3"));
+        .containsExactlyInAnyOrder(
+            "remove-snapshot-0", "remove-snapshot-1", "remove-snapshot-2", "remove-snapshot-3");
 
     assertThat(deletedFiles).as("FILE_A should be deleted").contains(FILE_A.location());
     assertThat(deletedFiles).as("FILE_B should be deleted").contains(FILE_B.location());
@@ -656,7 +653,7 @@ public class TestExpireSnapshotsAction extends TestBase {
         .hasSameSizeAs(deletedFiles);
     // Take the diff
     expectedDeletes.removeAll(deletedFiles);
-    assertThat(expectedDeletes).as("Exactly same files should be deleted").isEmpty();
+    Assert.assertTrue("Exactly same files should be deleted", expectedDeletes.isEmpty());
   }
 
   /**
@@ -672,7 +669,7 @@ public class TestExpireSnapshotsAction extends TestBase {
     // `B` commit
     Set<String> deletedAFiles = Sets.newHashSet();
     table.newOverwrite().addFile(FILE_B).deleteFile(FILE_A).deleteWith(deletedAFiles::add).commit();
-    assertThat(deletedAFiles).as("No files should be physically deleted").isEmpty();
+    Assert.assertTrue("No files should be physically deleted", deletedAFiles.isEmpty());
 
     // pick the snapshot 'B`
     Snapshot snapshotB = table.currentSnapshot();
@@ -707,7 +704,7 @@ public class TestExpireSnapshotsAction extends TestBase {
               i.addedDataFiles(table.io())
                   .forEach(
                       item -> {
-                        assertThat(deletedFiles).doesNotContain(item.location());
+                        Assert.assertFalse(deletedFiles.contains(item.location()));
                       });
             });
 
@@ -756,7 +753,7 @@ public class TestExpireSnapshotsAction extends TestBase {
               i.addedDataFiles(table.io())
                   .forEach(
                       item -> {
-                        assertThat(deletedFiles).doesNotContain(item.location());
+                        Assert.assertFalse(deletedFiles.contains(item.location()));
                       });
             });
     checkExpirationResults(0L, 0L, 0L, 1L, 1L, firstResult);
@@ -776,7 +773,7 @@ public class TestExpireSnapshotsAction extends TestBase {
               i.addedDataFiles(table.io())
                   .forEach(
                       item -> {
-                        assertThat(deletedFiles).doesNotContain(item.location());
+                        Assert.assertFalse(deletedFiles.contains(item.location()));
                       });
             });
     checkExpirationResults(0L, 0L, 0L, 0L, 2L, secondResult);
@@ -813,7 +810,7 @@ public class TestExpireSnapshotsAction extends TestBase {
         .isNull();
     assertThat(deletedFiles)
         .as("Should remove only the expired manifest list location.")
-        .isEqualTo(Sets.newHashSet(firstSnapshot.manifestListLocation()));
+        .containsExactly(firstSnapshot.manifestListLocation());
 
     checkExpirationResults(0, 0, 0, 0, 1, result);
   }
@@ -862,20 +859,18 @@ public class TestExpireSnapshotsAction extends TestBase {
         .isNull();
     assertThat(deletedFiles)
         .as("Should remove expired manifest lists and deleted data file.")
-        .isEqualTo(
-            Sets.newHashSet(
-                firstSnapshot.manifestListLocation(), // snapshot expired
-                firstSnapshot
-                    .allManifests(table.io())
-                    .get(0)
-                    .path(), // manifest was rewritten for delete
-                secondSnapshot.manifestListLocation(), // snapshot expired
-                secondSnapshot
-                    .allManifests(table.io())
-                    .get(0)
-                    .path(), // manifest contained only deletes, was dropped
-                FILE_A.location()) // deleted
-            );
+        .containsExactlyInAnyOrder(
+            firstSnapshot.manifestListLocation(), // snapshot expired
+            firstSnapshot
+                .allManifests(table.io())
+                .get(0)
+                .path(), // manifest was rewritten for delete
+            secondSnapshot.manifestListLocation(), // snapshot expired
+            secondSnapshot
+                .allManifests(table.io())
+                .get(0)
+                .path(), // manifest contained only deletes, was dropped
+            FILE_A.location());
 
     checkExpirationResults(1, 0, 0, 2, 2, result);
   }
@@ -901,6 +896,7 @@ public class TestExpireSnapshotsAction extends TestBase {
     assertThat(secondSnapshot.allManifests(table.io()))
         .as("Should replace manifest with a rewritten manifest")
         .hasSize(1);
+
     table
         .newFastAppend() // do not merge to keep the last snapshot's manifest valid
         .appendFile(FILE_C)
@@ -933,16 +929,14 @@ public class TestExpireSnapshotsAction extends TestBase {
 
     assertThat(deletedFiles)
         .as("Should remove expired manifest lists and deleted data file.")
-        .isEqualTo(
-            Sets.newHashSet(
-                firstSnapshot.manifestListLocation(), // snapshot expired
-                firstSnapshot
-                    .allManifests(table.io())
-                    .get(0)
-                    .path(), // manifest was rewritten for delete
-                secondSnapshot.manifestListLocation(), // snapshot expired
-                FILE_A.location()) // deleted
-            );
+        .containsExactlyInAnyOrder(
+            firstSnapshot.manifestListLocation(), // snapshot expired
+            firstSnapshot
+                .allManifests(table.io())
+                .get(0)
+                .path(), // manifest was rewritten for delete
+            secondSnapshot.manifestListLocation(), // snapshot expired
+            FILE_A.location());
     checkExpirationResults(1, 0, 0, 1, 2, result);
   }
 
@@ -994,12 +988,9 @@ public class TestExpireSnapshotsAction extends TestBase {
 
     assertThat(deletedFiles)
         .as("Should remove expired manifest lists and reverted appended data file")
-        .isEqualTo(
-            Sets.newHashSet(
-                secondSnapshot.manifestListLocation(), // snapshot expired
-                Iterables.getOnlyElement(secondSnapshotManifests)
-                    .path()) // manifest is no longer referenced
-            );
+        .containsExactlyInAnyOrder(
+            secondSnapshot.manifestListLocation(), // snapshot expired
+            Iterables.getOnlyElement(secondSnapshotManifests).path());
 
     checkExpirationResults(0, 0, 0, 1, 1, result);
   }
@@ -1010,6 +1001,7 @@ public class TestExpireSnapshotsAction extends TestBase {
 
     Snapshot firstSnapshot = table.currentSnapshot();
     assertThat(firstSnapshot.allManifests(table.io())).as("Should create one manifest").hasSize(1);
+
     rightAfterSnapshot();
 
     table.newAppend().appendFile(FILE_B).commit();
@@ -1048,13 +1040,11 @@ public class TestExpireSnapshotsAction extends TestBase {
 
     assertThat(deletedFiles)
         .as("Should remove expired manifest lists and reverted appended data file")
-        .isEqualTo(
-            Sets.newHashSet(
-                secondSnapshot.manifestListLocation(), // snapshot expired
-                Iterables.getOnlyElement(secondSnapshotManifests)
-                    .path(), // manifest is no longer referenced
-                FILE_B.location()) // added, but rolled back
-            );
+        .containsExactlyInAnyOrder(
+            secondSnapshot.manifestListLocation(), // snapshot expired
+            Iterables.getOnlyElement(secondSnapshotManifests)
+                .path(), // manifest is no longer referenced
+            FILE_B.location());
 
     checkExpirationResults(1, 0, 0, 1, 1, result);
   }
@@ -1170,7 +1160,6 @@ public class TestExpireSnapshotsAction extends TestBase {
     assertThat(table.snapshot(firstSnapshot.snapshotId()))
         .as("Should remove the oldest snapshot")
         .isNull();
-    assertThat(pending).as("Pending deletes should contain one row").hasSize(1);
 
     assertThat(pending.get(0).getPath())
         .as("Pending delete should be the expired manifest list location")
@@ -1180,7 +1169,7 @@ public class TestExpireSnapshotsAction extends TestBase {
         .as("Pending delete should be a manifest list")
         .isEqualTo("Manifest List");
 
-    assertThat(deletedFiles).as("Should not delete any files").hasSize(0);
+    assertThat(deletedFiles).as("Should not delete any files").isEmpty();
 
     assertThat(action.expireFiles().count())
         .as("Multiple calls to expire should return the same count of deleted files")
@@ -1351,9 +1340,8 @@ public class TestExpireSnapshotsAction extends TestBase {
     // C, D should be retained (live)
     // B should be retained (previous snapshot points to it)
     // A should be deleted
-    assertThat(deletedFiles).contains(FILE_A.location());
-    assertThat(deletedFiles).doesNotContain(FILE_B.location());
-    assertThat(deletedFiles).doesNotContain(FILE_C.location());
-    assertThat(deletedFiles).doesNotContain(FILE_D.location());
+    assertThat(deletedFiles)
+        .contains(FILE_A.location())
+        .doesNotContain(FILE_B.location(), FILE_C.location(), FILE_D.location());
   }
 }
