@@ -45,8 +45,7 @@ public class TestSparkRecordOrcReaderWriter extends AvroDataTest {
   private static final int NUM_RECORDS = 200;
 
   private void writeAndValidate(Schema schema, List<Record> expectedRecords) throws IOException {
-    final File originalFile = File.createTempFile("junit", null, temp.toFile());
-    assertThat(originalFile.delete()).as("Delete should succeed").isTrue();
+    final File originalFile = temp.resolve("original").toFile();
 
     // Write few generic records into the original test file.
     try (FileAppender<Record> writer =
@@ -68,8 +67,7 @@ public class TestSparkRecordOrcReaderWriter extends AvroDataTest {
       assertEqualsUnsafe(schema.asStruct(), expectedRecords, reader, expectedRecords.size());
     }
 
-    final File anotherFile = File.createTempFile("junit", null, temp.toFile());
-    assertThat(anotherFile.delete()).as("Delete should succeed").isTrue();
+    final File anotherFile = temp.resolve("another").toFile();
 
     // Write those spark InternalRows into a new file again.
     try (FileAppender<InternalRow> writer =
@@ -130,12 +128,14 @@ public class TestSparkRecordOrcReaderWriter extends AvroDataTest {
     Iterator<Record> expectedIter = expected.iterator();
     Iterator<Record> actualIter = actual.iterator();
     for (int i = 0; i < size; i += 1) {
-      assertThat(expectedIter).as("Expected iterator should have more rows").hasNext();
-      assertThat(actualIter).as("Actual iterator should have more rows").hasNext();
-      assertThat(actualIter.next()).as("Should have same rows.").isEqualTo(expectedIter.next());
+      assertThat(expectedIter.hasNext()).as("Expected iterator should have more rows").isTrue();
+      assertThat(actualIter.hasNext()).as("Actual iterator should have more rows").isTrue();
+      assertThat(expectedIter.next()).isEqualTo(actualIter.next());
     }
-    assertThat(expectedIter).as("Expected iterator should not have any extra rows.").isExhausted();
-    assertThat(actualIter).as("Actual iterator should not have any extra rows.").isExhausted();
+    assertThat(expectedIter.hasNext())
+        .as("Expected iterator should not have any extra rows")
+        .isFalse();
+    assertThat(actualIter.hasNext()).as("Actual iterator should not have any extra rows").isFalse();
   }
 
   private static void assertEqualsUnsafe(
@@ -143,11 +143,13 @@ public class TestSparkRecordOrcReaderWriter extends AvroDataTest {
     Iterator<Record> expectedIter = expected.iterator();
     Iterator<InternalRow> actualIter = actual.iterator();
     for (int i = 0; i < size; i += 1) {
-      assertThat(expectedIter).as("Expected iterator should have more rows").hasNext();
-      assertThat(actualIter).as("Actual iterator should have more rows").hasNext();
+      assertThat(expectedIter.hasNext()).as("Expected iterator should have more rows").isTrue();
+      assertThat(actualIter.hasNext()).as("Actual iterator should have more rows").isTrue();
       GenericsHelpers.assertEqualsUnsafe(struct, expectedIter.next(), actualIter.next());
     }
-    assertThat(expectedIter).as("Expected iterator should not have any extra rows.").isExhausted();
-    assertThat(actualIter).as("Actual iterator should not have any extra rows.").isExhausted();
+    assertThat(expectedIter.hasNext())
+        .as("Expected iterator should not have any extra rows")
+        .isFalse();
+    assertThat(actualIter.hasNext()).as("Actual iterator should not have any extra rows").isFalse();
   }
 }
