@@ -27,7 +27,7 @@ import java.util.List;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.spark.Spark3Util;
-import org.apache.iceberg.spark.TestBaseWithCatalog;
+import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
 import org.apache.spark.sql.AnalysisException;
@@ -38,22 +38,23 @@ import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
 import org.apache.spark.sql.catalyst.parser.ParseException;
 import org.apache.spark.sql.internal.SQLConf;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
 
-public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
-  @BeforeEach
+public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
+  @Before
   public void createTable() {
     sql("CREATE TABLE %s (id bigint, data string) USING iceberg", tableName);
   }
 
-  @AfterEach
+  @After
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testMergeSchemaFailsWithoutWriterOption() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -85,7 +86,7 @@ public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
         .hasMessage("Field new_col not found in source schema");
   }
 
-  @TestTemplate
+  @Test
   public void testMergeSchemaWithoutAcceptAnySchema() throws Exception {
     Dataset<Row> twoColDF =
         jsonToDF(
@@ -108,11 +109,11 @@ public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
 
     assertThatThrownBy(() -> threeColDF.writeTo(tableName).option("merge-schema", "true").append())
         .isInstanceOf(AnalysisException.class)
-        .hasMessageContaining(
-            "Cannot write to `testhadoop`.`default`.`table`, the reason is too many data columns");
+        .hasMessageStartingWith(
+            "Cannot write to 'testhadoop.default.table', too many data columns");
   }
 
-  @TestTemplate
+  @Test
   public void testMergeSchemaSparkProperty() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -146,7 +147,7 @@ public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
         sql("select * from %s order by id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testMergeSchemaIcebergProperty() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -180,7 +181,7 @@ public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
         sql("select * from %s order by id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testWriteWithCaseSensitiveOption() throws NoSuchTableException, ParseException {
     SparkSession sparkSession = spark.cloneSession();
     sparkSession
@@ -204,51 +205,16 @@ public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
     List<Types.NestedField> fields =
         Spark3Util.loadIcebergTable(sparkSession, tableName).schema().asStruct().fields();
     // Additional columns should not be created
-    assertThat(fields).hasSize(2);
+    Assert.assertEquals(2, fields.size());
 
     // enable spark.sql.caseSensitive
     sparkSession.sql(String.format("SET %s=true", SQLConf.CASE_SENSITIVE().key()));
     ds.writeTo(tableName).option("merge-schema", "true").option("check-ordering", "false").append();
     fields = Spark3Util.loadIcebergTable(sparkSession, tableName).schema().asStruct().fields();
-    assertThat(fields).hasSize(4);
+    Assert.assertEquals(4, fields.size());
   }
 
-  @TestTemplate
-  public void testMergeSchemaSparkConfiguration() throws Exception {
-    sql(
-        "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
-        tableName, TableProperties.SPARK_WRITE_ACCEPT_ANY_SCHEMA);
-    Dataset<Row> twoColDF =
-        jsonToDF(
-            "id bigint, data string",
-            "{ \"id\": 1, \"data\": \"a\" }",
-            "{ \"id\": 2, \"data\": \"b\" }");
-
-    twoColDF.writeTo(tableName).append();
-
-    assertEquals(
-        "Should have initial 2-column rows",
-        ImmutableList.of(row(1L, "a"), row(2L, "b")),
-        sql("select * from %s order by id", tableName));
-    spark.conf().set("spark.sql.iceberg.merge-schema", "true");
-    Dataset<Row> threeColDF =
-        jsonToDF(
-            "id bigint, data string, salary float",
-            "{ \"id\": 3, \"data\": \"c\", \"salary\": 120000.34 }",
-            "{ \"id\": 4, \"data\": \"d\", \"salary\": 140000.56 }");
-
-    threeColDF.writeTo(tableName).append();
-    assertEquals(
-        "Should have 3-column rows",
-        ImmutableList.of(
-            row(1L, "a", null),
-            row(2L, "b", null),
-            row(3L, "c", 120000.34F),
-            row(4L, "d", 140000.56F)),
-        sql("select * from %s order by id", tableName));
-  }
-
-  @TestTemplate
+  @Test
   public void testMergeSchemaIgnoreCastingLongToInt() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -288,7 +254,7 @@ public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
     assertThat(idField.type().typeId()).isEqualTo(Type.TypeID.LONG);
   }
 
-  @TestTemplate
+  @Test
   public void testMergeSchemaIgnoreCastingDoubleToFloat() throws Exception {
     removeTables();
     sql("CREATE TABLE %s (id double, data string) USING iceberg", tableName);
@@ -330,7 +296,7 @@ public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
     assertThat(idField.type().typeId()).isEqualTo(Type.TypeID.DOUBLE);
   }
 
-  @TestTemplate
+  @Test
   public void testMergeSchemaIgnoreCastingDecimalToDecimalWithNarrowerPrecision() throws Exception {
     removeTables();
     sql("CREATE TABLE %s (id decimal(6,2), data string) USING iceberg", tableName);
