@@ -21,23 +21,24 @@ package org.apache.iceberg.spark.source;
 import static org.apache.iceberg.Files.localOutput;
 import static org.apache.iceberg.PlanningMode.DISTRIBUTED;
 import static org.apache.iceberg.PlanningMode.LOCAL;
+import static org.apache.spark.sql.catalyst.util.DateTimeUtils.fromJavaTimestamp;
+import static org.apache.spark.sql.functions.callUDF;
+import static org.apache.spark.sql.functions.column;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.io.IOException;
-import java.nio.file.Path;
+import java.sql.Timestamp;
 import java.time.OffsetDateTime;
 import java.util.Arrays;
 import java.util.List;
 import java.util.UUID;
+import java.util.function.Function;
 import java.util.stream.Collectors;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DataFiles;
 import org.apache.iceberg.FileFormat;
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.ParameterizedTestExtension;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.PlanningMode;
 import org.apache.iceberg.Schema;
@@ -52,13 +53,14 @@ import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.spark.SparkReadOptions;
-import org.apache.iceberg.spark.SparkWriteOptions;
 import org.apache.iceberg.spark.data.GenericsHelpers;
+import org.apache.iceberg.transforms.Transforms;
 import org.apache.iceberg.types.Types;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SparkSession;
+import org.apache.spark.sql.api.java.UDF1;
 import org.apache.spark.sql.catalyst.expressions.UnsafeRow;
 import org.apache.spark.sql.connector.expressions.filter.Predicate;
 import org.apache.spark.sql.connector.read.Batch;
@@ -72,15 +74,21 @@ import org.apache.spark.sql.sources.GreaterThan;
 import org.apache.spark.sql.sources.LessThan;
 import org.apache.spark.sql.sources.Not;
 import org.apache.spark.sql.sources.StringStartsWith;
+import org.apache.spark.sql.types.IntegerType$;
+import org.apache.spark.sql.types.LongType$;
+import org.apache.spark.sql.types.StringType$;
 import org.apache.spark.sql.util.CaseInsensitiveStringMap;
-import org.junit.jupiter.api.AfterAll;
-import org.junit.jupiter.api.BeforeAll;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
-import org.junit.jupiter.api.io.TempDir;
+import org.junit.AfterClass;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.BeforeClass;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
 
-@ExtendWith(ParameterizedTestExtension.class)
+@RunWith(Parameterized.class)
 public class TestFilteredScan {
   private static final Configuration CONF = new Configuration();
   private static final HadoopTables TABLES = new HadoopTables(CONF);
@@ -108,30 +116,48 @@ public class TestFilteredScan {
 
   private static SparkSession spark = null;
 
-  @BeforeAll
+  @BeforeClass
   public static void startSpark() {
     TestFilteredScan.spark = SparkSession.builder().master("local[2]").getOrCreate();
+
+    // define UDFs used by partition tests
+    Function<Object, Integer> bucket4 = Transforms.bucket(4).bind(Types.LongType.get());
+    spark.udf().register("bucket4", (UDF1<Long, Integer>) bucket4::apply, IntegerType$.MODULE$);
+
+    Function<Object, Integer> day = Transforms.day().bind(Types.TimestampType.withZone());
+    spark
+        .udf()
+        .register(
+            "ts_day",
+            (UDF1<Timestamp, Integer>) timestamp -> day.apply(fromJavaTimestamp(timestamp)),
+            IntegerType$.MODULE$);
+
+    Function<Object, Integer> hour = Transforms.hour().bind(Types.TimestampType.withZone());
+    spark
+        .udf()
+        .register(
+            "ts_hour",
+            (UDF1<Timestamp, Integer>) timestamp -> hour.apply(fromJavaTimestamp(timestamp)),
+            IntegerType$.MODULE$);
+
+    spark.udf().register("data_ident", (UDF1<String, String>) data -> data, StringType$.MODULE$);
+    spark.udf().register("id_ident", (UDF1<Long, Long>) id -> id, LongType$.MODULE$);
   }
 
-  @AfterAll
+  @AfterClass
   public static void stopSpark() {
     SparkSession currentSpark = TestFilteredScan.spark;
     TestFilteredScan.spark = null;
     currentSpark.stop();
   }
 
-  @TempDir private Path temp;
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
-  @Parameter(index = 0)
-  private String format;
+  private final String format;
+  private final boolean vectorized;
+  private final PlanningMode planningMode;
 
-  @Parameter(index = 1)
-  private boolean vectorized;
-
-  @Parameter(index = 2)
-  private PlanningMode planningMode;
-
-  @Parameters(name = "format = {0}, vectorized = {1}, planningMode = {2}")
+  @Parameterized.Parameters(name = "format = {0}, vectorized = {1}, planningMode = {2}")
   public static Object[][] parameters() {
     return new Object[][] {
       {"parquet", false, LOCAL},
@@ -142,16 +168,22 @@ public class TestFilteredScan {
     };
   }
 
+  public TestFilteredScan(String format, boolean vectorized, PlanningMode planningMode) {
+    this.format = format;
+    this.vectorized = vectorized;
+    this.planningMode = planningMode;
+  }
+
   private File parent = null;
   private File unpartitioned = null;
   private List<Record> records = null;
 
-  @BeforeEach
+  @Before
   public void writeUnpartitionedTable() throws IOException {
-    this.parent = temp.resolve("TestFilteredScan").toFile();
+    this.parent = temp.newFolder("TestFilteredScan");
     this.unpartitioned = new File(parent, "unpartitioned");
     File dataFolder = new File(unpartitioned, "data");
-    assertThat(dataFolder.mkdirs()).as("Mkdir should succeed").isTrue();
+    Assert.assertTrue("Mkdir should succeed", dataFolder.mkdirs());
 
     Table table =
         TABLES.create(
@@ -186,7 +218,7 @@ public class TestFilteredScan {
     table.newAppend().appendFile(file).commit();
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedIDFilters() {
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", unpartitioned.toString()));
@@ -198,7 +230,7 @@ public class TestFilteredScan {
       Batch scan = builder.build().toBatch();
 
       InputPartition[] partitions = scan.planInputPartitions();
-      assertThat(partitions).as("Should only create one task for a small file").hasSize(1);
+      Assert.assertEquals("Should only create one task for a small file", 1, partitions.length);
 
       // validate row filtering
       assertEqualsSafe(
@@ -206,7 +238,7 @@ public class TestFilteredScan {
     }
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedCaseInsensitiveIDFilters() {
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", unpartitioned.toString()));
@@ -228,7 +260,7 @@ public class TestFilteredScan {
         Batch scan = builder.build().toBatch();
 
         InputPartition[] tasks = scan.planInputPartitions();
-        assertThat(tasks).as("Should only create one task for a small file").hasSize(1);
+        Assert.assertEquals("Should only create one task for a small file", 1, tasks.length);
 
         // validate row filtering
         assertEqualsSafe(
@@ -242,7 +274,7 @@ public class TestFilteredScan {
     }
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedTimestampFilter() {
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", unpartitioned.toString()));
@@ -254,7 +286,7 @@ public class TestFilteredScan {
     Batch scan = builder.build().toBatch();
 
     InputPartition[] tasks = scan.planInputPartitions();
-    assertThat(tasks).as("Should only create one task for a small file").hasSize(1);
+    Assert.assertEquals("Should only create one task for a small file", 1, tasks.length);
 
     assertEqualsSafe(
         SCHEMA.asStruct(),
@@ -265,17 +297,16 @@ public class TestFilteredScan {
             "ts < cast('2017-12-22 00:00:00+00:00' as timestamp)"));
   }
 
-  @TestTemplate
+  @Test
   public void testBucketPartitionedIDFilters() {
-    Table table = buildPartitionedTable("bucketed_by_id", BUCKET_BY_ID);
+    Table table = buildPartitionedTable("bucketed_by_id", BUCKET_BY_ID, "bucket4", "id");
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
 
     Batch unfiltered =
         new SparkScanBuilder(spark, TABLES.load(options.get("path")), options).build().toBatch();
-    assertThat(unfiltered.planInputPartitions())
-        .as("Unfiltered table should created 4 read tasks")
-        .hasSize(4);
+    Assert.assertEquals(
+        "Unfiltered table should created 4 read tasks", 4, unfiltered.planInputPartitions().length);
 
     for (int i = 0; i < 10; i += 1) {
       SparkScanBuilder builder =
@@ -287,7 +318,7 @@ public class TestFilteredScan {
       InputPartition[] tasks = scan.planInputPartitions();
 
       // validate predicate push-down
-      assertThat(tasks).as("Should only create one task for a single bucket").hasSize(1);
+      Assert.assertEquals("Should create one task for a single bucket", 1, tasks.length);
 
       // validate row filtering
       assertEqualsSafe(
@@ -296,17 +327,16 @@ public class TestFilteredScan {
   }
 
   @SuppressWarnings("checkstyle:AvoidNestedBlocks")
-  @TestTemplate
+  @Test
   public void testDayPartitionedTimestampFilters() {
-    Table table = buildPartitionedTable("partitioned_by_day", PARTITION_BY_DAY);
+    Table table = buildPartitionedTable("partitioned_by_day", PARTITION_BY_DAY, "ts_day", "ts");
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
     Batch unfiltered =
         new SparkScanBuilder(spark, TABLES.load(options.get("path")), options).build().toBatch();
 
-    assertThat(unfiltered.planInputPartitions())
-        .as("Unfiltered table should created 2 read tasks")
-        .hasSize(2);
+    Assert.assertEquals(
+        "Unfiltered table should created 2 read tasks", 2, unfiltered.planInputPartitions().length);
 
     {
       SparkScanBuilder builder =
@@ -316,7 +346,7 @@ public class TestFilteredScan {
       Batch scan = builder.build().toBatch();
 
       InputPartition[] tasks = scan.planInputPartitions();
-      assertThat(tasks).as("Should create one task for 2017-12-21").hasSize(1);
+      Assert.assertEquals("Should create one task for 2017-12-21", 1, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
@@ -337,7 +367,7 @@ public class TestFilteredScan {
       Batch scan = builder.build().toBatch();
 
       InputPartition[] tasks = scan.planInputPartitions();
-      assertThat(tasks).as("Should create one task for 2017-12-22").hasSize(1);
+      Assert.assertEquals("Should create one task for 2017-12-22", 1, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
@@ -351,18 +381,17 @@ public class TestFilteredScan {
   }
 
   @SuppressWarnings("checkstyle:AvoidNestedBlocks")
-  @TestTemplate
+  @Test
   public void testHourPartitionedTimestampFilters() {
-    Table table = buildPartitionedTable("partitioned_by_hour", PARTITION_BY_HOUR);
+    Table table = buildPartitionedTable("partitioned_by_hour", PARTITION_BY_HOUR, "ts_hour", "ts");
 
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
     Batch unfiltered =
         new SparkScanBuilder(spark, TABLES.load(options.get("path")), options).build().toBatch();
 
-    assertThat(unfiltered.planInputPartitions())
-        .as("Unfiltered table should created 9 read tasks")
-        .hasSize(9);
+    Assert.assertEquals(
+        "Unfiltered table should created 9 read tasks", 9, unfiltered.planInputPartitions().length);
 
     {
       SparkScanBuilder builder =
@@ -372,7 +401,7 @@ public class TestFilteredScan {
       Batch scan = builder.build().toBatch();
 
       InputPartition[] tasks = scan.planInputPartitions();
-      assertThat(tasks).as("Should create 4 tasks for 2017-12-21: 15, 17, 21, 22").hasSize(4);
+      Assert.assertEquals("Should create 4 tasks for 2017-12-21: 15, 17, 21, 22", 4, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
@@ -393,7 +422,7 @@ public class TestFilteredScan {
       Batch scan = builder.build().toBatch();
 
       InputPartition[] tasks = scan.planInputPartitions();
-      assertThat(tasks).as("Should create 2 tasks for 2017-12-22: 6, 7").hasSize(2);
+      Assert.assertEquals("Should create 2 tasks for 2017-12-22: 6, 7", 2, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
@@ -407,7 +436,7 @@ public class TestFilteredScan {
   }
 
   @SuppressWarnings("checkstyle:AvoidNestedBlocks")
-  @TestTemplate
+  @Test
   public void testFilterByNonProjectedColumn() {
     {
       Schema actualProjection = SCHEMA.select("id", "data");
@@ -448,9 +477,10 @@ public class TestFilteredScan {
     }
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedByDataStartsWithFilter() {
-    Table table = buildPartitionedTable("partitioned_by_data", PARTITION_BY_DATA);
+    Table table =
+        buildPartitionedTable("partitioned_by_data", PARTITION_BY_DATA, "data_ident", "data");
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
 
@@ -460,12 +490,13 @@ public class TestFilteredScan {
     pushFilters(builder, new StringStartsWith("data", "junc"));
     Batch scan = builder.build().toBatch();
 
-    assertThat(scan.planInputPartitions()).hasSize(1);
+    Assert.assertEquals(1, scan.planInputPartitions().length);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedByDataNotStartsWithFilter() {
-    Table table = buildPartitionedTable("partitioned_by_data", PARTITION_BY_DATA);
+    Table table =
+        buildPartitionedTable("partitioned_by_data", PARTITION_BY_DATA, "data_ident", "data");
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
 
@@ -475,12 +506,12 @@ public class TestFilteredScan {
     pushFilters(builder, new Not(new StringStartsWith("data", "junc")));
     Batch scan = builder.build().toBatch();
 
-    assertThat(scan.planInputPartitions()).hasSize(9);
+    Assert.assertEquals(9, scan.planInputPartitions().length);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedByIdStartsWith() {
-    Table table = buildPartitionedTable("partitioned_by_id", PARTITION_BY_ID);
+    Table table = buildPartitionedTable("partitioned_by_id", PARTITION_BY_ID, "id_ident", "id");
 
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
@@ -491,12 +522,12 @@ public class TestFilteredScan {
     pushFilters(builder, new StringStartsWith("data", "junc"));
     Batch scan = builder.build().toBatch();
 
-    assertThat(scan.planInputPartitions()).hasSize(1);
+    Assert.assertEquals(1, scan.planInputPartitions().length);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedByIdNotStartsWith() {
-    Table table = buildPartitionedTable("partitioned_by_id", PARTITION_BY_ID);
+    Table table = buildPartitionedTable("partitioned_by_id", PARTITION_BY_ID, "id_ident", "id");
 
     CaseInsensitiveStringMap options =
         new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
@@ -507,10 +538,10 @@ public class TestFilteredScan {
     pushFilters(builder, new Not(new StringStartsWith("data", "junc")));
     Batch scan = builder.build().toBatch();
 
-    assertThat(scan.planInputPartitions()).hasSize(9);
+    Assert.assertEquals(9, scan.planInputPartitions().length);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedStartsWith() {
     Dataset<Row> df =
         spark
@@ -522,11 +553,11 @@ public class TestFilteredScan {
     List<String> matchedData =
         df.select("data").where("data LIKE 'jun%'").as(Encoders.STRING()).collectAsList();
 
-    assertThat(matchedData).hasSize(1);
-    assertThat(matchedData.get(0)).isEqualTo("junction");
+    Assert.assertEquals(1, matchedData.size());
+    Assert.assertEquals("junction", matchedData.get(0));
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedNotStartsWith() {
     Dataset<Row> df =
         spark
@@ -544,8 +575,8 @@ public class TestFilteredScan {
             .filter(d -> !d.startsWith("jun"))
             .collect(Collectors.toList());
 
-    assertThat(matchedData).hasSize(9);
-    assertThat(Sets.newHashSet(matchedData)).isEqualTo(Sets.newHashSet(expected));
+    Assert.assertEquals(9, matchedData.size());
+    Assert.assertEquals(Sets.newHashSet(expected), Sets.newHashSet(matchedData));
   }
 
   private static Record projectFlat(Schema projection, Record record) {
@@ -565,7 +596,7 @@ public class TestFilteredScan {
     for (int i = 0; i < numRecords; i += 1) {
       GenericsHelpers.assertEqualsUnsafe(struct, expected.get(i), actual.get(i));
     }
-    assertThat(actual).as("Number of results should match expected").hasSameSizeAs(expected);
+    Assert.assertEquals("Number of results should match expected", expected.size(), actual.size());
   }
 
   public static void assertEqualsSafe(
@@ -575,7 +606,7 @@ public class TestFilteredScan {
     for (int i = 0; i < numRecords; i += 1) {
       GenericsHelpers.assertEqualsSafe(struct, expected.get(i), actual.get(i));
     }
-    assertThat(actual).as("Number of results should match expected").hasSameSizeAs(expected);
+    Assert.assertEquals("Number of results should match expected", expected.size(), actual.size());
   }
 
   private List<Record> expected(int... ordinals) {
@@ -592,7 +623,8 @@ public class TestFilteredScan {
     filterable.pushPredicates(Arrays.stream(filters).map(Filter::toV2).toArray(Predicate[]::new));
   }
 
-  private Table buildPartitionedTable(String desc, PartitionSpec spec) {
+  private Table buildPartitionedTable(
+      String desc, PartitionSpec spec, String udf, String partitionColumn) {
     File location = new File(parent, desc);
     Table table = TABLES.create(SCHEMA, spec, location.toString());
 
@@ -608,10 +640,12 @@ public class TestFilteredScan {
             .option(SparkReadOptions.VECTORIZATION_ENABLED, String.valueOf(vectorized))
             .load(unpartitioned.toString());
 
-    // disable fanout writers to locally order records for future verifications
     allRows
+        .coalesce(1) // ensure only 1 file per partition is written
+        .withColumn("part", callUDF(udf, column(partitionColumn)))
+        .sortWithinPartitions("part")
+        .drop("part")
         .write()
-        .option(SparkWriteOptions.FANOUT_ENABLED, "false")
         .format("iceberg")
         .mode("append")
         .save(table.location());
