@@ -642,9 +642,8 @@ public class TestMetadataTablesWithPartitionEvolution extends SparkCatalogTestBa
 
     for (MetadataTableType tableType : Arrays.asList(FILES, ALL_DATA_FILES, ENTRIES, ALL_ENTRIES)) {
       assertThatThrownBy(() -> loadMetadataTable(tableType))
-          .as("Should complain about the partition type")
           .isInstanceOf(ValidationException.class)
-          .hasMessageContaining("Cannot build table partition type, unknown transforms");
+          .hasMessage("Cannot build table partition type, unknown transforms: [zero]");
     }
   }
 
