@@ -18,23 +18,16 @@
  */
 package org.apache.iceberg.spark.source;
 
-import static org.apache.iceberg.spark.data.TestVectorizedOrcDataReader.temp;
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.iceberg.types.Types.NestedField.required;
-import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.File;
-import java.nio.file.Path;
 import java.util.List;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import org.apache.avro.generic.GenericData;
 import org.apache.iceberg.DataFiles;
 import org.apache.iceberg.Files;
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.ParameterizedTestExtension;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Table;
@@ -59,15 +52,19 @@ import org.apache.spark.sql.types.DataTypes;
 import org.apache.spark.sql.types.Metadata;
 import org.apache.spark.sql.types.StructField;
 import org.apache.spark.sql.types.StructType;
-import org.junit.jupiter.api.AfterAll;
-import org.junit.jupiter.api.BeforeAll;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
-import org.junit.jupiter.api.io.TempDir;
+import org.junit.AfterClass;
+import org.junit.Assert;
+import org.junit.Assume;
+import org.junit.BeforeClass;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
 
-@ExtendWith(ParameterizedTestExtension.class)
+@RunWith(Parameterized.class)
 public class TestPartitionValues {
-  @Parameters(name = "format = {0}, vectorized = {1}")
+  @Parameterized.Parameters(name = "format = {0}, vectorized = {1}")
   public static Object[][] parameters() {
     return new Object[][] {
       {"parquet", false},
@@ -105,33 +102,35 @@ public class TestPartitionValues {
 
   private static SparkSession spark = null;
 
-  @BeforeAll
+  @BeforeClass
   public static void startSpark() {
     TestPartitionValues.spark = SparkSession.builder().master("local[2]").getOrCreate();
   }
 
-  @AfterAll
+  @AfterClass
   public static void stopSpark() {
     SparkSession currentSpark = TestPartitionValues.spark;
     TestPartitionValues.spark = null;
     currentSpark.stop();
   }
 
-  @TempDir private Path temp;
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
-  @Parameter(index = 0)
-  private String format;
+  private final String format;
+  private final boolean vectorized;
 
-  @Parameter(index = 1)
-  private boolean vectorized;
+  public TestPartitionValues(String format, boolean vectorized) {
+    this.format = format;
+    this.vectorized = vectorized;
+  }
 
-  @TestTemplate
+  @Test
   public void testNullPartitionValue() throws Exception {
     String desc = "null_part";
-    File parent = new File(temp.toFile(), desc);
+    File parent = temp.newFolder(desc);
     File location = new File(parent, "test");
     File dataFolder = new File(location, "data");
-    assertThat(dataFolder.mkdirs()).as("mkdirs should succeed").isTrue();
+    Assert.assertTrue("mkdirs should succeed", dataFolder.mkdirs());
 
     HadoopTables tables = new HadoopTables(spark.sessionState().newHadoopConf());
     Table table = tables.create(SIMPLE_SCHEMA, SPEC, location.toString());
@@ -162,17 +161,17 @@ public class TestPartitionValues {
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
 
-    assertThat(actual).as("Number of rows should match").hasSameSizeAs(expected);
-    assertThat(actual).as("Result rows should match").isEqualTo(expected);
+    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
+    Assert.assertEquals("Result rows should match", expected, actual);
   }
 
-  @TestTemplate
+  @Test
   public void testReorderedColumns() throws Exception {
     String desc = "reorder_columns";
-    File parent = new File(temp.toFile(), desc);
+    File parent = temp.newFolder(desc);
     File location = new File(parent, "test");
     File dataFolder = new File(location, "data");
-    assertThat(dataFolder.mkdirs()).as("mkdirs should succeed").isTrue();
+    Assert.assertTrue("mkdirs should succeed", dataFolder.mkdirs());
 
     HadoopTables tables = new HadoopTables(spark.sessionState().newHadoopConf());
     Table table = tables.create(SIMPLE_SCHEMA, SPEC, location.toString());
@@ -201,17 +200,17 @@ public class TestPartitionValues {
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
 
-    assertThat(actual).as("Number of rows should match").hasSameSizeAs(expected);
-    assertThat(actual).as("Result rows should match").isEqualTo(expected);
+    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
+    Assert.assertEquals("Result rows should match", expected, actual);
   }
 
-  @TestTemplate
+  @Test
   public void testReorderedColumnsNoNullability() throws Exception {
     String desc = "reorder_columns_no_nullability";
-    File parent = new File(temp.toFile(), desc);
+    File parent = temp.newFolder(desc);
     File location = new File(parent, "test");
     File dataFolder = new File(location, "data");
-    assertThat(dataFolder.mkdirs()).as("mkdirs should succeed").isTrue();
+    Assert.assertTrue("mkdirs should succeed", dataFolder.mkdirs());
 
     HadoopTables tables = new HadoopTables(spark.sessionState().newHadoopConf());
     Table table = tables.create(SIMPLE_SCHEMA, SPEC, location.toString());
@@ -241,11 +240,11 @@ public class TestPartitionValues {
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
 
-    assertThat(actual).as("Number of rows should match").hasSameSizeAs(expected);
-    assertThat(actual).as("Result rows should match").isEqualTo(expected);
+    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
+    Assert.assertEquals("Result rows should match", expected, actual);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionValueTypes() throws Exception {
     String[] columnNames =
         new String[] {
@@ -255,13 +254,13 @@ public class TestPartitionValues {
     HadoopTables tables = new HadoopTables(spark.sessionState().newHadoopConf());
 
     // create a table around the source data
-    String sourceLocation = temp.resolve("source_table").toString();
+    String sourceLocation = temp.newFolder("source_table").toString();
     Table source = tables.create(SUPPORTED_PRIMITIVES, sourceLocation);
 
     // write out an Avro data file with all of the data types for source data
     List<GenericData.Record> expected = RandomData.generateList(source.schema(), 2, 128735L);
-    File avroData = File.createTempFile("data", ".avro", temp.toFile());
-    assertThat(avroData.delete()).isTrue();
+    File avroData = temp.newFile("data.avro");
+    Assert.assertTrue(avroData.delete());
     try (FileAppender<GenericData.Record> appender =
         Avro.write(Files.localOutput(avroData)).schema(source.schema()).build()) {
       appender.addAll(expected);
@@ -287,23 +286,21 @@ public class TestPartitionValues {
     for (String column : columnNames) {
       String desc = "partition_by_" + SUPPORTED_PRIMITIVES.findType(column).toString();
 
-      File parent = new File(temp.toFile(), desc);
+      File parent = temp.newFolder(desc);
       File location = new File(parent, "test");
       File dataFolder = new File(location, "data");
-      assertThat(dataFolder.mkdirs()).as("mkdirs should succeed").isTrue();
+      Assert.assertTrue("mkdirs should succeed", dataFolder.mkdirs());
 
       PartitionSpec spec = PartitionSpec.builderFor(SUPPORTED_PRIMITIVES).identity(column).build();
 
       Table table = tables.create(SUPPORTED_PRIMITIVES, spec, location.toString());
       table.updateProperties().set(TableProperties.DEFAULT_FILE_FORMAT, format).commit();
 
-      // disable distribution/ordering and fanout writers to preserve the original ordering
       sourceDF
           .write()
           .format("iceberg")
           .mode(SaveMode.Append)
           .option(SparkWriteOptions.USE_TABLE_DISTRIBUTION_AND_ORDERING, "false")
-          .option(SparkWriteOptions.FANOUT_ENABLED, "false")
           .save(location.toString());
 
       List<Row> actual =
@@ -314,7 +311,7 @@ public class TestPartitionValues {
               .load(location.toString())
               .collectAsList();
 
-      assertThat(actual).as("Number of rows should match").hasSameSizeAs(expected);
+      Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
 
       for (int i = 0; i < expected.size(); i += 1) {
         TestHelpers.assertEqualsSafe(
@@ -323,7 +320,7 @@ public class TestPartitionValues {
     }
   }
 
-  @TestTemplate
+  @Test
   public void testNestedPartitionValues() throws Exception {
     String[] columnNames =
         new String[] {
@@ -334,13 +331,13 @@ public class TestPartitionValues {
     Schema nestedSchema = new Schema(optional(1, "nested", SUPPORTED_PRIMITIVES.asStruct()));
 
     // create a table around the source data
-    String sourceLocation = temp.resolve("source_table").toString();
+    String sourceLocation = temp.newFolder("source_table").toString();
     Table source = tables.create(nestedSchema, sourceLocation);
 
     // write out an Avro data file with all of the data types for source data
     List<GenericData.Record> expected = RandomData.generateList(source.schema(), 2, 128735L);
-    File avroData = File.createTempFile("data", ".avro", temp.toFile());
-    assertThat(avroData.delete()).isTrue();
+    File avroData = temp.newFile("data.avro");
+    Assert.assertTrue(avroData.delete());
     try (FileAppender<GenericData.Record> appender =
         Avro.write(Files.localOutput(avroData)).schema(source.schema()).build()) {
       appender.addAll(expected);
@@ -366,10 +363,10 @@ public class TestPartitionValues {
     for (String column : columnNames) {
       String desc = "partition_by_" + SUPPORTED_PRIMITIVES.findType(column).toString();
 
-      File parent = new File(temp.toFile(), desc);
+      File parent = temp.newFolder(desc);
       File location = new File(parent, "test");
       File dataFolder = new File(location, "data");
-      assertThat(dataFolder.mkdirs()).as("mkdirs should succeed").isTrue();
+      Assert.assertTrue("mkdirs should succeed", dataFolder.mkdirs());
 
       PartitionSpec spec =
           PartitionSpec.builderFor(nestedSchema).identity("nested." + column).build();
@@ -377,13 +374,11 @@ public class TestPartitionValues {
       Table table = tables.create(nestedSchema, spec, location.toString());
       table.updateProperties().set(TableProperties.DEFAULT_FILE_FORMAT, format).commit();
 
-      // disable distribution/ordering and fanout writers to preserve the original ordering
       sourceDF
           .write()
           .format("iceberg")
           .mode(SaveMode.Append)
           .option(SparkWriteOptions.USE_TABLE_DISTRIBUTION_AND_ORDERING, "false")
-          .option(SparkWriteOptions.FANOUT_ENABLED, "false")
           .save(location.toString());
 
       List<Row> actual =
@@ -394,7 +389,7 @@ public class TestPartitionValues {
               .load(location.toString())
               .collectAsList();
 
-      assertThat(actual).as("Number of rows should match").hasSameSizeAs(expected);
+      Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
 
       for (int i = 0; i < expected.size(); i += 1) {
         TestHelpers.assertEqualsSafe(nestedSchema.asStruct(), expected.get(i), actual.get(i));
@@ -408,7 +403,7 @@ public class TestPartitionValues {
    * thrown with the message like: Cannot cast org.apache.spark.unsafe.types.UTF8String to
    * java.lang.CharSequence
    */
-  @TestTemplate
+  @Test
   public void testPartitionedByNestedString() throws Exception {
     // schema and partition spec
     Schema nestedSchema =
@@ -422,7 +417,7 @@ public class TestPartitionValues {
 
     // create table
     HadoopTables tables = new HadoopTables(spark.sessionState().newHadoopConf());
-    String baseLocation = temp.resolve("partition_by_nested_string").toString();
+    String baseLocation = temp.newFolder("partition_by_nested_string").toString();
     tables.create(nestedSchema, spec, baseLocation);
 
     // input data frame
@@ -453,12 +448,12 @@ public class TestPartitionValues {
             .load(baseLocation)
             .collectAsList();
 
-    assertThat(actual).as("Number of rows should match").hasSameSizeAs(rows);
+    Assert.assertEquals("Number of rows should match", rows.size(), actual.size());
   }
 
-  @TestTemplate
+  @Test
   public void testReadPartitionColumn() throws Exception {
-    assumeThat(format).as("Temporary skip ORC").isNotEqualTo("orc");
+    Assume.assumeTrue("Temporary skip ORC", !"orc".equals(format));
 
     Schema nestedSchema =
         new Schema(
@@ -474,7 +469,7 @@ public class TestPartitionValues {
 
     // create table
     HadoopTables tables = new HadoopTables(spark.sessionState().newHadoopConf());
-    String baseLocation = temp.resolve("partition_by_nested_string").toString();
+    String baseLocation = temp.newFolder("partition_by_nested_string").toString();
     Table table = tables.create(nestedSchema, spec, baseLocation);
     table.updateProperties().set(TableProperties.DEFAULT_FILE_FORMAT, format).commit();
 
@@ -500,10 +495,10 @@ public class TestPartitionValues {
             .as(Encoders.STRING())
             .collectAsList();
 
-    assertThat(actual).as("Number of rows should match").hasSize(10);
+    Assert.assertEquals("Number of rows should match", 10, actual.size());
 
     List<String> inputRecords =
         IntStream.range(0, 10).mapToObj(i -> "name_" + i).collect(Collectors.toList());
-    assertThat(actual).as("Read object should be matched").isEqualTo(inputRecords);
+    Assert.assertEquals("Read object should be matched", inputRecords, actual);
   }
 }
