@@ -19,7 +19,6 @@
 package org.apache.iceberg.spark.source;
 
 import java.util.List;
-import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.io.FileWriterFactory;
 import org.apache.iceberg.io.TestPositionDeltaWriters;
@@ -33,10 +32,6 @@ import org.apache.spark.unsafe.types.UTF8String;
 
 public class TestSparkPositionDeltaWriters extends TestPositionDeltaWriters<InternalRow> {
 
-  public TestSparkPositionDeltaWriters(FileFormat fileFormat) {
-    super(fileFormat);
-  }
-
   @Override
   protected FileWriterFactory<InternalRow> newWriterFactory(
       Schema dataSchema,
@@ -66,7 +61,7 @@ public class TestSparkPositionDeltaWriters extends TestPositionDeltaWriters<Inte
     StructLikeSet set = StructLikeSet.create(table.schema().asStruct());
     StructType sparkType = SparkSchemaUtil.convert(table.schema());
     for (InternalRow row : rows) {
-      InternalRowWrapper wrapper = new InternalRowWrapper(sparkType);
+      InternalRowWrapper wrapper = new InternalRowWrapper(sparkType, table.schema().asStruct());
       set.add(wrapper.wrap(row));
     }
     return set;
