@@ -18,51 +18,34 @@
  */
 package org.apache.iceberg.spark.sql;
 
-import static org.assertj.core.api.Assertions.assertThat;
-
 import java.util.List;
 import java.util.stream.IntStream;
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.spark.IcebergSpark;
-import org.apache.iceberg.spark.SparkCatalogConfig;
-import org.apache.iceberg.spark.TestBaseWithCatalog;
+import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
 import org.apache.spark.sql.types.DataTypes;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
 
-public class TestPartitionedWritesAsSelect extends TestBaseWithCatalog {
+public class TestPartitionedWritesAsSelect extends SparkTestBaseWithCatalog {
 
-  @Parameter(index = 3)
-  private String targetTable;
+  private final String targetTable = tableName("target_table");
 
-  @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}, targetTable = {3}")
-  protected static Object[][] parameters() {
-    return new Object[][] {
-      {
-        SparkCatalogConfig.HADOOP.catalogName(),
-        SparkCatalogConfig.HADOOP.implementation(),
-        SparkCatalogConfig.HADOOP.properties(),
-        SparkCatalogConfig.HADOOP.catalogName() + ".default.target_table"
-      },
-    };
-  }
-
-  @BeforeEach
+  @Before
   public void createTables() {
     sql(
         "CREATE TABLE %s (id bigint, data string, category string, ts timestamp) USING iceberg",
         tableName);
   }
 
-  @AfterEach
+  @After
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
     sql("DROP TABLE IF EXISTS %s", targetTable);
   }
 
-  @TestTemplate
+  @Test
   public void testInsertAsSelectAppend() {
     insertData(3);
     List<Object[]> expected = currentData();
@@ -75,9 +58,10 @@ public class TestPartitionedWritesAsSelect extends TestBaseWithCatalog {
     sql(
         "INSERT INTO %s SELECT id, data, category, ts FROM %s ORDER BY ts,category",
         targetTable, tableName);
-    assertThat(scalarSql("SELECT count(*) FROM %s", targetTable))
-        .as("Should have 15 rows after insert")
-        .isEqualTo(3 * 5L);
+    Assert.assertEquals(
+        "Should have 15 rows after insert",
+        3 * 5L,
+        scalarSql("SELECT count(*) FROM %s", targetTable));
 
     assertEquals(
         "Row data should match expected",
@@ -85,7 +69,7 @@ public class TestPartitionedWritesAsSelect extends TestBaseWithCatalog {
         sql("SELECT * FROM %s ORDER BY id", targetTable));
   }
 
-  @TestTemplate
+  @Test
   public void testInsertAsSelectWithBucket() {
     insertData(3);
     List<Object[]> expected = currentData();
@@ -99,9 +83,10 @@ public class TestPartitionedWritesAsSelect extends TestBaseWithCatalog {
     sql(
         "INSERT INTO %s SELECT id, data, category, ts FROM %s ORDER BY iceberg_bucket8(data)",
         targetTable, tableName);
-    assertThat(scalarSql("SELECT count(*) FROM %s", targetTable))
-        .as("Should have 15 rows after insert")
-        .isEqualTo(3 * 5L);
+    Assert.assertEquals(
+        "Should have 15 rows after insert",
+        3 * 5L,
+        scalarSql("SELECT count(*) FROM %s", targetTable));
 
     assertEquals(
         "Row data should match expected",
@@ -109,7 +94,7 @@ public class TestPartitionedWritesAsSelect extends TestBaseWithCatalog {
         sql("SELECT * FROM %s ORDER BY id", targetTable));
   }
 
-  @TestTemplate
+  @Test
   public void testInsertAsSelectWithTruncate() {
     insertData(3);
     List<Object[]> expected = currentData();
@@ -125,9 +110,10 @@ public class TestPartitionedWritesAsSelect extends TestBaseWithCatalog {
         "INSERT INTO %s SELECT id, data, category, ts FROM %s "
             + "ORDER BY iceberg_truncate_string4(data),iceberg_truncate_long4(id)",
         targetTable, tableName);
-    assertThat(scalarSql("SELECT count(*) FROM %s", targetTable))
-        .as("Should have 15 rows after insert")
-        .isEqualTo(3 * 5L);
+    Assert.assertEquals(
+        "Should have 15 rows after insert",
+        3 * 5L,
+        scalarSql("SELECT count(*) FROM %s", targetTable));
 
     assertEquals(
         "Row data should match expected",
