@@ -18,65 +18,37 @@
  */
 package org.apache.iceberg.spark.sql;
 
-import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.text.SimpleDateFormat;
-import java.util.Arrays;
 import java.util.Date;
 import java.util.List;
+import java.util.Map;
 import java.util.concurrent.TimeUnit;
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.events.Listeners;
 import org.apache.iceberg.events.ScanEvent;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
-import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.spark.Spark3Util;
-import org.apache.iceberg.spark.SparkCatalogConfig;
+import org.apache.iceberg.spark.SparkCatalogTestBase;
 import org.apache.iceberg.spark.SparkReadOptions;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
 
-public class TestSelect extends CatalogTestBase {
+public class TestSelect extends SparkCatalogTestBase {
   private int scanEventCount = 0;
   private ScanEvent lastScanEvent = null;
+  private String binaryTableName = tableName("binary_table");
 
-  @Parameter(index = 3)
-  private String binaryTableName;
+  public TestSelect(String catalogName, String implementation, Map<String, String> config) {
+    super(catalogName, implementation, config);
 
-  @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}, binaryTableName = {3}")
-  protected static Object[][] parameters() {
-    return new Object[][] {
-      {
-        SparkCatalogConfig.HIVE.catalogName(),
-        SparkCatalogConfig.HIVE.implementation(),
-        SparkCatalogConfig.HIVE.properties(),
-        SparkCatalogConfig.HIVE.catalogName() + ".default.binary_table"
-      },
-      {
-        SparkCatalogConfig.HADOOP.catalogName(),
-        SparkCatalogConfig.HADOOP.implementation(),
-        SparkCatalogConfig.HADOOP.properties(),
-        SparkCatalogConfig.HADOOP.catalogName() + ".default.binary_table"
-      },
-      {
-        SparkCatalogConfig.SPARK.catalogName(),
-        SparkCatalogConfig.SPARK.implementation(),
-        SparkCatalogConfig.SPARK.properties(),
-        "default.binary_table"
-      }
-    };
-  }
-
-  @BeforeEach
-  public void createTables() {
     // register a scan event listener to validate pushdown
     Listeners.register(
         event -> {
@@ -84,7 +56,10 @@ public class TestSelect extends CatalogTestBase {
           lastScanEvent = event;
         },
         ScanEvent.class);
+  }
 
+  @Before
+  public void createTables() {
     sql("CREATE TABLE %s (id bigint, data string, float float) USING iceberg", tableName);
     sql("INSERT INTO %s VALUES (1, 'a', 1.0), (2, 'b', 2.0), (3, 'c', float('NaN'))", tableName);
 
@@ -92,13 +67,13 @@ public class TestSelect extends CatalogTestBase {
     this.lastScanEvent = null;
   }
 
-  @AfterEach
+  @After
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
     sql("DROP TABLE IF EXISTS %s", binaryTableName);
   }
 
-  @TestTemplate
+  @Test
   public void testSelect() {
     List<Object[]> expected =
         ImmutableList.of(row(1L, "a", 1.0F), row(2L, "b", 2.0F), row(3L, "c", Float.NaN));
@@ -106,7 +81,7 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Should return all expected rows", expected, sql("SELECT * FROM %s", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testSelectRewrite() {
     List<Object[]> expected = ImmutableList.of(row(3L, "c", Float.NaN));
 
@@ -115,28 +90,29 @@ public class TestSelect extends CatalogTestBase {
         expected,
         sql("SELECT * FROM %s where float = float('NaN')", tableName));
 
-    assertThat(scanEventCount).as("Should create only one scan").isEqualTo(1);
-    assertThat(Spark3Util.describe(lastScanEvent.filter()))
-        .as("Should push down expected filter")
-        .isEqualTo("(float IS NOT NULL AND is_nan(float))");
+    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
+    Assert.assertEquals(
+        "Should push down expected filter",
+        "(float IS NOT NULL AND is_nan(float))",
+        Spark3Util.describe(lastScanEvent.filter()));
   }
 
-  @TestTemplate
+  @Test
   public void testProjection() {
     List<Object[]> expected = ImmutableList.of(row(1L), row(2L), row(3L));
 
     assertEquals("Should return all expected rows", expected, sql("SELECT id FROM %s", tableName));
 
-    assertThat(scanEventCount).as("Should create only one scan").isEqualTo(1);
-    assertThat(lastScanEvent.filter())
-        .as("Should not push down a filter")
-        .isEqualTo(Expressions.alwaysTrue());
-    assertThat(lastScanEvent.projection().asStruct())
-        .as("Should project only the id column")
-        .isEqualTo(validationCatalog.loadTable(tableIdent).schema().select("id").asStruct());
+    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
+    Assert.assertEquals(
+        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    Assert.assertEquals(
+        "Should project only the id column",
+        validationCatalog.loadTable(tableIdent).schema().select("id").asStruct(),
+        lastScanEvent.projection().asStruct());
   }
 
-  @TestTemplate
+  @Test
   public void testExpressionPushdown() {
     List<Object[]> expected = ImmutableList.of(row("b"));
 
@@ -145,17 +121,18 @@ public class TestSelect extends CatalogTestBase {
         expected,
         sql("SELECT data FROM %s WHERE id = 2", tableName));
 
-    assertThat(scanEventCount).as("Should create only one scan").isEqualTo(1);
-    assertThat(Spark3Util.describe(lastScanEvent.filter()))
-        .as("Should push down expected filter")
-        .isEqualTo("(id IS NOT NULL AND id = 2)");
-    assertThat(lastScanEvent.projection().asStruct())
-        .as("Should project only id and data columns")
-        .isEqualTo(
-            validationCatalog.loadTable(tableIdent).schema().select("id", "data").asStruct());
+    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
+    Assert.assertEquals(
+        "Should push down expected filter",
+        "(id IS NOT NULL AND id = 2)",
+        Spark3Util.describe(lastScanEvent.filter()));
+    Assert.assertEquals(
+        "Should project only id and data columns",
+        validationCatalog.loadTable(tableIdent).schema().select("id", "data").asStruct(),
+        lastScanEvent.projection().asStruct());
   }
 
-  @TestTemplate
+  @Test
   public void testMetadataTables() {
     assertEquals(
         "Snapshot metadata table",
@@ -163,7 +140,7 @@ public class TestSelect extends CatalogTestBase {
         sql("SELECT * FROM %s.snapshots", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testSnapshotInTableName() {
     // get the snapshot ID of the last write and get the current row set as expected
     long snapshotId = validationCatalog.loadTable(tableIdent).currentSnapshot().snapshotId();
@@ -188,7 +165,7 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at specific ID " + snapshotId, expected, fromDF);
   }
 
-  @TestTemplate
+  @Test
   public void testTimestampInTableName() {
     // get a timestamp just after the last write and get the current row set as expected
     long snapshotTs = validationCatalog.loadTable(tableIdent).currentSnapshot().timestampMillis();
@@ -214,7 +191,7 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at timestamp " + timestamp, expected, fromDF);
   }
 
-  @TestTemplate
+  @Test
   public void testVersionAsOf() {
     // get the snapshot ID of the last write and get the current row set as expected
     long snapshotId = validationCatalog.loadTable(tableIdent).currentSnapshot().snapshotId();
@@ -244,7 +221,7 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at specific ID " + snapshotId, expected, fromDF);
   }
 
-  @TestTemplate
+  @Test
   public void testTagReference() {
     Table table = validationCatalog.loadTable(tableIdent);
     long snapshotId = table.currentSnapshot().snapshotId();
@@ -275,7 +252,7 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at specific tag reference name", expected, fromDF);
   }
 
-  @TestTemplate
+  @Test
   public void testUseSnapshotIdForTagReferenceAsOf() {
     Table table = validationCatalog.loadTable(tableIdent);
     long snapshotId1 = table.currentSnapshot().snapshotId();
@@ -300,7 +277,7 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at specific tag reference name", actual, travelWithLongResult);
   }
 
-  @TestTemplate
+  @Test
   public void testBranchReference() {
     Table table = validationCatalog.loadTable(tableIdent);
     long snapshotId = table.currentSnapshot().snapshotId();
@@ -336,72 +313,14 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at specific branch reference name", expected, fromDF);
   }
 
-  @TestTemplate
-  public void readAndWriteWithBranchAfterSchemaChange() {
-    Table table = validationCatalog.loadTable(tableIdent);
-    String branchName = "test_branch";
-    table.manageSnapshots().createBranch(branchName, table.currentSnapshot().snapshotId()).commit();
-
-    List<Object[]> expected =
-        Arrays.asList(row(1L, "a", 1.0f), row(2L, "b", 2.0f), row(3L, "c", Float.NaN));
-    assertThat(sql("SELECT * FROM %s", tableName)).containsExactlyElementsOf(expected);
-
-    // change schema on the table and add more data
-    sql("ALTER TABLE %s DROP COLUMN float", tableName);
-    sql("ALTER TABLE %s ADD COLUMN new_col date", tableName);
-    sql(
-        "INSERT INTO %s VALUES (4, 'd', date('2024-04-04')), (5, 'e', date('2024-05-05'))",
-        tableName);
-
-    // time-travel query using snapshot id should return the snapshot's schema
-    long branchSnapshotId = table.refs().get(branchName).snapshotId();
-    assertThat(sql("SELECT * FROM %s VERSION AS OF %s", tableName, branchSnapshotId))
-        .containsExactlyElementsOf(expected);
-
-    // querying the head of the branch should return the table's schema
-    assertThat(sql("SELECT * FROM %s VERSION AS OF '%s'", tableName, branchName))
-        .containsExactly(row(1L, "a", null), row(2L, "b", null), row(3L, "c", null));
-
-    if (!"spark_catalog".equals(catalogName)) {
-      // querying the head of the branch using 'branch_' should return the table's schema
-      assertThat(sql("SELECT * FROM %s.branch_%s", tableName, branchName))
-          .containsExactly(row(1L, "a", null), row(2L, "b", null), row(3L, "c", null));
-    }
-
-    // writing to a branch uses the table's schema
-    sql(
-        "INSERT INTO %s.branch_%s VALUES (6L, 'f', cast('2023-06-06' as date)), (7L, 'g', cast('2023-07-07' as date))",
-        tableName, branchName);
-
-    // querying the head of the branch returns the table's schema
-    assertThat(sql("SELECT * FROM %s VERSION AS OF '%s'", tableName, branchName))
-        .containsExactlyInAnyOrder(
-            row(1L, "a", null),
-            row(2L, "b", null),
-            row(3L, "c", null),
-            row(6L, "f", java.sql.Date.valueOf("2023-06-06")),
-            row(7L, "g", java.sql.Date.valueOf("2023-07-07")));
-
-    // using DataFrameReader with the 'branch' option should return the table's schema
-    Dataset<Row> df =
-        spark.read().format("iceberg").option(SparkReadOptions.BRANCH, branchName).load(tableName);
-    assertThat(rowsToJava(df.collectAsList()))
-        .containsExactlyInAnyOrder(
-            row(1L, "a", null),
-            row(2L, "b", null),
-            row(3L, "c", null),
-            row(6L, "f", java.sql.Date.valueOf("2023-06-06")),
-            row(7L, "g", java.sql.Date.valueOf("2023-07-07")));
-  }
-
-  @TestTemplate
+  @Test
   public void testUnknownReferenceAsOf() {
     assertThatThrownBy(() -> sql("SELECT * FROM %s VERSION AS OF 'test_unknown'", tableName))
         .hasMessageContaining("Cannot find matching snapshot ID or reference name for version")
         .isInstanceOf(ValidationException.class);
   }
 
-  @TestTemplate
+  @Test
   public void testTimestampAsOf() {
     long snapshotTs = validationCatalog.loadTable(tableIdent).currentSnapshot().timestampMillis();
     long timestamp = waitUntilAfter(snapshotTs + 1000);
@@ -448,7 +367,7 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at timestamp " + timestamp, expected, fromDF);
   }
 
-  @TestTemplate
+  @Test
   public void testInvalidTimeTravelBasedOnBothAsOfAndTableIdentifier() {
     // get the snapshot ID of the last write
     long snapshotId = validationCatalog.loadTable(tableIdent).currentSnapshot().snapshotId();
@@ -503,7 +422,7 @@ public class TestSelect extends CatalogTestBase {
         .hasMessage("Cannot do time-travel based on both table identifier and AS OF");
   }
 
-  @TestTemplate
+  @Test
   public void testInvalidTimeTravelAgainstBranchIdentifierWithAsOf() {
     long snapshotId = validationCatalog.loadTable(tableIdent).currentSnapshot().snapshotId();
     validationCatalog.loadTable(tableIdent).manageSnapshots().createBranch("b1").commit();
@@ -523,7 +442,7 @@ public class TestSelect extends CatalogTestBase {
         .hasMessage("Cannot do time-travel based on both table identifier and AS OF");
   }
 
-  @TestTemplate
+  @Test
   public void testSpecifySnapshotAndTimestamp() {
     // get the snapshot ID of the last write
     long snapshotId = validationCatalog.loadTable(tableIdent).currentSnapshot().snapshotId();
@@ -551,7 +470,7 @@ public class TestSelect extends CatalogTestBase {
                 snapshotId, timestamp));
   }
 
-  @TestTemplate
+  @Test
   public void testBinaryInFilter() {
     sql("CREATE TABLE %s (id bigint, binary binary) USING iceberg", binaryTableName);
     sql("INSERT INTO %s VALUES (1, X''), (2, X'1111'), (3, X'11')", binaryTableName);
@@ -563,7 +482,7 @@ public class TestSelect extends CatalogTestBase {
         sql("SELECT id, binary FROM %s where binary > X'11'", binaryTableName));
   }
 
-  @TestTemplate
+  @Test
   public void testComplexTypeFilter() {
     String complexTypeTableName = tableName("complex_table");
     sql(
