@@ -18,50 +18,56 @@
  */
 package org.apache.iceberg.spark.sql;
 
-import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
-import org.apache.iceberg.spark.TestBaseWithCatalog;
+import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
 import org.apache.spark.sql.AnalysisException;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
 
-public class TestSparkHoursFunction extends TestBaseWithCatalog {
+public class TestSparkHoursFunction extends SparkTestBaseWithCatalog {
 
-  @BeforeEach
+  @Before
   public void useCatalog() {
     sql("USE %s", catalogName);
   }
 
-  @TestTemplate
+  @Test
   public void testTimestamps() {
-    assertThat(scalarSql("SELECT system.hours(TIMESTAMP '2017-12-01 10:12:55.038194 UTC+00:00')"))
-        .as("Expected to produce 17501 * 24 + 10")
-        .isEqualTo(420034);
-    assertThat(scalarSql("SELECT system.hours(TIMESTAMP '1970-01-01 00:00:01.000001 UTC+00:00')"))
-        .as("Expected to produce 0 * 24 + 0 = 0")
-        .isEqualTo(0);
-    assertThat(scalarSql("SELECT system.hours(TIMESTAMP '1969-12-31 23:59:58.999999 UTC+00:00')"))
-        .as("Expected to produce -1")
-        .isEqualTo(-1);
-    assertThat(scalarSql("SELECT system.hours(CAST(null AS TIMESTAMP))")).isNull();
+    Assert.assertEquals(
+        "Expected to produce 17501 * 24 + 10",
+        420034,
+        scalarSql("SELECT system.hours(TIMESTAMP '2017-12-01 10:12:55.038194 UTC+00:00')"));
+    Assert.assertEquals(
+        "Expected to produce 0 * 24 + 0 = 0",
+        0,
+        scalarSql("SELECT system.hours(TIMESTAMP '1970-01-01 00:00:01.000001 UTC+00:00')"));
+    Assert.assertEquals(
+        "Expected to produce -1",
+        -1,
+        scalarSql("SELECT system.hours(TIMESTAMP '1969-12-31 23:59:58.999999 UTC+00:00')"));
+    Assert.assertNull(scalarSql("SELECT system.hours(CAST(null AS TIMESTAMP))"));
   }
 
-  @TestTemplate
+  @Test
   public void testTimestampsNtz() {
-    assertThat(scalarSql("SELECT system.hours(TIMESTAMP_NTZ '2017-12-01 10:12:55.038194 UTC')"))
-        .as("Expected to produce 17501 * 24 + 10")
-        .isEqualTo(420034);
-    assertThat(scalarSql("SELECT system.hours(TIMESTAMP_NTZ '1970-01-01 00:00:01.000001 UTC')"))
-        .as("Expected to produce 0 * 24 + 0 = 0")
-        .isEqualTo(0);
-    assertThat(scalarSql("SELECT system.hours(TIMESTAMP_NTZ '1969-12-31 23:59:58.999999 UTC')"))
-        .as("Expected to produce -1")
-        .isEqualTo(-1);
-    assertThat(scalarSql("SELECT system.hours(CAST(null AS TIMESTAMP_NTZ))")).isNull();
+    Assert.assertEquals(
+        "Expected to produce 17501 * 24 + 10",
+        420034,
+        scalarSql("SELECT system.hours(TIMESTAMP_NTZ '2017-12-01 10:12:55.038194 UTC')"));
+    Assert.assertEquals(
+        "Expected to produce 0 * 24 + 0 = 0",
+        0,
+        scalarSql("SELECT system.hours(TIMESTAMP_NTZ '1970-01-01 00:00:01.000001 UTC')"));
+    Assert.assertEquals(
+        "Expected to produce -1",
+        -1,
+        scalarSql("SELECT system.hours(TIMESTAMP_NTZ '1969-12-31 23:59:58.999999 UTC')"));
+    Assert.assertNull(scalarSql("SELECT system.hours(CAST(null AS TIMESTAMP_NTZ))"));
   }
 
-  @TestTemplate
+  @Test
   public void testWrongNumberOfArguments() {
     assertThatThrownBy(() -> scalarSql("SELECT system.hours()"))
         .isInstanceOf(AnalysisException.class)
@@ -75,7 +81,7 @@ public class TestSparkHoursFunction extends TestBaseWithCatalog {
             "Function 'hours' cannot process input: (date, date): Wrong number of inputs");
   }
 
-  @TestTemplate
+  @Test
   public void testInvalidInputTypes() {
     assertThatThrownBy(() -> scalarSql("SELECT system.hours(1)"))
         .isInstanceOf(AnalysisException.class)
