@@ -20,14 +20,20 @@ package org.apache.iceberg.spark.sql;
 
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
+import java.util.Map;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.exceptions.ValidationException;
-import org.junit.jupiter.api.TestTemplate;
+import org.junit.Test;
 
 public class TestUnpartitionedWritesToBranch extends UnpartitionedWritesTestBase {
 
   private static final String BRANCH = "test";
 
+  public TestUnpartitionedWritesToBranch(
+      String catalogName, String implementation, Map<String, String> config) {
+    super(catalogName, implementation, config);
+  }
+
   @Override
   public void createTables() {
     super.createTables();
@@ -46,7 +52,7 @@ public class TestUnpartitionedWritesToBranch extends UnpartitionedWritesTestBase
     return String.format("%s VERSION AS OF '%s'", tableName, BRANCH);
   }
 
-  @TestTemplate
+  @Test
   public void testInsertIntoNonExistingBranchFails() {
     assertThatThrownBy(
             () -> sql("INSERT INTO %s.branch_not_exist VALUES (4, 'd'), (5, 'e')", tableName))
