@@ -129,7 +129,6 @@ public class TestCreateChangelogViewProcedure extends ExtensionsTestBase {
     var df = spark.sql("select * from cdc_view");
     var fieldNames =
         Arrays.stream(df.schema().fields()).map(StructField::name).collect(Collectors.toList());
-
     assertThat(fieldNames)
         .containsExactly(
             "the id", "the.data", "_change_type", "_change_ordinal", "_commit_snapshot_id");
@@ -678,4 +677,18 @@ public class TestCreateChangelogViewProcedure extends ExtensionsTestBase {
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageContaining("Not support net changes with update images");
   }
+
+  @TestTemplate
+  public void testUpdateWithInComparableType() {
+    sql(
+        "CREATE TABLE %s (id INT NOT NULL, data MAP<STRING,STRING>, age INT) USING iceberg",
+        tableName);
+
+    assertThatThrownBy(
+            () ->
+                sql("CALL %s.system.create_changelog_view(table => '%s')", catalogName, tableName))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessageContaining(
+            "Identifier field is required as table contains unorderable columns: [data]");
+  }
 }
