@@ -24,9 +24,9 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.function.Supplier;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
-import org.apache.iceberg.BaseScanTaskGroup;
 import org.apache.iceberg.PartitionField;
 import org.apache.iceberg.PartitionScanTask;
 import org.apache.iceberg.PartitionSpec;
@@ -34,11 +34,11 @@ import org.apache.iceberg.Scan;
 import org.apache.iceberg.ScanTask;
 import org.apache.iceberg.ScanTaskGroup;
 import org.apache.iceberg.Schema;
-import org.apache.iceberg.StructLike;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.io.CloseableIterable;
+import org.apache.iceberg.metrics.ScanReport;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.spark.Spark3Util;
@@ -69,7 +69,6 @@ abstract class SparkPartitioningAwareScan<T extends PartitionScanTask> extends S
   private List<ScanTaskGroup<T>> taskGroups = null; // lazy cache of task groups
   private StructType groupingKeyType = null; // lazy cache of the grouping key type
   private Transform[] groupingKeyTransforms = null; // lazy cache of grouping key transforms
-  private StructLikeSet groupingKeys = null; // lazy cache of grouping keys
 
   SparkPartitioningAwareScan(
       SparkSession spark,
@@ -77,9 +76,9 @@ abstract class SparkPartitioningAwareScan<T extends PartitionScanTask> extends S
       Scan<?, ? extends ScanTask, ? extends ScanTaskGroup<?>> scan,
       SparkReadConf readConf,
       Schema expectedSchema,
-      List<Expression> filters) {
-
-    super(spark, table, readConf, expectedSchema, filters);
+      List<Expression> filters,
+      Supplier<ScanReport> scanReportSupplier) {
+    super(spark, table, readConf, expectedSchema, filters, scanReportSupplier);
 
     this.scan = scan;
     this.preserveDataGrouping = readConf.preserveDataGrouping();
@@ -201,7 +200,7 @@ abstract class SparkPartitioningAwareScan<T extends PartitionScanTask> extends S
         CloseableIterable<ScanTaskGroup<T>> plannedTaskGroups =
             TableScanUtil.planTaskGroups(
                 CloseableIterable.withNoopClose(tasks()),
-                scan.targetSplitSize(),
+                adjustSplitSize(tasks(), scan.targetSplitSize()),
                 scan.splitLookback(),
                 scan.splitOpenFileCost());
         this.taskGroups = Lists.newArrayList(plannedTaskGroups);
@@ -215,7 +214,7 @@ abstract class SparkPartitioningAwareScan<T extends PartitionScanTask> extends S
         List<ScanTaskGroup<T>> plannedTaskGroups =
             TableScanUtil.planTaskGroups(
                 tasks(),
-                scan.targetSplitSize(),
+                adjustSplitSize(tasks(), scan.targetSplitSize()),
                 scan.splitLookback(),
                 scan.splitOpenFileCost(),
                 groupingKeyType());
@@ -228,35 +227,7 @@ abstract class SparkPartitioningAwareScan<T extends PartitionScanTask> extends S
             plannedGroupingKeys.size(),
             table().name());
 
-        // task groups may be planned multiple times because of runtime filtering
-        // the number of task groups may change but the set of grouping keys must stay same
-        // if grouping keys are not null, this planning happens after runtime filtering
-        // so an empty task group must be added for each filtered out grouping key
-
-        if (groupingKeys == null) {
-          this.taskGroups = plannedTaskGroups;
-          this.groupingKeys = plannedGroupingKeys;
-
-        } else {
-          StructLikeSet missingGroupingKeys = StructLikeSet.create(groupingKeyType());
-
-          for (StructLike groupingKey : groupingKeys) {
-            if (!plannedGroupingKeys.contains(groupingKey)) {
-              missingGroupingKeys.add(groupingKey);
-            }
-          }
-
-          LOG.debug(
-              "{} grouping key(s) were filtered out at runtime for table {}",
-              missingGroupingKeys.size(),
-              table().name());
-
-          for (StructLike groupingKey : missingGroupingKeys) {
-            plannedTaskGroups.add(new BaseScanTaskGroup<>(groupingKey, Collections.emptyList()));
-          }
-
-          this.taskGroups = plannedTaskGroups;
-        }
+        this.taskGroups = plannedTaskGroups;
       }
     }
 
@@ -264,7 +235,7 @@ abstract class SparkPartitioningAwareScan<T extends PartitionScanTask> extends S
   }
 
   // only task groups can be reset while resetting tasks
-  // the set of scanned specs, grouping key type, grouping keys must never change
+  // the set of scanned specs and grouping key type must never change
   protected void resetTasks(List<T> filteredTasks) {
     this.taskGroups = null;
     this.tasks = filteredTasks;
