@@ -24,6 +24,7 @@ import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.IOException;
 import java.math.RoundingMode;
+import java.nio.file.Path;
 import java.util.List;
 import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
@@ -45,8 +46,8 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.math.LongMath;
 import org.apache.iceberg.spark.CommitMetadata;
 import org.apache.iceberg.spark.SparkReadOptions;
-import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
 import org.apache.iceberg.spark.SparkWriteOptions;
+import org.apache.iceberg.spark.TestBaseWithCatalog;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.SnapshotUtil;
 import org.apache.spark.sql.Column;
@@ -57,14 +58,12 @@ import org.apache.spark.sql.SaveMode;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
 import org.apache.spark.sql.functions;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.io.TempDir;
 
-public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
+public class TestDataSourceOptions extends TestBaseWithCatalog {
 
   private static final Configuration CONF = new Configuration();
   private static final Schema SCHEMA =
@@ -72,23 +71,23 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
           optional(1, "id", Types.IntegerType.get()), optional(2, "data", Types.StringType.get()));
   private static SparkSession spark = null;
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir private Path temp;
 
-  @BeforeClass
+  @BeforeAll
   public static void startSpark() {
     TestDataSourceOptions.spark = SparkSession.builder().master("local[2]").getOrCreate();
   }
 
-  @AfterClass
+  @AfterAll
   public static void stopSpark() {
     SparkSession currentSpark = TestDataSourceOptions.spark;
     TestDataSourceOptions.spark = null;
     currentSpark.stop();
   }
 
-  @Test
+  @TestTemplate
   public void testWriteFormatOptionOverridesTableProperties() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -111,14 +110,14 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
       tasks.forEach(
           task -> {
             FileFormat fileFormat = FileFormat.fromFileName(task.file().location());
-            Assert.assertEquals(FileFormat.PARQUET, fileFormat);
+            assertThat(fileFormat).isEqualTo(FileFormat.PARQUET);
           });
     }
   }
 
-  @Test
+  @TestTemplate
   public void testNoWriteFormatOption() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -136,14 +135,14 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
       tasks.forEach(
           task -> {
             FileFormat fileFormat = FileFormat.fromFileName(task.file().location());
-            Assert.assertEquals(FileFormat.AVRO, fileFormat);
+            assertThat(fileFormat).isEqualTo(FileFormat.AVRO);
           });
     }
   }
 
-  @Test
+  @TestTemplate
   public void testHadoopOptions() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
     Configuration sparkHadoopConf = spark.sessionState().newHadoopConf();
     String originalDefaultFS = sparkHadoopConf.get("fs.default.name");
 
@@ -177,15 +176,15 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
       List<SimpleRecord> resultRecords =
           resultDf.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
 
-      Assert.assertEquals("Records should match", expectedRecords, resultRecords);
+      assertThat(resultRecords).as("Records should match").isEqualTo(expectedRecords);
     } finally {
       sparkHadoopConf.set("fs.default.name", originalDefaultFS);
     }
   }
 
-  @Test
+  @TestTemplate
   public void testSplitOptionsOverridesTableProperties() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -209,7 +208,7 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
 
     List<DataFile> files =
         Lists.newArrayList(icebergTable.currentSnapshot().addedDataFiles(icebergTable.io()));
-    Assert.assertEquals("Should have written 1 file", 1, files.size());
+    assertThat(files).as("Should have written 1 file").hasSize(1);
 
     long fileSize = files.get(0).fileSizeInBytes();
     long splitSize = LongMath.divide(fileSize, 2, RoundingMode.CEILING);
@@ -221,12 +220,14 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
             .option(SparkReadOptions.SPLIT_SIZE, String.valueOf(splitSize))
             .load(tableLocation);
 
-    Assert.assertEquals("Spark partitions should match", 2, resultDf.javaRDD().getNumPartitions());
+    assertThat(resultDf.javaRDD().getNumPartitions())
+        .as("Spark partitions should match")
+        .isEqualTo(2);
   }
 
-  @Test
+  @TestTemplate
   public void testIncrementalScanOptions() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -330,9 +331,9 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
     assertThat(row2.getInt(1)).as("max value should match").isEqualTo(3);
   }
 
-  @Test
+  @TestTemplate
   public void testMetadataSplitSizeOptionOverrideTableProperties() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -349,7 +350,7 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
 
     List<ManifestFile> manifests = table.currentSnapshot().allManifests(table.io());
 
-    Assert.assertEquals("Must be 2 manifests", 2, manifests.size());
+    assertThat(manifests).as("Must be 2 manifests").hasSize(2);
 
     // set the target metadata split size so each manifest ends up in a separate split
     table
@@ -358,7 +359,7 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
         .commit();
 
     Dataset<Row> entriesDf = spark.read().format("iceberg").load(tableLocation + "#entries");
-    Assert.assertEquals("Num partitions must match", 2, entriesDf.javaRDD().getNumPartitions());
+    assertThat(entriesDf.javaRDD().getNumPartitions()).as("Num partitions must match").isEqualTo(2);
 
     // override the table property using options
     entriesDf =
@@ -367,12 +368,12 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
             .format("iceberg")
             .option(SparkReadOptions.SPLIT_SIZE, String.valueOf(128 * 1024 * 1024))
             .load(tableLocation + "#entries");
-    Assert.assertEquals("Num partitions must match", 1, entriesDf.javaRDD().getNumPartitions());
+    assertThat(entriesDf.javaRDD().getNumPartitions()).as("Num partitions must match").isEqualTo(1);
   }
 
-  @Test
+  @TestTemplate
   public void testDefaultMetadataSplitSize() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -401,12 +402,12 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
     Dataset<Row> metadataDf = spark.read().format("iceberg").load(tableLocation + "#entries");
 
     int partitionNum = metadataDf.javaRDD().getNumPartitions();
-    Assert.assertEquals("Spark partitions should match", expectedSplits, partitionNum);
+    assertThat(partitionNum).as("Spark partitions should match").isEqualTo(expectedSplits);
   }
 
-  @Test
+  @TestTemplate
   public void testExtraSnapshotMetadata() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
     HadoopTables tables = new HadoopTables(CONF);
     tables.create(SCHEMA, PartitionSpec.unpartitioned(), Maps.newHashMap(), tableLocation);
 
@@ -424,13 +425,14 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
 
     Table table = tables.load(tableLocation);
 
-    Assert.assertTrue(table.currentSnapshot().summary().get("extra-key").equals("someValue"));
-    Assert.assertTrue(table.currentSnapshot().summary().get("another-key").equals("anotherValue"));
+    assertThat(table.currentSnapshot().summary())
+        .containsEntry("extra-key", "someValue")
+        .containsEntry("another-key", "anotherValue");
   }
 
-  @Test
+  @TestTemplate
   public void testExtraSnapshotMetadataWithSQL() throws InterruptedException, IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
     HadoopTables tables = new HadoopTables(CONF);
 
     Table table =
@@ -465,15 +467,15 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
     writerThread.join();
 
     List<Snapshot> snapshots = Lists.newArrayList(table.snapshots());
-    Assert.assertEquals(2, snapshots.size());
-    Assert.assertNull(snapshots.get(0).summary().get("writer-thread"));
+    assertThat(snapshots).hasSize(2);
+    assertThat(snapshots.get(0).summary().get("writer-thread")).isNull();
     assertThat(snapshots.get(1).summary())
         .containsEntry("writer-thread", "test-extra-commit-message-writer-thread")
         .containsEntry("extra-key", "someValue")
         .containsEntry("another-key", "anotherValue");
   }
 
-  @Test
+  @TestTemplate
   public void testExtraSnapshotMetadataWithDelete()
       throws InterruptedException, NoSuchTableException {
     spark.sessionState().conf().setConfString("spark.sql.shuffle.partitions", "1");
@@ -508,8 +510,9 @@ public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
 
     Table table = validationCatalog.loadTable(tableIdent);
     List<Snapshot> snapshots = Lists.newArrayList(table.snapshots());
-    Assert.assertEquals(2, snapshots.size());
-    Assert.assertNull(snapshots.get(0).summary().get("writer-thread"));
+
+    assertThat(snapshots).hasSize(2);
+    assertThat(snapshots.get(0).summary().get("writer-thread")).isNull();
     assertThat(snapshots.get(1).summary())
         .containsEntry("writer-thread", "test-extra-commit-message-delete-thread")
         .containsEntry("extra-key", "someValue")
