@@ -20,10 +20,12 @@ package org.apache.iceberg.spark.source;
 
 import static org.apache.iceberg.Files.localInput;
 import static org.apache.iceberg.Files.localOutput;
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Path;
 import java.util.List;
 import java.util.UUID;
 import java.util.concurrent.TimeoutException;
@@ -55,12 +57,10 @@ import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.execution.streaming.MemoryStream;
 import org.apache.spark.sql.streaming.StreamingQuery;
 import org.apache.spark.sql.streaming.StreamingQueryException;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 import scala.Option;
 import scala.collection.JavaConverters;
 
@@ -79,7 +79,6 @@ public class TestForwardCompatibility {
           .withSpecId(0)
           .addField("zero", 1, "id_zero")
           .build();
-
   // create a fake spec to use to write table metadata
   private static final PartitionSpec FAKE_SPEC =
       org.apache.iceberg.TestHelpers.newExpectedSpecBuilder()
@@ -88,16 +87,16 @@ public class TestForwardCompatibility {
           .addField("identity", 1, "id_zero")
           .build();
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir private Path temp;
 
   private static SparkSession spark = null;
 
-  @BeforeClass
+  @BeforeAll
   public static void startSpark() {
     TestForwardCompatibility.spark = SparkSession.builder().master("local[2]").getOrCreate();
   }
 
-  @AfterClass
+  @AfterAll
   public static void stopSpark() {
     SparkSession currentSpark = TestForwardCompatibility.spark;
     TestForwardCompatibility.spark = null;
@@ -106,7 +105,7 @@ public class TestForwardCompatibility {
 
   @Test
   public void testSparkWriteFailsUnknownTransform() throws IOException {
-    File parent = temp.newFolder("avro");
+    File parent = temp.resolve("avro").toFile();
     File location = new File(parent, "test");
     File dataFolder = new File(location, "data");
     dataFolder.mkdirs();
@@ -127,14 +126,13 @@ public class TestForwardCompatibility {
                     .format("iceberg")
                     .mode("append")
                     .save(location.toString()))
-        .as("Should reject write with unsupported transform")
         .isInstanceOf(UnsupportedOperationException.class)
-        .hasMessageContaining("Cannot write using unsupported transforms: zero");
+        .hasMessageEndingWith("Cannot write using unsupported transforms: zero");
   }
 
   @Test
   public void testSparkStreamingWriteFailsUnknownTransform() throws IOException, TimeoutException {
-    File parent = temp.newFolder("avro");
+    File parent = temp.resolve("avro").toFile();
     File location = new File(parent, "test");
     File dataFolder = new File(location, "data");
     dataFolder.mkdirs();
@@ -160,14 +158,13 @@ public class TestForwardCompatibility {
     send(batch1, inputStream);
 
     assertThatThrownBy(query::processAllAvailable)
-        .as("Should reject streaming write with unsupported transform")
         .isInstanceOf(StreamingQueryException.class)
-        .hasMessageContaining("Cannot write using unsupported transforms: zero");
+        .hasMessageEndingWith("Cannot write using unsupported transforms: zero");
   }
 
   @Test
   public void testSparkCanReadUnknownTransform() throws IOException {
-    File parent = temp.newFolder("avro");
+    File parent = temp.resolve("avro").toFile();
     File location = new File(parent, "test");
     File dataFolder = new File(location, "data");
     dataFolder.mkdirs();
@@ -197,7 +194,7 @@ public class TestForwardCompatibility {
             .withPartitionPath("id_zero=0")
             .build();
 
-    OutputFile manifestFile = localOutput(FileFormat.AVRO.addExtension(temp.newFile().toString()));
+    OutputFile manifestFile = localOutput(FileFormat.AVRO.addExtension(temp.toFile().toString()));
     ManifestWriter<DataFile> manifestWriter = ManifestFiles.write(FAKE_SPEC, manifestFile);
     try {
       manifestWriter.add(file);
@@ -210,7 +207,7 @@ public class TestForwardCompatibility {
     Dataset<Row> df = spark.read().format("iceberg").load(location.toString());
 
     List<Row> rows = df.collectAsList();
-    Assert.assertEquals("Should contain 100 rows", 100, rows.size());
+    assertThat(rows).as("Should contain 100 rows").hasSize(100);
 
     for (int i = 0; i < expected.size(); i += 1) {
       TestHelpers.assertEqualsSafe(table.schema().asStruct(), expected.get(i), rows.get(i));
