@@ -21,31 +21,25 @@ package org.apache.iceberg.spark.source;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.List;
-import java.util.Map;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
-import org.apache.iceberg.spark.SparkCatalogTestBase;
+import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.spark.SparkWriteOptions;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
-import org.junit.After;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.TestTemplate;
 
-public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
+public class TestRequiredDistributionAndOrdering extends CatalogTestBase {
 
-  public TestRequiredDistributionAndOrdering(
-      String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
-  }
-
-  @After
+  @AfterEach
   public void dropTestTable() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Test
+  @TestTemplate
   public void testDefaultLocalSort() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, c3 STRING) "
@@ -74,7 +68,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
         sql("SELECT count(*) FROM %s", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testPartitionColumnsArePrependedForRangeDistribution() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, c3 STRING) "
@@ -110,7 +104,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
         sql("SELECT count(*) FROM %s", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testSortOrderIncludesPartitionColumns() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, c3 STRING) "
@@ -142,7 +136,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
         sql("SELECT count(*) FROM %s", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testDisabledDistributionAndOrdering() {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, c3 STRING) "
@@ -168,6 +162,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
                 inputDF
                     .writeTo(tableName)
                     .option(SparkWriteOptions.USE_TABLE_DISTRIBUTION_AND_ORDERING, "false")
+                    .option(SparkWriteOptions.FANOUT_ENABLED, "false")
                     .append())
         .cause()
         .isInstanceOf(IllegalStateException.class)
@@ -176,7 +171,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
                 + "and by partition within each spec. Either cluster the incoming records or switch to fanout writers.");
   }
 
-  @Test
+  @TestTemplate
   public void testHashDistribution() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, c3 STRING) "
@@ -212,7 +207,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
         sql("SELECT count(*) FROM %s", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testSortBucketTransformsWithoutExtensions() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, c3 STRING) "
@@ -238,7 +233,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
     assertEquals("Rows must match", expected, sql("SELECT * FROM %s ORDER BY c1", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testRangeDistributionWithQuotedColumnsNames() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, `c.3` STRING) "
@@ -274,7 +269,7 @@ public class TestRequiredDistributionAndOrdering extends SparkCatalogTestBase {
         sql("SELECT count(*) FROM %s", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testHashDistributionWithQuotedColumnsNames() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (c1 INT, c2 STRING, `c``3` STRING) "
