@@ -18,11 +18,14 @@
  */
 package org.apache.iceberg.spark.sql;
 
+import static org.apache.iceberg.CatalogUtil.ICEBERG_CATALOG_TYPE;
+import static org.apache.iceberg.CatalogUtil.ICEBERG_CATALOG_TYPE_REST;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.File;
-import java.util.Map;
+import java.nio.file.Files;
 import java.util.UUID;
 import org.apache.iceberg.BaseTable;
 import org.apache.iceberg.PartitionSpec;
@@ -30,84 +33,89 @@ import org.apache.iceberg.Schema;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableOperations;
 import org.apache.iceberg.TableProperties;
+import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.hadoop.HadoopCatalog;
-import org.apache.iceberg.spark.SparkCatalogTestBase;
+import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.types.Types.NestedField;
 import org.apache.iceberg.types.Types.StructType;
 import org.apache.spark.sql.connector.catalog.TableCatalog;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.TestTemplate;
 
-public class TestCreateTable extends SparkCatalogTestBase {
-  public TestCreateTable(String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
-  }
+public class TestCreateTable extends CatalogTestBase {
 
-  @After
+  @AfterEach
   public void dropTestTable() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Test
+  @TestTemplate
   public void testTransformIgnoreCase() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
     sql(
         "CREATE TABLE IF NOT EXISTS %s (id BIGINT NOT NULL, ts timestamp) "
             + "USING iceberg partitioned by (HOURS(ts))",
         tableName);
-    Assert.assertTrue("Table should already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent)).as("Table should already exist").isTrue();
     sql(
         "CREATE TABLE IF NOT EXISTS %s (id BIGINT NOT NULL, ts timestamp) "
             + "USING iceberg partitioned by (hours(ts))",
         tableName);
-    Assert.assertTrue("Table should already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent)).as("Table should already exist").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testTransformSingularForm() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
     sql(
         "CREATE TABLE IF NOT EXISTS %s (id BIGINT NOT NULL, ts timestamp) "
             + "USING iceberg partitioned by (hour(ts))",
         tableName);
-    Assert.assertTrue("Table should exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent)).as("Table should exist").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testTransformPluralForm() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
     sql(
         "CREATE TABLE IF NOT EXISTS %s (id BIGINT NOT NULL, ts timestamp) "
             + "USING iceberg partitioned by (hours(ts))",
         tableName);
-    Assert.assertTrue("Table should exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent)).as("Table should exist").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTable() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql("CREATE TABLE %s (id BIGINT NOT NULL, data STRING) USING iceberg", tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertNotNull("Should load the new table", table);
+    assertThat(table).as("Should load the new table").isNotNull();
 
     StructType expectedSchema =
         StructType.of(
             NestedField.required(1, "id", Types.LongType.get()),
             NestedField.optional(2, "data", Types.StringType.get()));
-    Assert.assertEquals(
-        "Should have the expected schema", expectedSchema, table.schema().asStruct());
-    Assert.assertEquals("Should not be partitioned", 0, table.spec().fields().size());
-    Assert.assertNull(
-        "Should not have the default format set",
-        table.properties().get(TableProperties.DEFAULT_FILE_FORMAT));
+    assertThat(table.schema().asStruct())
+        .as("Should have the expected schema")
+        .isEqualTo(expectedSchema);
+    assertThat(table.spec().fields()).as("Should not be partitioned").hasSize(0);
+    assertThat(table.properties().get(TableProperties.DEFAULT_FILE_FORMAT))
+        .as("Should not have the default format set")
+        .isNull();
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTablePartitionedByUUID() {
     assertThat(validationCatalog.tableExists(tableIdent)).isFalse();
     Schema schema = new Schema(1, Types.NestedField.optional(1, "uuid", Types.UUIDType.get()));
@@ -129,10 +137,11 @@ public class TestCreateTable extends SparkCatalogTestBase {
     assertThat(sql("SELECT uuid FROM %s", tableName)).hasSize(1).element(0).isEqualTo(row(uuid));
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTableInRootNamespace() {
-    Assume.assumeTrue(
-        "Hadoop has no default namespace configured", "testhadoop".equals(catalogName));
+    assumeThat(catalogName)
+        .as("Hadoop has no default namespace configured")
+        .isEqualTo("testhadoop");
 
     try {
       sql("CREATE TABLE %s.table (id bigint) USING iceberg", catalogName);
@@ -141,44 +150,47 @@ public class TestCreateTable extends SparkCatalogTestBase {
     }
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTableUsingParquet() {
-    Assume.assumeTrue(
-        "Not working with session catalog because Spark will not use v2 for a Parquet table",
-        !"spark_catalog".equals(catalogName));
+    assumeThat(catalogName)
+        .as("Not working with session catalog because Spark will not use v2 for a Parquet table")
+        .isNotEqualTo("spark_catalog");
 
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql("CREATE TABLE %s (id BIGINT NOT NULL, data STRING) USING parquet", tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertNotNull("Should load the new table", table);
+    assertThat(table).as("Should load the new table").isNotNull();
 
     StructType expectedSchema =
         StructType.of(
             NestedField.required(1, "id", Types.LongType.get()),
             NestedField.optional(2, "data", Types.StringType.get()));
-    Assert.assertEquals(
-        "Should have the expected schema", expectedSchema, table.schema().asStruct());
-    Assert.assertEquals("Should not be partitioned", 0, table.spec().fields().size());
-    Assert.assertEquals(
-        "Should not have default format parquet",
-        "parquet",
-        table.properties().get(TableProperties.DEFAULT_FILE_FORMAT));
+    assertThat(table.schema().asStruct())
+        .as("Should have the expected schema")
+        .isEqualTo(expectedSchema);
+    assertThat(table.spec().fields()).as("Should not be partitioned").hasSize(0);
+    assertThat(table.properties().get(TableProperties.DEFAULT_FILE_FORMAT))
+        .as("Should not have default format parquet")
+        .isEqualTo("parquet");
 
     assertThatThrownBy(
             () ->
                 sql(
                     "CREATE TABLE %s.default.fail (id BIGINT NOT NULL, data STRING) USING crocodile",
                     catalogName))
-        .as("Should reject unsupported format names")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Unsupported format in USING: crocodile");
+        .hasMessage("Unsupported format in USING: crocodile");
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTablePartitionedBy() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql(
         "CREATE TABLE %s "
@@ -188,7 +200,7 @@ public class TestCreateTable extends SparkCatalogTestBase {
         tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertNotNull("Should load the new table", table);
+    assertThat(table).as("Should load the new table").isNotNull();
 
     StructType expectedSchema =
         StructType.of(
@@ -196,8 +208,9 @@ public class TestCreateTable extends SparkCatalogTestBase {
             NestedField.optional(2, "created_at", Types.TimestampType.withZone()),
             NestedField.optional(3, "category", Types.StringType.get()),
             NestedField.optional(4, "data", Types.StringType.get()));
-    Assert.assertEquals(
-        "Should have the expected schema", expectedSchema, table.schema().asStruct());
+    assertThat(table.schema().asStruct())
+        .as("Should have the expected schema")
+        .isEqualTo(expectedSchema);
 
     PartitionSpec expectedSpec =
         PartitionSpec.builderFor(new Schema(expectedSchema.fields()))
@@ -205,16 +218,18 @@ public class TestCreateTable extends SparkCatalogTestBase {
             .bucket("id", 8)
             .day("created_at")
             .build();
-    Assert.assertEquals("Should be partitioned correctly", expectedSpec, table.spec());
+    assertThat(table.spec()).as("Should be partitioned correctly").isEqualTo(expectedSpec);
 
-    Assert.assertNull(
-        "Should not have the default format set",
-        table.properties().get(TableProperties.DEFAULT_FILE_FORMAT));
+    assertThat(table.properties().get(TableProperties.DEFAULT_FILE_FORMAT))
+        .as("Should not have the default format set")
+        .isNull();
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTableColumnComments() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql(
         "CREATE TABLE %s "
@@ -223,23 +238,26 @@ public class TestCreateTable extends SparkCatalogTestBase {
         tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertNotNull("Should load the new table", table);
+    assertThat(table).as("Should load the new table").isNotNull();
 
     StructType expectedSchema =
         StructType.of(
             NestedField.required(1, "id", Types.LongType.get(), "Unique identifier"),
             NestedField.optional(2, "data", Types.StringType.get(), "Data value"));
-    Assert.assertEquals(
-        "Should have the expected schema", expectedSchema, table.schema().asStruct());
-    Assert.assertEquals("Should not be partitioned", 0, table.spec().fields().size());
-    Assert.assertNull(
-        "Should not have the default format set",
-        table.properties().get(TableProperties.DEFAULT_FILE_FORMAT));
+    assertThat(table.schema().asStruct())
+        .as("Should have the expected schema")
+        .isEqualTo(expectedSchema);
+    assertThat(table.spec().fields()).as("Should not be partitioned").hasSize(0);
+    assertThat(table.properties().get(TableProperties.DEFAULT_FILE_FORMAT))
+        .as("Should not have the default format set")
+        .isNull();
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTableComment() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql(
         "CREATE TABLE %s "
@@ -249,34 +267,36 @@ public class TestCreateTable extends SparkCatalogTestBase {
         tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertNotNull("Should load the new table", table);
+    assertThat(table).as("Should load the new table").isNotNull();
 
     StructType expectedSchema =
         StructType.of(
             NestedField.required(1, "id", Types.LongType.get()),
             NestedField.optional(2, "data", Types.StringType.get()));
-    Assert.assertEquals(
-        "Should have the expected schema", expectedSchema, table.schema().asStruct());
-    Assert.assertEquals("Should not be partitioned", 0, table.spec().fields().size());
-    Assert.assertNull(
-        "Should not have the default format set",
-        table.properties().get(TableProperties.DEFAULT_FILE_FORMAT));
-    Assert.assertEquals(
-        "Should have the table comment set in properties",
-        "Table doc",
-        table.properties().get(TableCatalog.PROP_COMMENT));
+    assertThat(table.schema().asStruct())
+        .as("Should have the expected schema")
+        .isEqualTo(expectedSchema);
+    assertThat(table.spec().fields()).as("Should not be partitioned").hasSize(0);
+    assertThat(table.properties().get(TableProperties.DEFAULT_FILE_FORMAT))
+        .as("Should not have the default format set")
+        .isNull();
+    assertThat(table.properties().get(TableCatalog.PROP_COMMENT))
+        .as("Should have the table comment set in properties")
+        .isEqualTo("Table doc");
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTableLocation() throws Exception {
-    Assume.assumeTrue(
-        "Cannot set custom locations for Hadoop catalog tables",
-        !(validationCatalog instanceof HadoopCatalog));
+    assumeThat(validationCatalog)
+        .as("Cannot set custom locations for Hadoop catalog tables")
+        .isNotInstanceOf(HadoopCatalog.class);
 
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
-    File tableLocation = temp.newFolder();
-    Assert.assertTrue(tableLocation.delete());
+    File tableLocation = Files.createTempDirectory(temp, "junit").toFile();
+    assertThat(tableLocation.delete()).isTrue();
 
     String location = "file:" + tableLocation;
 
@@ -288,24 +308,27 @@ public class TestCreateTable extends SparkCatalogTestBase {
         tableName, location);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertNotNull("Should load the new table", table);
+    assertThat(table).as("Should load the new table").isNotNull();
 
     StructType expectedSchema =
         StructType.of(
             NestedField.required(1, "id", Types.LongType.get()),
             NestedField.optional(2, "data", Types.StringType.get()));
-    Assert.assertEquals(
-        "Should have the expected schema", expectedSchema, table.schema().asStruct());
-    Assert.assertEquals("Should not be partitioned", 0, table.spec().fields().size());
-    Assert.assertNull(
-        "Should not have the default format set",
-        table.properties().get(TableProperties.DEFAULT_FILE_FORMAT));
-    Assert.assertEquals("Should have a custom table location", location, table.location());
+    assertThat(table.schema().asStruct())
+        .as("Should have the expected schema")
+        .isEqualTo(expectedSchema);
+    assertThat(table.spec().fields()).as("Should not be partitioned").hasSize(0);
+    assertThat(table.properties().get(TableProperties.DEFAULT_FILE_FORMAT))
+        .as("Should not have the default format set")
+        .isNull();
+    assertThat(table.location()).as("Should have a custom table location").isEqualTo(location);
   }
 
-  @Test
+  @TestTemplate
   public void testCreateTableProperties() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql(
         "CREATE TABLE %s "
@@ -315,22 +338,69 @@ public class TestCreateTable extends SparkCatalogTestBase {
         tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertNotNull("Should load the new table", table);
+    assertThat(table).as("Should load the new table").isNotNull();
 
     StructType expectedSchema =
         StructType.of(
             NestedField.required(1, "id", Types.LongType.get()),
             NestedField.optional(2, "data", Types.StringType.get()));
-    Assert.assertEquals(
-        "Should have the expected schema", expectedSchema, table.schema().asStruct());
-    Assert.assertEquals("Should not be partitioned", 0, table.spec().fields().size());
-    Assert.assertEquals("Should have property p1", "2", table.properties().get("p1"));
-    Assert.assertEquals("Should have property p2", "x", table.properties().get("p2"));
+    assertThat(table.schema().asStruct())
+        .as("Should have the expected schema")
+        .isEqualTo(expectedSchema);
+    assertThat(table.spec().fields()).as("Should not be partitioned").hasSize(0);
+    assertThat(table.properties()).containsEntry("p1", "2").containsEntry("p2", "x");
   }
 
-  @Test
+  @TestTemplate
+  public void testCreateTableCommitProperties() {
+    assumeThat(catalogConfig.get(ICEBERG_CATALOG_TYPE))
+        .as(
+            "need to fix https://github.com/apache/iceberg/issues/11554 before enabling this for the REST catalog")
+        .isNotEqualTo(ICEBERG_CATALOG_TYPE_REST);
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
+
+    assertThatThrownBy(
+            () ->
+                sql(
+                    "CREATE TABLE %s "
+                        + "(id BIGINT NOT NULL, data STRING) "
+                        + "USING iceberg "
+                        + "TBLPROPERTIES ('commit.retry.num-retries'='x', p2='x')",
+                    tableName))
+        .isInstanceOf(ValidationException.class)
+        .hasMessage("Table property commit.retry.num-retries must have integer value");
+
+    assertThatThrownBy(
+            () ->
+                sql(
+                    "CREATE TABLE %s "
+                        + "(id BIGINT NOT NULL, data STRING) "
+                        + "USING iceberg "
+                        + "TBLPROPERTIES ('commit.retry.max-wait-ms'='-1')",
+                    tableName))
+        .isInstanceOf(ValidationException.class)
+        .hasMessage("Table property commit.retry.max-wait-ms must have non negative integer value");
+
+    sql(
+        "CREATE TABLE %s "
+            + "(id BIGINT NOT NULL, data STRING) "
+            + "USING iceberg "
+            + "TBLPROPERTIES ('commit.retry.num-retries'='1', 'commit.retry.max-wait-ms'='3000')",
+        tableName);
+
+    Table table = validationCatalog.loadTable(tableIdent);
+    assertThat(table.properties())
+        .containsEntry(TableProperties.COMMIT_NUM_RETRIES, "1")
+        .containsEntry(TableProperties.COMMIT_MAX_RETRY_WAIT_MS, "3000");
+  }
+
+  @TestTemplate
   public void testCreateTableWithFormatV2ThroughTableProperty() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql(
         "CREATE TABLE %s "
@@ -340,15 +410,16 @@ public class TestCreateTable extends SparkCatalogTestBase {
         tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertEquals(
-        "should create table using format v2",
-        2,
-        ((BaseTable) table).operations().current().formatVersion());
+    assertThat(((BaseTable) table).operations().current().formatVersion())
+        .as("should create table using format v2")
+        .isEqualTo(2);
   }
 
-  @Test
+  @TestTemplate
   public void testUpgradeTableWithFormatV2ThroughTableProperty() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql(
         "CREATE TABLE %s "
@@ -359,15 +430,21 @@ public class TestCreateTable extends SparkCatalogTestBase {
 
     Table table = validationCatalog.loadTable(tableIdent);
     TableOperations ops = ((BaseTable) table).operations();
-    Assert.assertEquals("should create table using format v1", 1, ops.refresh().formatVersion());
+    assertThat(ops.refresh().formatVersion())
+        .as("should create table using format v1")
+        .isEqualTo(1);
 
     sql("ALTER TABLE %s SET TBLPROPERTIES ('format-version'='2')", tableName);
-    Assert.assertEquals("should update table to use format v2", 2, ops.refresh().formatVersion());
+    assertThat(ops.refresh().formatVersion())
+        .as("should update table to use format v2")
+        .isEqualTo(2);
   }
 
-  @Test
+  @TestTemplate
   public void testDowngradeTableToFormatV1ThroughTablePropertyFails() {
-    Assert.assertFalse("Table should not already exist", validationCatalog.tableExists(tableIdent));
+    assertThat(validationCatalog.tableExists(tableIdent))
+        .as("Table should not already exist")
+        .isFalse();
 
     sql(
         "CREATE TABLE %s "
@@ -378,13 +455,14 @@ public class TestCreateTable extends SparkCatalogTestBase {
 
     Table table = validationCatalog.loadTable(tableIdent);
     TableOperations ops = ((BaseTable) table).operations();
-    Assert.assertEquals("should create table using format v2", 2, ops.refresh().formatVersion());
+    assertThat(ops.refresh().formatVersion())
+        .as("should create table using format v2")
+        .isEqualTo(2);
 
     assertThatThrownBy(
             () -> sql("ALTER TABLE %s SET TBLPROPERTIES ('format-version'='1')", tableName))
-        .as("should fail to downgrade to v1")
         .cause()
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Cannot downgrade v2 table to v1");
+        .hasMessage("Cannot downgrade v2 table to v1");
   }
 }
