@@ -21,40 +21,64 @@ package org.apache.iceberg.spark.sql;
 import static org.apache.spark.sql.functions.col;
 import static org.apache.spark.sql.functions.lit;
 import static org.apache.spark.sql.functions.when;
+import static org.assertj.core.api.Assertions.assertThat;
 
-import java.util.Map;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Table;
-import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
-import org.apache.iceberg.spark.SparkCatalogTestBase;
+import org.apache.iceberg.spark.CatalogTestBase;
+import org.apache.iceberg.spark.SparkCatalogConfig;
 import org.apache.iceberg.types.Types;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
 
-public class TestCreateTableAsSelect extends SparkCatalogTestBase {
+public class TestCreateTableAsSelect extends CatalogTestBase {
 
-  private final String sourceName;
+  @Parameter(index = 3)
+  private String sourceName;
 
-  public TestCreateTableAsSelect(
-      String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
-    this.sourceName = tableName("source");
+  @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}, sourceName = {3}")
+  protected static Object[][] parameters() {
+    return new Object[][] {
+      {
+        SparkCatalogConfig.HIVE.catalogName(),
+        SparkCatalogConfig.HIVE.implementation(),
+        SparkCatalogConfig.HIVE.properties(),
+        SparkCatalogConfig.HIVE.catalogName() + ".default.source"
+      },
+      {
+        SparkCatalogConfig.HADOOP.catalogName(),
+        SparkCatalogConfig.HADOOP.implementation(),
+        SparkCatalogConfig.HADOOP.properties(),
+        SparkCatalogConfig.HADOOP.catalogName() + ".default.source"
+      },
+      {
+        SparkCatalogConfig.SPARK.catalogName(),
+        SparkCatalogConfig.SPARK.implementation(),
+        SparkCatalogConfig.SPARK.properties(),
+        "default.source"
+      }
+    };
+  }
 
+  @BeforeEach
+  public void createTableIfNotExists() {
     sql(
         "CREATE TABLE IF NOT EXISTS %s (id bigint NOT NULL, data string) "
             + "USING iceberg PARTITIONED BY (truncate(id, 3))",
         sourceName);
-    sql("INSERT INTO %s VALUES (1, 'a'), (2, 'b'), (3, 'c')", sourceName);
+    sql("INSERT INTO %s VALUES (1, 'a'), (2, 'b'), (3, 'c'), (4, 'd'), (5, 'e')", sourceName);
   }
 
-  @After
+  @AfterEach
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Test
+  @TestTemplate
   public void testUnpartitionedCTAS() {
     sql("CREATE TABLE %s USING iceberg AS SELECT * FROM %s", tableName, sourceName);
 
@@ -65,18 +89,18 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
 
     Table ctasTable = validationCatalog.loadTable(tableIdent);
 
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        ctasTable.schema().asStruct());
-    Assert.assertEquals("Should be an unpartitioned table", 0, ctasTable.spec().fields().size());
+    assertThat(ctasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+
+    assertThat(ctasTable.spec().fields()).as("Should be an unpartitioned table").hasSize(0);
     assertEquals(
         "Should have rows matching the source table",
         sql("SELECT * FROM %s ORDER BY id", sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testPartitionedCTAS() {
     sql(
         "CREATE TABLE %s USING iceberg PARTITIONED BY (id) AS SELECT * FROM %s ORDER BY id",
@@ -91,18 +115,42 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
 
     Table ctasTable = validationCatalog.loadTable(tableIdent);
 
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        ctasTable.schema().asStruct());
-    Assert.assertEquals("Should be partitioned by id", expectedSpec, ctasTable.spec());
+    assertThat(ctasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+    assertThat(ctasTable.spec()).as("Should be partitioned by id").isEqualTo(expectedSpec);
     assertEquals(
         "Should have rows matching the source table",
         sql("SELECT * FROM %s ORDER BY id", sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @Test
+  @TestTemplate
+  public void testCTASWriteDistributionModeRespected() {
+    sql(
+        "CREATE TABLE %s USING iceberg PARTITIONED BY (bucket(2, id)) AS SELECT * FROM %s",
+        tableName, sourceName);
+
+    Schema expectedSchema =
+        new Schema(
+            Types.NestedField.optional(1, "id", Types.LongType.get()),
+            Types.NestedField.optional(2, "data", Types.StringType.get()));
+
+    PartitionSpec expectedSpec = PartitionSpec.builderFor(expectedSchema).bucket("id", 2).build();
+
+    Table ctasTable = validationCatalog.loadTable(tableIdent);
+
+    assertThat(ctasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+    assertThat(ctasTable.spec()).as("Should be partitioned by id").isEqualTo(expectedSpec);
+    assertEquals(
+        "Should have rows matching the source table",
+        sql("SELECT * FROM %s ORDER BY id", sourceName),
+        sql("SELECT * FROM %s ORDER BY id", tableName));
+  }
+
+  @TestTemplate
   public void testRTAS() {
     sql(
         "CREATE TABLE %s USING iceberg TBLPROPERTIES ('prop1'='val1', 'prop2'='val2')"
@@ -132,11 +180,10 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
     Table rtasTable = validationCatalog.loadTable(tableIdent);
 
     // the replacement table has a different schema and partition spec than the original
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        rtasTable.schema().asStruct());
-    Assert.assertEquals("Should be partitioned by part", expectedSpec, rtasTable.spec());
+    assertThat(rtasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+    assertThat(rtasTable.spec()).as("Should be partitioned by part").isEqualTo(expectedSpec);
 
     assertEquals(
         "Should have rows matching the source table",
@@ -146,18 +193,19 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
             sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
 
-    Assert.assertEquals(
-        "Table should have expected snapshots", 2, Iterables.size(rtasTable.snapshots()));
-
-    Assert.assertEquals(
-        "Should have updated table property", "newval1", rtasTable.properties().get("prop1"));
-    Assert.assertEquals(
-        "Should have preserved table property", "val2", rtasTable.properties().get("prop2"));
-    Assert.assertEquals(
-        "Should have new table property", "val3", rtasTable.properties().get("prop3"));
+    assertThat(rtasTable.snapshots()).as("Table should have expected snapshots").hasSize(2);
+    assertThat(rtasTable.properties().get("prop1"))
+        .as("Should have updated table property")
+        .isEqualTo("newval1");
+    assertThat(rtasTable.properties().get("prop2"))
+        .as("Should have preserved table property")
+        .isEqualTo("val2");
+    assertThat(rtasTable.properties().get("prop3"))
+        .as("Should have new table property")
+        .isEqualTo("val3");
   }
 
-  @Test
+  @TestTemplate
   public void testCreateRTAS() {
     sql(
         "CREATE OR REPLACE TABLE %s USING iceberg PARTITIONED BY (part) AS "
@@ -194,11 +242,10 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
     Table rtasTable = validationCatalog.loadTable(tableIdent);
 
     // the replacement table has a different schema and partition spec than the original
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        rtasTable.schema().asStruct());
-    Assert.assertEquals("Should be partitioned by part", expectedSpec, rtasTable.spec());
+    assertThat(rtasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+    assertThat(rtasTable.spec()).as("Should be partitioned by part").isEqualTo(expectedSpec);
 
     assertEquals(
         "Should have rows matching the source table",
@@ -208,11 +255,10 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
             sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
 
-    Assert.assertEquals(
-        "Table should have expected snapshots", 2, Iterables.size(rtasTable.snapshots()));
+    assertThat(rtasTable.snapshots()).as("Table should have expected snapshots").hasSize(2);
   }
 
-  @Test
+  @TestTemplate
   public void testDataFrameV2Create() throws Exception {
     spark.table(sourceName).writeTo(tableName).using("iceberg").create();
 
@@ -223,18 +269,17 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
 
     Table ctasTable = validationCatalog.loadTable(tableIdent);
 
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        ctasTable.schema().asStruct());
-    Assert.assertEquals("Should be an unpartitioned table", 0, ctasTable.spec().fields().size());
+    assertThat(ctasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+    assertThat(ctasTable.spec().fields()).as("Should be an unpartitioned table").hasSize(0);
     assertEquals(
         "Should have rows matching the source table",
         sql("SELECT * FROM %s ORDER BY id", sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testDataFrameV2Replace() throws Exception {
     spark.table(sourceName).writeTo(tableName).using("iceberg").create();
 
@@ -267,11 +312,10 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
     Table rtasTable = validationCatalog.loadTable(tableIdent);
 
     // the replacement table has a different schema and partition spec than the original
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        rtasTable.schema().asStruct());
-    Assert.assertEquals("Should be partitioned by part", expectedSpec, rtasTable.spec());
+    assertThat(rtasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+    assertThat(rtasTable.spec()).as("Should be partitioned by part").isEqualTo(expectedSpec);
 
     assertEquals(
         "Should have rows matching the source table",
@@ -281,11 +325,10 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
             sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
 
-    Assert.assertEquals(
-        "Table should have expected snapshots", 2, Iterables.size(rtasTable.snapshots()));
+    assertThat(rtasTable.snapshots()).as("Table should have expected snapshots").hasSize(2);
   }
 
-  @Test
+  @TestTemplate
   public void testDataFrameV2CreateOrReplace() {
     spark
         .table(sourceName)
@@ -335,11 +378,10 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
     Table rtasTable = validationCatalog.loadTable(tableIdent);
 
     // the replacement table has a different schema and partition spec than the original
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        rtasTable.schema().asStruct());
-    Assert.assertEquals("Should be partitioned by part", expectedSpec, rtasTable.spec());
+    assertThat(rtasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
+    assertThat(rtasTable.spec()).as("Should be partitioned by part").isEqualTo(expectedSpec);
 
     assertEquals(
         "Should have rows matching the source table",
@@ -349,11 +391,10 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
             sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
 
-    Assert.assertEquals(
-        "Table should have expected snapshots", 2, Iterables.size(rtasTable.snapshots()));
+    assertThat(rtasTable.snapshots()).as("Table should have expected snapshots").hasSize(2);
   }
 
-  @Test
+  @TestTemplate
   public void testCreateRTASWithPartitionSpecChanging() {
     sql(
         "CREATE OR REPLACE TABLE %s USING iceberg PARTITIONED BY (part) AS "
@@ -393,13 +434,12 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
             .withSpecId(2) // The Spec is new
             .build();
 
-    Assert.assertEquals("Should be partitioned by part and id", expectedSpec, rtasTable.spec());
+    assertThat(rtasTable.spec()).as("Should be partitioned by part and id").isEqualTo(expectedSpec);
 
     // the replacement table has a different schema and partition spec than the original
-    Assert.assertEquals(
-        "Should have expected nullable schema",
-        expectedSchema.asStruct(),
-        rtasTable.schema().asStruct());
+    assertThat(rtasTable.schema().asStruct())
+        .as("Should have expected nullable schema")
+        .isEqualTo(expectedSchema.asStruct());
 
     assertEquals(
         "Should have rows matching the source table",
@@ -409,7 +449,6 @@ public class TestCreateTableAsSelect extends SparkCatalogTestBase {
             sourceName),
         sql("SELECT * FROM %s ORDER BY id", tableName));
 
-    Assert.assertEquals(
-        "Table should have expected snapshots", 2, Iterables.size(rtasTable.snapshots()));
+    assertThat(rtasTable.snapshots()).as("Table should have expected snapshots").hasSize(2);
   }
 }
